# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/adapter_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2dbtlabs/proto/public/v1/fields/adapter_types.proto\x12\x1ev1.public.fields.adapter_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xbe\x02\n\x16\x41\x64\x61pterCommonEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12P\n\x05\x65xtra\x18\t \x03(\x0b\x32\x41.v1.public.fields.adapter_types.AdapterCommonEventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x13\x41\x64\x61pterNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\xc9\x02\n\x0f\x41\x64\x61pterNodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12J\n\rnode_relation\x18\n \x01(\x0b\x32\x33.v1.public.fields.adapter_types.AdapterNodeRelation\x12\x15\n\rnode_checksum\x18\x0b \x01(\t\"G\n\x0fReferenceKeyMsg\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\"?\n\x19\x41\x64\x61pterDeprecationWarning\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\xad\x01\n\x1c\x41\x64\x61pterDeprecationWarningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.adapter_types.AdapterDeprecationWarning\"!\n\x1f\x43ollectFreshnessReturnSignature\"\xb9\x01\n\"CollectFreshnessReturnSignatureMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32?.v1.public.fields.adapter_types.CollectFreshnessReturnSignature\"\xa1\x01\n\x11\x41\x64\x61pterEventDebug\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"\x9d\x01\n\x14\x41\x64\x61pterEventDebugMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.adapter_types.AdapterEventDebug\"\xa0\x01\n\x10\x41\x64\x61pterEventInfo\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"\x9b\x01\n\x13\x41\x64\x61pterEventInfoMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.AdapterEventInfo\"\xa3\x01\n\x13\x41\x64\x61pterEventWarning\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"\xa1\x01\n\x16\x41\x64\x61pterEventWarningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.adapter_types.AdapterEventWarning\"\xb3\x01\n\x11\x41\x64\x61pterEventError\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x10\n\x08\x65xc_info\x18\x05 \x01(\t\"\x9d\x01\n\x14\x41\x64\x61pterEventErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.adapter_types.AdapterEventError\"y\n\rNewConnection\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"\x95\x01\n\x10NewConnectionMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.NewConnection\"=\n\x10\x43onnectionReused\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x16\n\x0eorig_conn_name\x18\x02 \x01(\t\"\x9b\x01\n\x13\x43onnectionReusedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.ConnectionReused\"0\n\x1b\x43onnectionLeftOpenInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"\xb1\x01\n\x1e\x43onnectionLeftOpenInCleanupMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.adapter_types.ConnectionLeftOpenInCleanup\".\n\x19\x43onnectionClosedInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"\xad\x01\n\x1c\x43onnectionClosedInCleanupMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.adapter_types.ConnectionClosedInCleanup\"y\n\x0eRollbackFailed\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\x97\x01\n\x11RollbackFailedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.RollbackFailed\"i\n\x10\x43onnectionClosed\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x9b\x01\n\x13\x43onnectionClosedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.ConnectionClosed\"k\n\x12\x43onnectionLeftOpen\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x9f\x01\n\x15\x43onnectionLeftOpenMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.adapter_types.ConnectionLeftOpen\"a\n\x08Rollback\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x8b\x01\n\x0bRollbackMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.adapter_types.Rollback\"@\n\tCacheMiss\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"\x8d\x01\n\x0c\x43\x61\x63heMissMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.adapter_types.CacheMiss\"u\n\rListRelations\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x42\n\trelations\x18\x03 \x03(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x95\x01\n\x10ListRelationsMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.ListRelations\"z\n\x0e\x43onnectionUsed\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"\x97\x01\n\x11\x43onnectionUsedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.ConnectionUsed\"n\n\x08SQLQuery\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x0b\n\x03sql\x18\x03 \x01(\t\"\x8b\x01\n\x0bSQLQueryMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.adapter_types.SQLQuery\"\x87\x01\n\x0eSQLQueryStatus\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x03 \x01(\x02\x12\x10\n\x08query_id\x18\x04 \x01(\t\"\x97\x01\n\x11SQLQueryStatusMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.SQLQueryStatus\"b\n\tSQLCommit\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"\x8d\x01\n\x0cSQLCommitMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.adapter_types.SQLCommit\"t\n\rColTypeChange\x12\x11\n\torig_type\x18\x01 \x01(\t\x12\x10\n\x08new_type\x18\x02 \x01(\t\x12>\n\x05table\x18\x03 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x95\x01\n\x10\x43olTypeChangeMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.ColTypeChange\"S\n\x0eSchemaCreation\x12\x41\n\x08relation\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x97\x01\n\x11SchemaCreationMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.SchemaCreation\"O\n\nSchemaDrop\x12\x41\n\x08relation\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x8f\x01\n\rSchemaDropMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.adapter_types.SchemaDrop\"\xaa\x02\n\x0b\x43\x61\x63heAction\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12@\n\x07ref_key\x18\x02 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\x12\x42\n\tref_key_2\x18\x03 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\x12\x42\n\tref_key_3\x18\x04 \x01(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\x12\x41\n\x08ref_list\x18\x05 \x03(\x0b\x32/.v1.public.fields.adapter_types.ReferenceKeyMsg\"\x91\x01\n\x0e\x43\x61\x63heActionMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.adapter_types.CacheAction\"\xab\x01\n\x0e\x43\x61\x63heDumpGraph\x12\x46\n\x04\x64ump\x18\x01 \x03(\x0b\x32\x38.v1.public.fields.adapter_types.CacheDumpGraph.DumpEntry\x12\x14\n\x0c\x62\x65\x66ore_after\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x1a+\n\tDumpEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x11\x43\x61\x63heDumpGraphMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.CacheDumpGraph\"B\n\x11\x41\x64\x61pterRegistered\x12\x14\n\x0c\x61\x64\x61pter_name\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x61pter_version\x18\x02 \x01(\t\"\x9d\x01\n\x14\x41\x64\x61pterRegisteredMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.adapter_types.AdapterRegistered\"!\n\x12\x41\x64\x61pterImportError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x9f\x01\n\x15\x41\x64\x61pterImportErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.adapter_types.AdapterImportError\"#\n\x0fPluginLoadError\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"\x99\x01\n\x12PluginLoadErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.adapter_types.PluginLoadError\"t\n\x14NewConnectionOpening\x12\x42\n\tnode_info\x18\x01 \x01(\x0b\x32/.v1.public.fields.adapter_types.AdapterNodeInfo\x12\x18\n\x10\x63onnection_state\x18\x02 \x01(\t\"\xa3\x01\n\x17NewConnectionOpeningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.adapter_types.NewConnectionOpening\"8\n\rCodeExecution\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ode_content\x18\x02 \x01(\t\"\x95\x01\n\x10\x43odeExecutionMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.adapter_types.CodeExecution\"6\n\x13\x43odeExecutionStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x02 \x01(\x02\"\xa1\x01\n\x16\x43odeExecutionStatusMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.adapter_types.CodeExecutionStatus\"%\n\x16\x43\x61talogGenerationError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\xa7\x01\n\x19\x43\x61talogGenerationErrorMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.CatalogGenerationError\"-\n\x13WriteCatalogFailure\x12\x16\n\x0enum_exceptions\x18\x01 \x01(\x05\"\xa1\x01\n\x16WriteCatalogFailureMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.adapter_types.WriteCatalogFailure\"\x1e\n\x0e\x43\x61talogWritten\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x97\x01\n\x11\x43\x61talogWrittenMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.adapter_types.CatalogWritten\"\x14\n\x12\x43\x61nnotGenerateDocs\"\x9f\x01\n\x15\x43\x61nnotGenerateDocsMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.adapter_types.CannotGenerateDocs\"\x11\n\x0f\x42uildingCatalog\"\x99\x01\n\x12\x42uildingCatalogMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.adapter_types.BuildingCatalog\"-\n\x18\x44\x61tabaseErrorRunningHook\x12\x11\n\thook_type\x18\x01 \x01(\t\"\xab\x01\n\x1b\x44\x61tabaseErrorRunningHookMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.adapter_types.DatabaseErrorRunningHook\"4\n\x0cHooksRunning\x12\x11\n\tnum_hooks\x18\x01 \x01(\x05\x12\x11\n\thook_type\x18\x02 \x01(\t\"\x93\x01\n\x0fHooksRunningMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.adapter_types.HooksRunning\"T\n\x14\x46inishedRunningStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\x12\x11\n\texecution\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x03 \x01(\x02\"\xa3\x01\n\x17\x46inishedRunningStatsMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.adapter_types.FinishedRunningStats\"<\n\x15\x43onstraintNotEnforced\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"\xa5\x01\n\x18\x43onstraintNotEnforcedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.adapter_types.ConstraintNotEnforced\"=\n\x16\x43onstraintNotSupported\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"\xa7\x01\n\x19\x43onstraintNotSupportedMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.ConstraintNotSupported\"%\n\x10TypeCodeNotFound\x12\x11\n\ttype_code\x18\x01 \x01(\x05\"\x9b\x01\n\x13TypeCodeNotFoundMsg\x12\x44\n\x04info\x18\x01 \x01(\x0b\x32\x36.v1.public.fields.adapter_types.AdapterCommonEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.adapter_types.TypeCodeNotFoundBAZ?github.com/dbt-labs/proto-golang/v1/public/fields/adapter_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.adapter_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dbt-labs/proto-golang/v1/public/fields/adapter_types'
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._loaded_options = None
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._loaded_options = None
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_options = b'8\001'
  _globals['_ADAPTERCOMMONEVENTINFO']._serialized_start=150
  _globals['_ADAPTERCOMMONEVENTINFO']._serialized_end=468
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._serialized_start=424
  _globals['_ADAPTERCOMMONEVENTINFO_EXTRAENTRY']._serialized_end=468
  _globals['_ADAPTERNODERELATION']._serialized_start=470
  _globals['_ADAPTERNODERELATION']._serialized_end=563
  _globals['_ADAPTERNODEINFO']._serialized_start=566
  _globals['_ADAPTERNODEINFO']._serialized_end=895
  _globals['_REFERENCEKEYMSG']._serialized_start=897
  _globals['_REFERENCEKEYMSG']._serialized_end=968
  _globals['_ADAPTERDEPRECATIONWARNING']._serialized_start=970
  _globals['_ADAPTERDEPRECATIONWARNING']._serialized_end=1033
  _globals['_ADAPTERDEPRECATIONWARNINGMSG']._serialized_start=1036
  _globals['_ADAPTERDEPRECATIONWARNINGMSG']._serialized_end=1209
  _globals['_COLLECTFRESHNESSRETURNSIGNATURE']._serialized_start=1211
  _globals['_COLLECTFRESHNESSRETURNSIGNATURE']._serialized_end=1244
  _globals['_COLLECTFRESHNESSRETURNSIGNATUREMSG']._serialized_start=1247
  _globals['_COLLECTFRESHNESSRETURNSIGNATUREMSG']._serialized_end=1432
  _globals['_ADAPTEREVENTDEBUG']._serialized_start=1435
  _globals['_ADAPTEREVENTDEBUG']._serialized_end=1596
  _globals['_ADAPTEREVENTDEBUGMSG']._serialized_start=1599
  _globals['_ADAPTEREVENTDEBUGMSG']._serialized_end=1756
  _globals['_ADAPTEREVENTINFO']._serialized_start=1759
  _globals['_ADAPTEREVENTINFO']._serialized_end=1919
  _globals['_ADAPTEREVENTINFOMSG']._serialized_start=1922
  _globals['_ADAPTEREVENTINFOMSG']._serialized_end=2077
  _globals['_ADAPTEREVENTWARNING']._serialized_start=2080
  _globals['_ADAPTEREVENTWARNING']._serialized_end=2243
  _globals['_ADAPTEREVENTWARNINGMSG']._serialized_start=2246
  _globals['_ADAPTEREVENTWARNINGMSG']._serialized_end=2407
  _globals['_ADAPTEREVENTERROR']._serialized_start=2410
  _globals['_ADAPTEREVENTERROR']._serialized_end=2589
  _globals['_ADAPTEREVENTERRORMSG']._serialized_start=2592
  _globals['_ADAPTEREVENTERRORMSG']._serialized_end=2749
  _globals['_NEWCONNECTION']._serialized_start=2751
  _globals['_NEWCONNECTION']._serialized_end=2872
  _globals['_NEWCONNECTIONMSG']._serialized_start=2875
  _globals['_NEWCONNECTIONMSG']._serialized_end=3024
  _globals['_CONNECTIONREUSED']._serialized_start=3026
  _globals['_CONNECTIONREUSED']._serialized_end=3087
  _globals['_CONNECTIONREUSEDMSG']._serialized_start=3090
  _globals['_CONNECTIONREUSEDMSG']._serialized_end=3245
  _globals['_CONNECTIONLEFTOPENINCLEANUP']._serialized_start=3247
  _globals['_CONNECTIONLEFTOPENINCLEANUP']._serialized_end=3295
  _globals['_CONNECTIONLEFTOPENINCLEANUPMSG']._serialized_start=3298
  _globals['_CONNECTIONLEFTOPENINCLEANUPMSG']._serialized_end=3475
  _globals['_CONNECTIONCLOSEDINCLEANUP']._serialized_start=3477
  _globals['_CONNECTIONCLOSEDINCLEANUP']._serialized_end=3523
  _globals['_CONNECTIONCLOSEDINCLEANUPMSG']._serialized_start=3526
  _globals['_CONNECTIONCLOSEDINCLEANUPMSG']._serialized_end=3699
  _globals['_ROLLBACKFAILED']._serialized_start=3701
  _globals['_ROLLBACKFAILED']._serialized_end=3822
  _globals['_ROLLBACKFAILEDMSG']._serialized_start=3825
  _globals['_ROLLBACKFAILEDMSG']._serialized_end=3976
  _globals['_CONNECTIONCLOSED']._serialized_start=3978
  _globals['_CONNECTIONCLOSED']._serialized_end=4083
  _globals['_CONNECTIONCLOSEDMSG']._serialized_start=4086
  _globals['_CONNECTIONCLOSEDMSG']._serialized_end=4241
  _globals['_CONNECTIONLEFTOPEN']._serialized_start=4243
  _globals['_CONNECTIONLEFTOPEN']._serialized_end=4350
  _globals['_CONNECTIONLEFTOPENMSG']._serialized_start=4353
  _globals['_CONNECTIONLEFTOPENMSG']._serialized_end=4512
  _globals['_ROLLBACK']._serialized_start=4514
  _globals['_ROLLBACK']._serialized_end=4611
  _globals['_ROLLBACKMSG']._serialized_start=4614
  _globals['_ROLLBACKMSG']._serialized_end=4753
  _globals['_CACHEMISS']._serialized_start=4755
  _globals['_CACHEMISS']._serialized_end=4819
  _globals['_CACHEMISSMSG']._serialized_start=4822
  _globals['_CACHEMISSMSG']._serialized_end=4963
  _globals['_LISTRELATIONS']._serialized_start=4965
  _globals['_LISTRELATIONS']._serialized_end=5082
  _globals['_LISTRELATIONSMSG']._serialized_start=5085
  _globals['_LISTRELATIONSMSG']._serialized_end=5234
  _globals['_CONNECTIONUSED']._serialized_start=5236
  _globals['_CONNECTIONUSED']._serialized_end=5358
  _globals['_CONNECTIONUSEDMSG']._serialized_start=5361
  _globals['_CONNECTIONUSEDMSG']._serialized_end=5512
  _globals['_SQLQUERY']._serialized_start=5514
  _globals['_SQLQUERY']._serialized_end=5624
  _globals['_SQLQUERYMSG']._serialized_start=5627
  _globals['_SQLQUERYMSG']._serialized_end=5766
  _globals['_SQLQUERYSTATUS']._serialized_start=5769
  _globals['_SQLQUERYSTATUS']._serialized_end=5904
  _globals['_SQLQUERYSTATUSMSG']._serialized_start=5907
  _globals['_SQLQUERYSTATUSMSG']._serialized_end=6058
  _globals['_SQLCOMMIT']._serialized_start=6060
  _globals['_SQLCOMMIT']._serialized_end=6158
  _globals['_SQLCOMMITMSG']._serialized_start=6161
  _globals['_SQLCOMMITMSG']._serialized_end=6302
  _globals['_COLTYPECHANGE']._serialized_start=6304
  _globals['_COLTYPECHANGE']._serialized_end=6420
  _globals['_COLTYPECHANGEMSG']._serialized_start=6423
  _globals['_COLTYPECHANGEMSG']._serialized_end=6572
  _globals['_SCHEMACREATION']._serialized_start=6574
  _globals['_SCHEMACREATION']._serialized_end=6657
  _globals['_SCHEMACREATIONMSG']._serialized_start=6660
  _globals['_SCHEMACREATIONMSG']._serialized_end=6811
  _globals['_SCHEMADROP']._serialized_start=6813
  _globals['_SCHEMADROP']._serialized_end=6892
  _globals['_SCHEMADROPMSG']._serialized_start=6895
  _globals['_SCHEMADROPMSG']._serialized_end=7038
  _globals['_CACHEACTION']._serialized_start=7041
  _globals['_CACHEACTION']._serialized_end=7339
  _globals['_CACHEACTIONMSG']._serialized_start=7342
  _globals['_CACHEACTIONMSG']._serialized_end=7487
  _globals['_CACHEDUMPGRAPH']._serialized_start=7490
  _globals['_CACHEDUMPGRAPH']._serialized_end=7661
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_start=7618
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_end=7661
  _globals['_CACHEDUMPGRAPHMSG']._serialized_start=7664
  _globals['_CACHEDUMPGRAPHMSG']._serialized_end=7815
  _globals['_ADAPTERREGISTERED']._serialized_start=7817
  _globals['_ADAPTERREGISTERED']._serialized_end=7883
  _globals['_ADAPTERREGISTEREDMSG']._serialized_start=7886
  _globals['_ADAPTERREGISTEREDMSG']._serialized_end=8043
  _globals['_ADAPTERIMPORTERROR']._serialized_start=8045
  _globals['_ADAPTERIMPORTERROR']._serialized_end=8078
  _globals['_ADAPTERIMPORTERRORMSG']._serialized_start=8081
  _globals['_ADAPTERIMPORTERRORMSG']._serialized_end=8240
  _globals['_PLUGINLOADERROR']._serialized_start=8242
  _globals['_PLUGINLOADERROR']._serialized_end=8277
  _globals['_PLUGINLOADERRORMSG']._serialized_start=8280
  _globals['_PLUGINLOADERRORMSG']._serialized_end=8433
  _globals['_NEWCONNECTIONOPENING']._serialized_start=8435
  _globals['_NEWCONNECTIONOPENING']._serialized_end=8551
  _globals['_NEWCONNECTIONOPENINGMSG']._serialized_start=8554
  _globals['_NEWCONNECTIONOPENINGMSG']._serialized_end=8717
  _globals['_CODEEXECUTION']._serialized_start=8719
  _globals['_CODEEXECUTION']._serialized_end=8775
  _globals['_CODEEXECUTIONMSG']._serialized_start=8778
  _globals['_CODEEXECUTIONMSG']._serialized_end=8927
  _globals['_CODEEXECUTIONSTATUS']._serialized_start=8929
  _globals['_CODEEXECUTIONSTATUS']._serialized_end=8983
  _globals['_CODEEXECUTIONSTATUSMSG']._serialized_start=8986
  _globals['_CODEEXECUTIONSTATUSMSG']._serialized_end=9147
  _globals['_CATALOGGENERATIONERROR']._serialized_start=9149
  _globals['_CATALOGGENERATIONERROR']._serialized_end=9186
  _globals['_CATALOGGENERATIONERRORMSG']._serialized_start=9189
  _globals['_CATALOGGENERATIONERRORMSG']._serialized_end=9356
  _globals['_WRITECATALOGFAILURE']._serialized_start=9358
  _globals['_WRITECATALOGFAILURE']._serialized_end=9403
  _globals['_WRITECATALOGFAILUREMSG']._serialized_start=9406
  _globals['_WRITECATALOGFAILUREMSG']._serialized_end=9567
  _globals['_CATALOGWRITTEN']._serialized_start=9569
  _globals['_CATALOGWRITTEN']._serialized_end=9599
  _globals['_CATALOGWRITTENMSG']._serialized_start=9602
  _globals['_CATALOGWRITTENMSG']._serialized_end=9753
  _globals['_CANNOTGENERATEDOCS']._serialized_start=9755
  _globals['_CANNOTGENERATEDOCS']._serialized_end=9775
  _globals['_CANNOTGENERATEDOCSMSG']._serialized_start=9778
  _globals['_CANNOTGENERATEDOCSMSG']._serialized_end=9937
  _globals['_BUILDINGCATALOG']._serialized_start=9939
  _globals['_BUILDINGCATALOG']._serialized_end=9956
  _globals['_BUILDINGCATALOGMSG']._serialized_start=9959
  _globals['_BUILDINGCATALOGMSG']._serialized_end=10112
  _globals['_DATABASEERRORRUNNINGHOOK']._serialized_start=10114
  _globals['_DATABASEERRORRUNNINGHOOK']._serialized_end=10159
  _globals['_DATABASEERRORRUNNINGHOOKMSG']._serialized_start=10162
  _globals['_DATABASEERRORRUNNINGHOOKMSG']._serialized_end=10333
  _globals['_HOOKSRUNNING']._serialized_start=10335
  _globals['_HOOKSRUNNING']._serialized_end=10387
  _globals['_HOOKSRUNNINGMSG']._serialized_start=10390
  _globals['_HOOKSRUNNINGMSG']._serialized_end=10537
  _globals['_FINISHEDRUNNINGSTATS']._serialized_start=10539
  _globals['_FINISHEDRUNNINGSTATS']._serialized_end=10623
  _globals['_FINISHEDRUNNINGSTATSMSG']._serialized_start=10626
  _globals['_FINISHEDRUNNINGSTATSMSG']._serialized_end=10789
  _globals['_CONSTRAINTNOTENFORCED']._serialized_start=10791
  _globals['_CONSTRAINTNOTENFORCED']._serialized_end=10851
  _globals['_CONSTRAINTNOTENFORCEDMSG']._serialized_start=10854
  _globals['_CONSTRAINTNOTENFORCEDMSG']._serialized_end=11019
  _globals['_CONSTRAINTNOTSUPPORTED']._serialized_start=11021
  _globals['_CONSTRAINTNOTSUPPORTED']._serialized_end=11082
  _globals['_CONSTRAINTNOTSUPPORTEDMSG']._serialized_start=11085
  _globals['_CONSTRAINTNOTSUPPORTEDMSG']._serialized_end=11252
  _globals['_TYPECODENOTFOUND']._serialized_start=11254
  _globals['_TYPECODENOTFOUND']._serialized_end=11291
  _globals['_TYPECODENOTFOUNDMSG']._serialized_start=11294
  _globals['_TYPECODENOTFOUNDMSG']._serialized_end=11449
# @@protoc_insertion_point(module_scope)
