# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/mcp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2
from dbtlabs.proto.public.v1.common import vortex_telemetry_contexts_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__telemetry__contexts__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dbtlabs/proto/public/v1/events/mcp.proto\x12\x14v1.public.events.mcp\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\x1a>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xcc\x05\n\nToolCalled\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rstart_time_ms\x18\x03 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x04 \x01(\x03\x12\x11\n\ttool_name\x18\x05 \x01(\t\x12\x42\n\targuments\x18\x06 \x03(\x0b\x32/.v1.public.events.mcp.ToolCalled.ArgumentsEntry\x12\x15\n\rerror_message\x18\x07 \x01(\t\x12$\n\x1c\x64\x62t_cloud_environment_id_dev\x18\x08 \x01(\t\x12%\n\x1d\x64\x62t_cloud_environment_id_prod\x18\t \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\n \x01(\t\x12\x15\n\rlocal_user_id\x18\x0b \x01(\t\x12\x0c\n\x04host\x18\x0c \x01(\t\x12 \n\x18multicell_account_prefix\x18\r \x01(\t\x12W\n\x03\x63tx\x18\x0e \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x17\n\x0f\x64\x62t_mcp_version\x18\x0f \x01(\t\x12\x1d\n\x15\x61uthentication_method\x18\x10 \x01(\t\x12\x10\n\x08trace_id\x18\x11 \x01(\t\x12\x19\n\x11\x64isabled_toolsets\x18\x12 \x03(\t\x12\x16\n\x0e\x64isabled_tools\x18\x13 \x03(\t\x12\x12\n\nuser_agent\x18\x14 \x01(\t\x1a\x30\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42\x37Z5github.com/dbt-labs/proto-golang/v1/public/events/mcpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/dbt-labs/proto-golang/v1/public/events/mcp'
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._loaded_options = None
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._serialized_options = b'8\001'
  _globals['_TOOLCALLED']._loaded_options = None
  _globals['_TOOLCALLED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_TOOLCALLED']._serialized_start=259
  _globals['_TOOLCALLED']._serialized_end=975
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._serialized_start=917
  _globals['_TOOLCALLED_ARGUMENTSENTRY']._serialized_end=965
# @@protoc_insertion_point(module_scope)
