"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SeverityNumber:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SeverityNumberEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SeverityNumber.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SEVERITY_NUMBER_UNSPECIFIED: _SeverityNumber.ValueType  # 0
    """Default value. Should not be used."""
    SEVERITY_NUMBER_TRACE: _SeverityNumber.ValueType  # 1
    SEVERITY_NUMBER_DEBUG: _SeverityNumber.ValueType  # 5
    SEVERITY_NUMBER_INFO: _SeverityNumber.ValueType  # 9
    SEVERITY_NUMBER_WARN: _SeverityNumber.ValueType  # 13
    SEVERITY_NUMBER_ERROR: _SeverityNumber.ValueType  # 17

class SeverityNumber(_SeverityNumber, metaclass=_SeverityNumberEnumTypeWrapper):
    """Subset of OTLP LogRecord.SeverityNumber used by fusion."""

SEVERITY_NUMBER_UNSPECIFIED: SeverityNumber.ValueType  # 0
"""Default value. Should not be used."""
SEVERITY_NUMBER_TRACE: SeverityNumber.ValueType  # 1
SEVERITY_NUMBER_DEBUG: SeverityNumber.ValueType  # 5
SEVERITY_NUMBER_INFO: SeverityNumber.ValueType  # 9
SEVERITY_NUMBER_WARN: SeverityNumber.ValueType  # 13
SEVERITY_NUMBER_ERROR: SeverityNumber.ValueType  # 17
Global___SeverityNumber: typing_extensions.TypeAlias = SeverityNumber
