"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ListOutputFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ListOutputFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ListOutputFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LIST_OUTPUT_FORMAT_UNSPECIFIED: _ListOutputFormat.ValueType  # 0
    LIST_OUTPUT_FORMAT_JSON: _ListOutputFormat.ValueType  # 1
    LIST_OUTPUT_FORMAT_SELECTOR: _ListOutputFormat.ValueType  # 2
    LIST_OUTPUT_FORMAT_NAME: _ListOutputFormat.ValueType  # 3
    LIST_OUTPUT_FORMAT_PATH: _ListOutputFormat.ValueType  # 4

class ListOutputFormat(_ListOutputFormat, metaclass=_ListOutputFormatEnumTypeWrapper):
    """Output format for list command"""

LIST_OUTPUT_FORMAT_UNSPECIFIED: ListOutputFormat.ValueType  # 0
LIST_OUTPUT_FORMAT_JSON: ListOutputFormat.ValueType  # 1
LIST_OUTPUT_FORMAT_SELECTOR: ListOutputFormat.ValueType  # 2
LIST_OUTPUT_FORMAT_NAME: ListOutputFormat.ValueType  # 3
LIST_OUTPUT_FORMAT_PATH: ListOutputFormat.ValueType  # 4
Global___ListOutputFormat: typing_extensions.TypeAlias = ListOutputFormat

@typing.final
class ListItemOutput(google.protobuf.message.Message):
    """Event emitted for each item in a list command output.
    This event replaces the dbt-core PrintEvent (Z052) for list operations.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    output_format: Global___ListOutputFormat.ValueType
    """Format of the output"""
    content: builtins.str
    """The actual content of the list item being displayed"""
    unique_id: builtins.str
    """The unique_id of the node being listed (e.g., "model.my_project.my_model")"""
    def __init__(
        self,
        *,
        output_format: Global___ListOutputFormat.ValueType = ...,
        content: builtins.str = ...,
        unique_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "content", b"content", "output_format", b"output_format", "unique_id", b"unique_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___ListItemOutput: typing_extensions.TypeAlias = ListItemOutput
