# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/phase/phase.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/phase/phase.proto\x12\x1dv1.public.events.fusion.phase\"\xed\x01\n\rPhaseExecuted\x12<\n\x05phase\x18\x01 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhase\x12\x1d\n\x10node_count_total\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1f\n\x12node_count_skipped\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10node_count_error\x18\x04 \x01(\x04H\x02\x88\x01\x01\x42\x13\n\x11_node_count_totalB\x15\n\x13_node_count_skippedB\x13\n\x11_node_count_error*\x8f\x04\n\x0e\x45xecutionPhase\x12\x1f\n\x1b\x45XECUTION_PHASE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45XECUTION_PHASE_CLEAN\x10\n\x12 \n\x1c\x45XECUTION_PHASE_LOAD_PROJECT\x10\x14\x12\x19\n\x15\x45XECUTION_PHASE_PARSE\x10\x1e\x12\x1c\n\x18\x45XECUTION_PHASE_SCHEDULE\x10(\x12\x1b\n\x17\x45XECUTION_PHASE_COMPARE\x10-\x12 \n\x1c\x45XECUTION_PHASE_INIT_ADAPTER\x10\x32\x12#\n\x1f\x45XECUTION_PHASE_DEFER_HYDRATION\x10<\x12$\n EXECUTION_PHASE_TASK_GRAPH_BUILD\x10\x46\x12(\n$EXECUTION_PHASE_NODE_CACHE_HYDRATION\x10P\x12\x1a\n\x16\x45XECUTION_PHASE_RENDER\x10Z\x12\x1b\n\x17\x45XECUTION_PHASE_ANALYZE\x10\x64\x12\x17\n\x13\x45XECUTION_PHASE_RUN\x10n\x12&\n\"EXECUTION_PHASE_FRESHNESS_ANALYSIS\x10x\x12\x1c\n\x17\x45XECUTION_PHASE_LINEAGE\x10\x82\x01\x12\x1a\n\x15\x45XECUTION_PHASE_DEBUG\x10\x8c\x01\x42@Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/phaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/phase'
  _globals['_EXECUTIONPHASE']._serialized_start=331
  _globals['_EXECUTIONPHASE']._serialized_end=858
  _globals['_PHASEEXECUTED']._serialized_start=91
  _globals['_PHASEEXECUTED']._serialized_end=328
# @@protoc_insertion_point(module_scope)
