# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events import fusion_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAdbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto\x12\"v1.public.events.fusion.onboarding\x1a+dbtlabs/proto/public/v1/events/fusion.proto\"R\n\x15OnboardingScreenShown\x12\x39\n\x06screen\x18\x01 \x01(\x0e\x32).v1.public.events.fusion.OnboardingScreenBEZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboardingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.onboarding.onboarding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboarding'
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_start=150
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_end=232
# @@protoc_insertion_point(module_scope)
