# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/dev/dev.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3dbtlabs/proto/public/v1/events/fusion/dev/dev.proto\x12\x1bv1.public.events.fusion.dev\"[\n\nDebugValue\x12\x11\n\x07\x66loat64\x18\x01 \x01(\x01H\x00\x12\x0e\n\x04\x62ool\x18\x04 \x01(\x08H\x00\x12\x10\n\x06string\x18\x05 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x06 \x01(\x0cH\x00\x42\x07\n\x05value\"\xea\x01\n\tCallTrace\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x04\x66ile\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04line\x18\x03 \x01(\rH\x01\x88\x01\x01\x12@\n\x05\x65xtra\x18\x04 \x03(\x0b\x32\x31.v1.public.events.fusion.dev.CallTrace.ExtraEntry\x1aU\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.v1.public.events.fusion.dev.DebugValue:\x02\x38\x01\x42\x07\n\x05_fileB\x07\n\x05_line\"3\n\x07Unknown\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0c\n\x04line\x18\x03 \x01(\rB>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/devb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.dev.dev_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/dev'
  _globals['_CALLTRACE_EXTRAENTRY']._loaded_options = None
  _globals['_CALLTRACE_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_DEBUGVALUE']._serialized_start=84
  _globals['_DEBUGVALUE']._serialized_end=175
  _globals['_CALLTRACE']._serialized_start=178
  _globals['_CALLTRACE']._serialized_end=412
  _globals['_CALLTRACE_EXTRAENTRY']._serialized_start=309
  _globals['_CALLTRACE_EXTRAENTRY']._serialized_end=394
  _globals['_UNKNOWN']._serialized_start=414
  _globals['_UNKNOWN']._serialized_end=465
# @@protoc_insertion_point(module_scope)
