# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/fusion.proto\x12\x17v1.public.events.fusion\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xb0\x01\n\x0b\x41\x64\x61pterInfo\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x04 \x01(\t\x12\x19\n\x11\x61\x64\x61pter_unique_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xe9\x02\n\rAdapterInfoV2\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x14\n\x0crun_model_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_name\x18\x04 \x01(\t\x12\x1c\n\x14\x62\x61se_adapter_version\x18\x05 \x01(\t\x12\x17\n\x0f\x61\x64\x61pter_version\x18\x06 \x01(\t\x12^\n\x15model_adapter_details\x18\x07 \x03(\x0b\x32?.v1.public.events.fusion.AdapterInfoV2.ModelAdapterDetailsEntry\x1a:\n\x18ModelAdapterDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x84\x02\n\nInvocation\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x06 \x01(\t\x12\x10\n\x08progress\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\t\x12\x13\n\x0bresult_type\x18\t \x01(\t\x12\x16\n\x0egit_commit_sha\x18\n \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x96\x01\n\rInvocationEnv\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb1\x01\n\x0ePackageInstall\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x82\x03\n\x0eResourceCounts\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x0e\n\x06models\x18\x04 \x01(\x05\x12\r\n\x05tests\x18\x05 \x01(\x05\x12\x11\n\tsnapshots\x18\x06 \x01(\x05\x12\x10\n\x08\x61nalyses\x18\x07 \x01(\x05\x12\x0e\n\x06macros\x18\x08 \x01(\x05\x12\x12\n\noperations\x18\t \x01(\x05\x12\r\n\x05seeds\x18\n \x01(\x05\x12\x0f\n\x07sources\x18\x0b \x01(\x05\x12\x11\n\texposures\x18\x0c \x01(\x05\x12\x0f\n\x07metrics\x18\r \x01(\x05\x12\x0e\n\x06groups\x18\x0e \x01(\x05\x12\x12\n\nunit_tests\x18\x0f \x01(\x05\x12\x17\n\x0fsemantic_models\x18\x10 \x01(\x05\x12\x15\n\rsaved_queries\x18\x11 \x01(\x05:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xf5\x03\n\x08RunModel\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x01\x12\x12\n\nrun_status\x18\x07 \x01(\t\x12\x13\n\x0brun_skipped\x18\x08 \x01(\x08\x12\x1d\n\x15model_materialization\x18\t \x01(\t\x12\"\n\x1amodel_incremental_strategy\x18\n \x01(\t\x12\x10\n\x08model_id\x18\x0b \x01(\t\x12\x17\n\x0fhashed_contents\x18\x0c \x01(\t\x12\x10\n\x08language\x18\r \x01(\t\x12\x11\n\thas_group\x18\x0e \x01(\x08\x12\x19\n\x11\x63ontract_enforced\x18\x0f \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x10 \x01(\t\x12\x11\n\tversioned\x18\x11 \x01(\x08\x12\x1a\n\x12run_skipped_reason\x18\x12 \x01(\t\x12\x14\n\x0crun_model_id\x18\x13 \x01(\t\x12\x15\n\rresource_type\x18\x14 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x96\x02\n\nOnboarding\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x15\n\rinvocation_id\x18\x03 \x01(\t\x12\x39\n\x06screen\x18\x04 \x01(\x0e\x32).v1.public.events.fusion.OnboardingScreen\x12\x39\n\x06\x61\x63tion\x18\x05 \x01(\x0e\x32).v1.public.events.fusion.OnboardingAction\x12\x0f\n\x07success\x18\x06 \x01(\x08\x12\x0f\n\x07user_id\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01*\xf2\x02\n\x10OnboardingScreen\x12\x16\n\x12SCREEN_UNSPECIFIED\x10\x00\x12\x0b\n\x07WELCOME\x10\x01\x12\x11\n\rPROFILE_CHECK\x10\x02\x12\x11\n\rPROFILE_FOUND\x10\x03\x12\x11\n\rPROFILE_SETUP\x10\x04\x12\x10\n\x0cLINK_ACCOUNT\x10\x05\x12\r\n\tDBT_PARSE\x10\x06\x12\x17\n\x13PARSE_ERROR_AUTOFIX\x10\x07\x12\x13\n\x0f\x44\x42T_PARSE_RETRY\x10\x08\x12\x14\n\x10PARSE_ERROR_FAIL\x10\t\x12\x11\n\rCOMPILE_NO_SA\x10\n\x12\x16\n\x12\x43OMPILE_NO_SA_FAIL\x10\x0b\x12\x0b\n\x07\x43OMPILE\x10\x0c\x12\x10\n\x0c\x43OMPILE_FAIL\x10\r\x12\x0b\n\x07SUCCESS\x10\x0e\x12\x13\n\x0f\x41GENTIC_AUTOFIX\x10\x0f\x12\x17\n\x13TRY_AGENTIC_AUTOFIX\x10\x10\x12\x16\n\x12\x44OWNLOAD_AGENTS_MD\x10\x11*\x93\x01\n\x10OnboardingAction\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\r\n\tINITIATED\x10\x01\x12\x10\n\x0cSCREEN_SHOWN\x10\x02\x12\x0f\n\x0bRUN_STARTED\x10\x03\x12\x10\n\x0cRUN_FINISHED\x10\x04\x12\x12\n\x0eSTEP_COMPLETED\x10\x05\x12\x0f\n\x0bSTEP_FAILED\x10\x06\x42:Z8github.com/dbt-labs/proto-golang/v1/public/events/fusionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dbt-labs/proto-golang/v1/public/events/fusion'
  _globals['_ADAPTERINFO']._loaded_options = None
  _globals['_ADAPTERINFO']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._loaded_options = None
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._serialized_options = b'8\001'
  _globals['_ADAPTERINFOV2']._loaded_options = None
  _globals['_ADAPTERINFOV2']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_INVOCATION']._loaded_options = None
  _globals['_INVOCATION']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_INVOCATIONENV']._loaded_options = None
  _globals['_INVOCATIONENV']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_PACKAGEINSTALL']._loaded_options = None
  _globals['_PACKAGEINSTALL']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_RESOURCECOUNTS']._loaded_options = None
  _globals['_RESOURCECOUNTS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_RUNMODEL']._loaded_options = None
  _globals['_RUNMODEL']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ONBOARDING']._loaded_options = None
  _globals['_ONBOARDING']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ONBOARDINGSCREEN']._serialized_start=2484
  _globals['_ONBOARDINGSCREEN']._serialized_end=2854
  _globals['_ONBOARDINGACTION']._serialized_start=2857
  _globals['_ONBOARDINGACTION']._serialized_end=3004
  _globals['_ADAPTERINFO']._serialized_start=171
  _globals['_ADAPTERINFO']._serialized_end=347
  _globals['_ADAPTERINFOV2']._serialized_start=350
  _globals['_ADAPTERINFOV2']._serialized_end=711
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._serialized_start=643
  _globals['_ADAPTERINFOV2_MODELADAPTERDETAILSENTRY']._serialized_end=701
  _globals['_INVOCATION']._serialized_start=714
  _globals['_INVOCATION']._serialized_end=974
  _globals['_INVOCATIONENV']._serialized_start=977
  _globals['_INVOCATIONENV']._serialized_end=1127
  _globals['_PACKAGEINSTALL']._serialized_start=1130
  _globals['_PACKAGEINSTALL']._serialized_end=1307
  _globals['_RESOURCECOUNTS']._serialized_start=1310
  _globals['_RESOURCECOUNTS']._serialized_end=1696
  _globals['_RUNMODEL']._serialized_start=1699
  _globals['_RUNMODEL']._serialized_end=2200
  _globals['_ONBOARDING']._serialized_start=2203
  _globals['_ONBOARDING']._serialized_end=2481
# @@protoc_insertion_point(module_scope)
