# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/update/update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9dbtlabs/proto/public/v1/events/fusion/update/update.proto\x12\x1ev1.public.events.fusion.update\"U\n\rPackageUpdate\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0f\n\x07package\x18\x02 \x01(\t\x12\x15\n\x08\x65xe_path\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_exe_pathBAZ?github.com/dbt-labs/proto-golang/v1/public/events/fusion/updateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.update.update_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dbt-labs/proto-golang/v1/public/events/fusion/update'
  _globals['_PACKAGEUPDATE']._serialized_start=93
  _globals['_PACKAGEUPDATE']._serialized_end=178
# @@protoc_insertion_point(module_scope)
