# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/show_data.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9dbtlabs/proto/public/v1/events/fusion/log/show_data.proto\x12\x1bv1.public.events.fusion.log\"\xe5\x01\n\x0eShowDataOutput\x12H\n\routput_format\x18\x01 \x01(\x0e\x32\x31.v1.public.events.fusion.log.ShowDataOutputFormat\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x11\n\tis_inline\x18\x04 \x01(\x08\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07\x63olumns\x18\x06 \x03(\t\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x07 \x01(\tB\x0c\n\n_unique_id*\x8a\x02\n\x14ShowDataOutputFormat\x12\'\n#SHOW_DATA_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12 \n\x1cSHOW_DATA_OUTPUT_FORMAT_TEXT\x10\x01\x12\x1f\n\x1bSHOW_DATA_OUTPUT_FORMAT_CSV\x10\x02\x12\x1f\n\x1bSHOW_DATA_OUTPUT_FORMAT_TSV\x10\x03\x12 \n\x1cSHOW_DATA_OUTPUT_FORMAT_JSON\x10\x04\x12\"\n\x1eSHOW_DATA_OUTPUT_FORMAT_NDJSON\x10\x05\x12\x1f\n\x1bSHOW_DATA_OUTPUT_FORMAT_YML\x10\x06\x42>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.show_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_SHOWDATAOUTPUTFORMAT']._serialized_start=323
  _globals['_SHOWDATAOUTPUTFORMAT']._serialized_end=589
  _globals['_SHOWDATAOUTPUT']._serialized_start=91
  _globals['_SHOWDATAOUTPUT']._serialized_end=320
# @@protoc_insertion_point(module_scope)
