"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompiledCodeInline(google.protobuf.message.Message):
    """Log event that carries inline compiled SQL code."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_FIELD_NUMBER: builtins.int
    sql: builtins.str
    def __init__(
        self,
        *,
        sql: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sql", b"sql"]) -> None: ...

Global___CompiledCodeInline: typing_extensions.TypeAlias = CompiledCodeInline
