"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class VortexTelemetryDbtCloudContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_ID_FIELD_NUMBER: builtins.int
    FEATURE_FIELD_NUMBER: builtins.int
    SNOWPLOW_DOMAIN_SESSION_ID_FIELD_NUMBER: builtins.int
    SNOWPLOW_DOMAIN_USER_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    REFERRER_URL_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ACCOUNT_IDENTIFIER_FIELD_NUMBER: builtins.int
    DBT_CLOUD_PROJECT_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    DBT_CLOUD_USER_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    feature: builtins.str
    """feature/product name emitting the telemetry event"""
    snowplow_domain_session_id: builtins.str
    """The snowplow domain session ID. This can be used to join these events with snowplow events."""
    snowplow_domain_user_id: builtins.str
    """The snowplow domain user ID. This can be used to join these events with snowplow events."""
    session_id: builtins.str
    """A session ID that can be used to correlate events that were emmitted by the same
    user during the same session.
    """
    referrer_url: builtins.str
    """The URL of the page the user was on when telemetry event was sent"""
    dbt_cloud_account_id: builtins.str
    """dbt Cloud account ID"""
    dbt_cloud_account_identifier: builtins.str
    """dbt Cloud account identifier"""
    dbt_cloud_project_id: builtins.str
    """dbt Cloud project ID"""
    dbt_cloud_environment_id: builtins.str
    """dbt Cloud environment ID"""
    dbt_cloud_user_id: builtins.str
    """dbt Cloud user ID"""
    def __init__(
        self,
        *,
        event_id: builtins.str = ...,
        feature: builtins.str = ...,
        snowplow_domain_session_id: builtins.str = ...,
        snowplow_domain_user_id: builtins.str = ...,
        session_id: builtins.str = ...,
        referrer_url: builtins.str = ...,
        dbt_cloud_account_id: builtins.str = ...,
        dbt_cloud_account_identifier: builtins.str = ...,
        dbt_cloud_project_id: builtins.str = ...,
        dbt_cloud_environment_id: builtins.str = ...,
        dbt_cloud_user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dbt_cloud_account_id", b"dbt_cloud_account_id", "dbt_cloud_account_identifier", b"dbt_cloud_account_identifier", "dbt_cloud_environment_id", b"dbt_cloud_environment_id", "dbt_cloud_project_id", b"dbt_cloud_project_id", "dbt_cloud_user_id", b"dbt_cloud_user_id", "event_id", b"event_id", "feature", b"feature", "referrer_url", b"referrer_url", "session_id", b"session_id", "snowplow_domain_session_id", b"snowplow_domain_session_id", "snowplow_domain_user_id", b"snowplow_domain_user_id"]) -> None: ...

Global___VortexTelemetryDbtCloudContext: typing_extensions.TypeAlias = VortexTelemetryDbtCloudContext
