# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/node/node.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dbtlabs/proto/public/v1/events/fusion/node/node.proto\x12\x1cv1.public.events.fusion.node\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\x95\x01\n\x14TestEvaluationDetail\x12?\n\x0ctest_outcome\x18\x01 \x01(\x0e\x32).v1.public.events.fusion.node.TestOutcome\x12\x14\n\x0c\x66\x61iling_rows\x18\x02 \x01(\x05\x12\x17\n\ndiff_table\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_diff_table\"m\n\x15SourceFreshnessDetail\x12T\n\x16node_freshness_outcome\x18\x01 \x01(\x0e\x32\x34.v1.public.events.fusion.node.SourceFreshnessOutcome\"[\n\x0fNodeCacheDetail\x12H\n\x11node_cache_reason\x18\x01 \x01(\x0e\x32-.v1.public.events.fusion.node.NodeCacheReason\"4\n\x16NodeSkipUpstreamDetail\x12\x1a\n\x12upstream_unique_id\x18\x01 \x01(\t\"\xc3\t\n\rNodeEvaluated\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\x08\x64\x61tabase\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06schema\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nidentifier\x18\x05 \x01(\tH\x03\x88\x01\x01\x12O\n\x0fmaterialization\x18\x07 \x01(\x0e\x32\x31.v1.public.events.fusion.node.NodeMaterializationH\x04\x88\x01\x01\x12#\n\x16\x63ustom_materialization\x18\x08 \x01(\tH\x05\x88\x01\x01\x12\x39\n\tnode_type\x18\t \x01(\x0e\x32&.v1.public.events.fusion.node.NodeType\x12?\n\x0cnode_outcome\x18\n \x01(\x0e\x32).v1.public.events.fusion.node.NodeOutcome\x12<\n\x05phase\x18\x0b \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhase\x12I\n\x0fnode_error_type\x18\x14 \x01(\x0e\x32+.v1.public.events.fusion.node.NodeErrorTypeH\x06\x88\x01\x01\x12O\n\x12node_cancel_reason\x18\x15 \x01(\x0e\x32..v1.public.events.fusion.node.NodeCancelReasonH\x07\x88\x01\x01\x12K\n\x10node_skip_reason\x18\x16 \x01(\x0e\x32,.v1.public.events.fusion.node.NodeSkipReasonH\x08\x88\x01\x01\x12J\n\x11node_cache_detail\x18\x1e \x01(\x0b\x32-.v1.public.events.fusion.node.NodeCacheDetailH\x00\x12N\n\x10node_test_detail\x18\x1f \x01(\x0b\x32\x32.v1.public.events.fusion.node.TestEvaluationDetailH\x00\x12U\n\x16node_freshness_outcome\x18  \x01(\x0b\x32\x33.v1.public.events.fusion.node.SourceFreshnessDetailH\x00\x12Y\n\x19node_skip_upstream_detail\x18! \x01(\x0b\x32\x34.v1.public.events.fusion.node.NodeSkipUpstreamDetailH\x00\x12 \n\x13\x64\x62t_core_event_code\x18( \x01(\tH\t\x88\x01\x01\x42\x15\n\x13node_outcome_detailB\x0b\n\t_databaseB\t\n\x07_schemaB\r\n\x0b_identifierB\x12\n\x10_materializationB\x19\n\x17_custom_materializationB\x12\n\x10_node_error_typeB\x15\n\x13_node_cancel_reasonB\x13\n\x11_node_skip_reasonB\x16\n\x14_dbt_core_event_code*\x88\x03\n\x08NodeType\x12\x19\n\x15NODE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fNODE_TYPE_MODEL\x10\x01\x12\x12\n\x0eNODE_TYPE_SEED\x10\x02\x12\x16\n\x12NODE_TYPE_SNAPSHOT\x10\x0b\x12\x14\n\x10NODE_TYPE_SOURCE\x10\x03\x12\x12\n\x0eNODE_TYPE_TEST\x10\x04\x12\x17\n\x13NODE_TYPE_UNIT_TEST\x10\x05\x12\x13\n\x0fNODE_TYPE_MACRO\x10\x06\x12\x18\n\x14NODE_TYPE_DOCS_MACRO\x10\x07\x12\x16\n\x12NODE_TYPE_ANALYSIS\x10\x08\x12\x17\n\x13NODE_TYPE_OPERATION\x10\t\x12\x16\n\x12NODE_TYPE_EXPOSURE\x10\n\x12\x14\n\x10NODE_TYPE_METRIC\x10\x0c\x12\x19\n\x15NODE_TYPE_SAVED_QUERY\x10\r\x12\x1c\n\x18NODE_TYPE_SEMANTIC_MODEL\x10\x0e\x12\x16\n\x12NODE_TYPE_FUNCTION\x10\x0f*\x92\x01\n\x0bNodeOutcome\x12\x1c\n\x18NODE_OUTCOME_UNSPECIFIED\x10\x00\x12\x18\n\x14NODE_OUTCOME_SUCCESS\x10\x01\x12\x16\n\x12NODE_OUTCOME_ERROR\x10\x02\x12\x19\n\x15NODE_OUTCOME_CANCELED\x10\x03\x12\x18\n\x14NODE_OUTCOME_SKIPPED\x10\x04*e\n\rNodeErrorType\x12\x1c\n\x18NODE_ERROR_TYPE_INTERNAL\x10\x00\x12\x1c\n\x18NODE_ERROR_TYPE_EXTERNAL\x10\x01\x12\x18\n\x14NODE_ERROR_TYPE_USER\x10\x02*9\n\x10NodeCancelReason\x12%\n!NODE_CANCEL_REASON_USER_CANCELLED\x10\x00*\xd3\x01\n\x0eNodeSkipReason\x12 \n\x1cNODE_SKIP_REASON_UNSPECIFIED\x10\x00\x12\x1d\n\x19NODE_SKIP_REASON_UPSTREAM\x10\x01\x12\x1b\n\x17NODE_SKIP_REASON_CACHED\x10\x02\x12#\n\x1fNODE_SKIP_REASON_PHASE_DISABLED\x10\x03\x12\x1a\n\x16NODE_SKIP_REASON_NO_OP\x10\x04\x12\"\n\x1eNODE_SKIP_REASON_PHASE_SKIPPED\x10\x05*\x85\x01\n\x0fNodeCacheReason\x12 \n\x1cNODE_CACHE_REASON_NO_CHANGES\x10\x00\x12!\n\x1dNODE_CACHE_REASON_STILL_FRESH\x10\x01\x12-\n)NODE_CACHE_REASON_UPDATE_CRITERIA_NOT_MET\x10\x02*\xc8\x04\n\x13NodeMaterialization\x12 \n\x1cNODE_MATERIALIZATION_UNKNOWN\x10\x00\x12!\n\x1dNODE_MATERIALIZATION_SNAPSHOT\x10\x01\x12\x1d\n\x19NODE_MATERIALIZATION_SEED\x10\x02\x12\x1d\n\x19NODE_MATERIALIZATION_VIEW\x10\x03\x12\x1e\n\x1aNODE_MATERIALIZATION_TABLE\x10\x04\x12$\n NODE_MATERIALIZATION_INCREMENTAL\x10\x05\x12*\n&NODE_MATERIALIZATION_MATERIALIZED_VIEW\x10\x06\x12!\n\x1dNODE_MATERIALIZATION_EXTERNAL\x10\x07\x12\x1d\n\x19NODE_MATERIALIZATION_TEST\x10\x08\x12\"\n\x1eNODE_MATERIALIZATION_EPHEMERAL\x10\t\x12\x1d\n\x19NODE_MATERIALIZATION_UNIT\x10\n\x12!\n\x1dNODE_MATERIALIZATION_ANALYSIS\x10\x0b\x12(\n$NODE_MATERIALIZATION_STREAMING_TABLE\x10\x0c\x12&\n\"NODE_MATERIALIZATION_DYNAMIC_TABLE\x10\r\x12!\n\x1dNODE_MATERIALIZATION_FUNCTION\x10\x0e\x12\x1f\n\x1bNODE_MATERIALIZATION_CUSTOM\x10\x64*X\n\x0bTestOutcome\x12\x17\n\x13TEST_OUTCOME_PASSED\x10\x00\x12\x17\n\x13TEST_OUTCOME_WARNED\x10\x01\x12\x17\n\x13TEST_OUTCOME_FAILED\x10\x02*\x9f\x01\n\x16SourceFreshnessOutcome\x12+\n\'SOURCE_FRESHNESS_OUTCOME_OUTCOME_PASSED\x10\x00\x12+\n\'SOURCE_FRESHNESS_OUTCOME_OUTCOME_WARNED\x10\x01\x12+\n\'SOURCE_FRESHNESS_OUTCOME_OUTCOME_FAILED\x10\x02\x42?Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.node.node_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/node'
  _globals['_NODETYPE']._serialized_start=1777
  _globals['_NODETYPE']._serialized_end=2169
  _globals['_NODEOUTCOME']._serialized_start=2172
  _globals['_NODEOUTCOME']._serialized_end=2318
  _globals['_NODEERRORTYPE']._serialized_start=2320
  _globals['_NODEERRORTYPE']._serialized_end=2421
  _globals['_NODECANCELREASON']._serialized_start=2423
  _globals['_NODECANCELREASON']._serialized_end=2480
  _globals['_NODESKIPREASON']._serialized_start=2483
  _globals['_NODESKIPREASON']._serialized_end=2694
  _globals['_NODECACHEREASON']._serialized_start=2697
  _globals['_NODECACHEREASON']._serialized_end=2830
  _globals['_NODEMATERIALIZATION']._serialized_start=2833
  _globals['_NODEMATERIALIZATION']._serialized_end=3417
  _globals['_TESTOUTCOME']._serialized_start=3419
  _globals['_TESTOUTCOME']._serialized_end=3507
  _globals['_SOURCEFRESHNESSOUTCOME']._serialized_start=3510
  _globals['_SOURCEFRESHNESSOUTCOME']._serialized_end=3669
  _globals['_TESTEVALUATIONDETAIL']._serialized_start=145
  _globals['_TESTEVALUATIONDETAIL']._serialized_end=294
  _globals['_SOURCEFRESHNESSDETAIL']._serialized_start=296
  _globals['_SOURCEFRESHNESSDETAIL']._serialized_end=405
  _globals['_NODECACHEDETAIL']._serialized_start=407
  _globals['_NODECACHEDETAIL']._serialized_end=498
  _globals['_NODESKIPUPSTREAMDETAIL']._serialized_start=500
  _globals['_NODESKIPUPSTREAMDETAIL']._serialized_end=552
  _globals['_NODEEVALUATED']._serialized_start=555
  _globals['_NODEEVALUATED']._serialized_end=1774
# @@protoc_insertion_point(module_scope)
