"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AdapterCommonEventInfo(google.protobuf.message.Message):
    """Common event info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    code: builtins.str
    msg: builtins.str
    level: builtins.str
    invocation_id: builtins.str
    pid: builtins.int
    thread: builtins.str
    category: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
        level: builtins.str = ...,
        invocation_id: builtins.str = ...,
        pid: builtins.int = ...,
        thread: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        category: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "code", b"code", "extra", b"extra", "invocation_id", b"invocation_id", "level", b"level", "msg", b"msg", "name", b"name", "pid", b"pid", "thread", b"thread", "ts", b"ts"]) -> None: ...

Global___AdapterCommonEventInfo: typing_extensions.TypeAlias = AdapterCommonEventInfo

@typing.final
class AdapterNodeRelation(google.protobuf.message.Message):
    """AdapterNodeRelation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    ALIAS_FIELD_NUMBER: builtins.int
    RELATION_NAME_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    alias: builtins.str
    relation_name: builtins.str
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        alias: builtins.str = ...,
        relation_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "database", b"database", "relation_name", b"relation_name", "schema", b"schema"]) -> None: ...

Global___AdapterNodeRelation: typing_extensions.TypeAlias = AdapterNodeRelation

@typing.final
class AdapterNodeInfo(google.protobuf.message.Message):
    """NodeInfo"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_PATH_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    MATERIALIZED_FIELD_NUMBER: builtins.int
    NODE_STATUS_FIELD_NUMBER: builtins.int
    NODE_STARTED_AT_FIELD_NUMBER: builtins.int
    NODE_FINISHED_AT_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    NODE_RELATION_FIELD_NUMBER: builtins.int
    NODE_CHECKSUM_FIELD_NUMBER: builtins.int
    node_path: builtins.str
    node_name: builtins.str
    unique_id: builtins.str
    resource_type: builtins.str
    materialized: builtins.str
    node_status: builtins.str
    node_started_at: builtins.str
    node_finished_at: builtins.str
    node_checksum: builtins.str
    @property
    def meta(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def node_relation(self) -> Global___AdapterNodeRelation: ...
    def __init__(
        self,
        *,
        node_path: builtins.str = ...,
        node_name: builtins.str = ...,
        unique_id: builtins.str = ...,
        resource_type: builtins.str = ...,
        materialized: builtins.str = ...,
        node_status: builtins.str = ...,
        node_started_at: builtins.str = ...,
        node_finished_at: builtins.str = ...,
        meta: google.protobuf.struct_pb2.Struct | None = ...,
        node_relation: Global___AdapterNodeRelation | None = ...,
        node_checksum: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta", "node_relation", b"node_relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["materialized", b"materialized", "meta", b"meta", "node_checksum", b"node_checksum", "node_finished_at", b"node_finished_at", "node_name", b"node_name", "node_path", b"node_path", "node_relation", b"node_relation", "node_started_at", b"node_started_at", "node_status", b"node_status", "resource_type", b"resource_type", "unique_id", b"unique_id"]) -> None: ...

Global___AdapterNodeInfo: typing_extensions.TypeAlias = AdapterNodeInfo

@typing.final
class ReferenceKeyMsg(google.protobuf.message.Message):
    """ReferenceKey"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    IDENTIFIER_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    identifier: builtins.str
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "identifier", b"identifier", "schema", b"schema"]) -> None: ...

Global___ReferenceKeyMsg: typing_extensions.TypeAlias = ReferenceKeyMsg

@typing.final
class AdapterDeprecationWarning(google.protobuf.message.Message):
    """D - Deprecations

    D005
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    old_name: builtins.str
    new_name: builtins.str
    def __init__(
        self,
        *,
        old_name: builtins.str = ...,
        new_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "old_name", b"old_name"]) -> None: ...

Global___AdapterDeprecationWarning: typing_extensions.TypeAlias = AdapterDeprecationWarning

@typing.final
class AdapterDeprecationWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterDeprecationWarning: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterDeprecationWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterDeprecationWarningMsg: typing_extensions.TypeAlias = AdapterDeprecationWarningMsg

@typing.final
class CollectFreshnessReturnSignature(google.protobuf.message.Message):
    """D012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CollectFreshnessReturnSignature: typing_extensions.TypeAlias = CollectFreshnessReturnSignature

@typing.final
class CollectFreshnessReturnSignatureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CollectFreshnessReturnSignature: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CollectFreshnessReturnSignature | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CollectFreshnessReturnSignatureMsg: typing_extensions.TypeAlias = CollectFreshnessReturnSignatureMsg

@typing.final
class AdapterEventDebug(google.protobuf.message.Message):
    """E - DB Adapter

    E001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventDebug: typing_extensions.TypeAlias = AdapterEventDebug

@typing.final
class AdapterEventDebugMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventDebug: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventDebug | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventDebugMsg: typing_extensions.TypeAlias = AdapterEventDebugMsg

@typing.final
class AdapterEventInfo(google.protobuf.message.Message):
    """E002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventInfo: typing_extensions.TypeAlias = AdapterEventInfo

@typing.final
class AdapterEventInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventInfo: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventInfoMsg: typing_extensions.TypeAlias = AdapterEventInfoMsg

@typing.final
class AdapterEventWarning(google.protobuf.message.Message):
    """E003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventWarning: typing_extensions.TypeAlias = AdapterEventWarning

@typing.final
class AdapterEventWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventWarning: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventWarningMsg: typing_extensions.TypeAlias = AdapterEventWarningMsg

@typing.final
class AdapterEventError(google.protobuf.message.Message):
    """E004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BASE_MSG_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    base_msg: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    @property
    def args(self) -> google.protobuf.struct_pb2.ListValue: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        name: builtins.str = ...,
        base_msg: builtins.str = ...,
        args: google.protobuf.struct_pb2.ListValue | None = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "base_msg", b"base_msg", "exc_info", b"exc_info", "name", b"name", "node_info", b"node_info"]) -> None: ...

Global___AdapterEventError: typing_extensions.TypeAlias = AdapterEventError

@typing.final
class AdapterEventErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterEventError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterEventError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterEventErrorMsg: typing_extensions.TypeAlias = AdapterEventErrorMsg

@typing.final
class NewConnection(google.protobuf.message.Message):
    """E005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_TYPE_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_type: builtins.str
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_type: builtins.str = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "conn_type", b"conn_type", "node_info", b"node_info"]) -> None: ...

Global___NewConnection: typing_extensions.TypeAlias = NewConnection

@typing.final
class NewConnectionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___NewConnection: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___NewConnection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NewConnectionMsg: typing_extensions.TypeAlias = NewConnectionMsg

@typing.final
class ConnectionReused(google.protobuf.message.Message):
    """E006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    ORIG_CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    orig_conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
        orig_conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "orig_conn_name", b"orig_conn_name"]) -> None: ...

Global___ConnectionReused: typing_extensions.TypeAlias = ConnectionReused

@typing.final
class ConnectionReusedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionReused: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionReused | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionReusedMsg: typing_extensions.TypeAlias = ConnectionReusedMsg

@typing.final
class ConnectionLeftOpenInCleanup(google.protobuf.message.Message):
    """E007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name"]) -> None: ...

Global___ConnectionLeftOpenInCleanup: typing_extensions.TypeAlias = ConnectionLeftOpenInCleanup

@typing.final
class ConnectionLeftOpenInCleanupMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionLeftOpenInCleanup: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionLeftOpenInCleanup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionLeftOpenInCleanupMsg: typing_extensions.TypeAlias = ConnectionLeftOpenInCleanupMsg

@typing.final
class ConnectionClosedInCleanup(google.protobuf.message.Message):
    """E008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name"]) -> None: ...

Global___ConnectionClosedInCleanup: typing_extensions.TypeAlias = ConnectionClosedInCleanup

@typing.final
class ConnectionClosedInCleanupMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionClosedInCleanup: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionClosedInCleanup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionClosedInCleanupMsg: typing_extensions.TypeAlias = ConnectionClosedInCleanupMsg

@typing.final
class RollbackFailed(google.protobuf.message.Message):
    """E009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "exc_info", b"exc_info", "node_info", b"node_info"]) -> None: ...

Global___RollbackFailed: typing_extensions.TypeAlias = RollbackFailed

@typing.final
class RollbackFailedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___RollbackFailed: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___RollbackFailed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RollbackFailedMsg: typing_extensions.TypeAlias = RollbackFailedMsg

@typing.final
class ConnectionClosed(google.protobuf.message.Message):
    """E010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___ConnectionClosed: typing_extensions.TypeAlias = ConnectionClosed

@typing.final
class ConnectionClosedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionClosed: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionClosed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionClosedMsg: typing_extensions.TypeAlias = ConnectionClosedMsg

@typing.final
class ConnectionLeftOpen(google.protobuf.message.Message):
    """E011"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___ConnectionLeftOpen: typing_extensions.TypeAlias = ConnectionLeftOpen

@typing.final
class ConnectionLeftOpenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionLeftOpen: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionLeftOpen | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionLeftOpenMsg: typing_extensions.TypeAlias = ConnectionLeftOpenMsg

@typing.final
class Rollback(google.protobuf.message.Message):
    """E012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___Rollback: typing_extensions.TypeAlias = Rollback

@typing.final
class RollbackMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___Rollback: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___Rollback | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RollbackMsg: typing_extensions.TypeAlias = RollbackMsg

@typing.final
class CacheMiss(google.protobuf.message.Message):
    """E013"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    database: builtins.str
    schema: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
        database: builtins.str = ...,
        schema: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "database", b"database", "schema", b"schema"]) -> None: ...

Global___CacheMiss: typing_extensions.TypeAlias = CacheMiss

@typing.final
class CacheMissMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CacheMiss: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CacheMiss | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CacheMissMsg: typing_extensions.TypeAlias = CacheMissMsg

@typing.final
class ListRelations(google.protobuf.message.Message):
    """E014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    RELATIONS_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    @property
    def relations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ReferenceKeyMsg]: ...
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        relations: collections.abc.Iterable[Global___ReferenceKeyMsg] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "relations", b"relations", "schema", b"schema"]) -> None: ...

Global___ListRelations: typing_extensions.TypeAlias = ListRelations

@typing.final
class ListRelationsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ListRelations: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ListRelations | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ListRelationsMsg: typing_extensions.TypeAlias = ListRelationsMsg

@typing.final
class ConnectionUsed(google.protobuf.message.Message):
    """E015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_TYPE_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_type: builtins.str
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_type: builtins.str = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "conn_type", b"conn_type", "node_info", b"node_info"]) -> None: ...

Global___ConnectionUsed: typing_extensions.TypeAlias = ConnectionUsed

@typing.final
class ConnectionUsedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConnectionUsed: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConnectionUsed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConnectionUsedMsg: typing_extensions.TypeAlias = ConnectionUsedMsg

@typing.final
class SQLQuery(google.protobuf.message.Message):
    """E016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    sql: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
        sql: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info", "sql", b"sql"]) -> None: ...

Global___SQLQuery: typing_extensions.TypeAlias = SQLQuery

@typing.final
class SQLQueryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SQLQuery: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SQLQuery | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLQueryMsg: typing_extensions.TypeAlias = SQLQueryMsg

@typing.final
class SQLQueryStatus(google.protobuf.message.Message):
    """E017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ELAPSED_FIELD_NUMBER: builtins.int
    QUERY_ID_FIELD_NUMBER: builtins.int
    status: builtins.str
    elapsed: builtins.float
    query_id: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        status: builtins.str = ...,
        elapsed: builtins.float = ...,
        query_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["elapsed", b"elapsed", "node_info", b"node_info", "query_id", b"query_id", "status", b"status"]) -> None: ...

Global___SQLQueryStatus: typing_extensions.TypeAlias = SQLQueryStatus

@typing.final
class SQLQueryStatusMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SQLQueryStatus: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SQLQueryStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLQueryStatusMsg: typing_extensions.TypeAlias = SQLQueryStatusMsg

@typing.final
class SQLCommit(google.protobuf.message.Message):
    """E018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name", "node_info", b"node_info"]) -> None: ...

Global___SQLCommit: typing_extensions.TypeAlias = SQLCommit

@typing.final
class SQLCommitMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SQLCommit: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SQLCommit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLCommitMsg: typing_extensions.TypeAlias = SQLCommitMsg

@typing.final
class ColTypeChange(google.protobuf.message.Message):
    """E019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIG_TYPE_FIELD_NUMBER: builtins.int
    NEW_TYPE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    orig_type: builtins.str
    new_type: builtins.str
    @property
    def table(self) -> Global___ReferenceKeyMsg: ...
    def __init__(
        self,
        *,
        orig_type: builtins.str = ...,
        new_type: builtins.str = ...,
        table: Global___ReferenceKeyMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_type", b"new_type", "orig_type", b"orig_type", "table", b"table"]) -> None: ...

Global___ColTypeChange: typing_extensions.TypeAlias = ColTypeChange

@typing.final
class ColTypeChangeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ColTypeChange: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ColTypeChange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ColTypeChangeMsg: typing_extensions.TypeAlias = ColTypeChangeMsg

@typing.final
class SchemaCreation(google.protobuf.message.Message):
    """E020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_FIELD_NUMBER: builtins.int
    @property
    def relation(self) -> Global___ReferenceKeyMsg: ...
    def __init__(
        self,
        *,
        relation: Global___ReferenceKeyMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["relation", b"relation"]) -> None: ...

Global___SchemaCreation: typing_extensions.TypeAlias = SchemaCreation

@typing.final
class SchemaCreationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SchemaCreation: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SchemaCreation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SchemaCreationMsg: typing_extensions.TypeAlias = SchemaCreationMsg

@typing.final
class SchemaDrop(google.protobuf.message.Message):
    """E021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_FIELD_NUMBER: builtins.int
    @property
    def relation(self) -> Global___ReferenceKeyMsg: ...
    def __init__(
        self,
        *,
        relation: Global___ReferenceKeyMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["relation", b"relation"]) -> None: ...

Global___SchemaDrop: typing_extensions.TypeAlias = SchemaDrop

@typing.final
class SchemaDropMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___SchemaDrop: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___SchemaDrop | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SchemaDropMsg: typing_extensions.TypeAlias = SchemaDropMsg

@typing.final
class CacheAction(google.protobuf.message.Message):
    """E022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    REF_KEY_FIELD_NUMBER: builtins.int
    REF_KEY_2_FIELD_NUMBER: builtins.int
    REF_KEY_3_FIELD_NUMBER: builtins.int
    REF_LIST_FIELD_NUMBER: builtins.int
    action: builtins.str
    @property
    def ref_key(self) -> Global___ReferenceKeyMsg: ...
    @property
    def ref_key_2(self) -> Global___ReferenceKeyMsg: ...
    @property
    def ref_key_3(self) -> Global___ReferenceKeyMsg: ...
    @property
    def ref_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ReferenceKeyMsg]: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        ref_key: Global___ReferenceKeyMsg | None = ...,
        ref_key_2: Global___ReferenceKeyMsg | None = ...,
        ref_key_3: Global___ReferenceKeyMsg | None = ...,
        ref_list: collections.abc.Iterable[Global___ReferenceKeyMsg] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ref_key", b"ref_key", "ref_key_2", b"ref_key_2", "ref_key_3", b"ref_key_3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "ref_key", b"ref_key", "ref_key_2", b"ref_key_2", "ref_key_3", b"ref_key_3", "ref_list", b"ref_list"]) -> None: ...

Global___CacheAction: typing_extensions.TypeAlias = CacheAction

@typing.final
class CacheActionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CacheAction: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CacheAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CacheActionMsg: typing_extensions.TypeAlias = CacheActionMsg

@typing.final
class CacheDumpGraph(google.protobuf.message.Message):
    """Skipping E023, E024, E025, E026, E027, E028, E029, E0230

    E031
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DumpEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DUMP_FIELD_NUMBER: builtins.int
    BEFORE_AFTER_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    before_after: builtins.str
    action: builtins.str
    @property
    def dump(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        dump: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        before_after: builtins.str = ...,
        action: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "before_after", b"before_after", "dump", b"dump"]) -> None: ...

Global___CacheDumpGraph: typing_extensions.TypeAlias = CacheDumpGraph

@typing.final
class CacheDumpGraphMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CacheDumpGraph: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CacheDumpGraph | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CacheDumpGraphMsg: typing_extensions.TypeAlias = CacheDumpGraphMsg

@typing.final
class AdapterRegistered(google.protobuf.message.Message):
    """Skipping E032, E033, E034

    E034
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTER_NAME_FIELD_NUMBER: builtins.int
    ADAPTER_VERSION_FIELD_NUMBER: builtins.int
    adapter_name: builtins.str
    adapter_version: builtins.str
    def __init__(
        self,
        *,
        adapter_name: builtins.str = ...,
        adapter_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter_name", b"adapter_name", "adapter_version", b"adapter_version"]) -> None: ...

Global___AdapterRegistered: typing_extensions.TypeAlias = AdapterRegistered

@typing.final
class AdapterRegisteredMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterRegistered: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterRegistered | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterRegisteredMsg: typing_extensions.TypeAlias = AdapterRegisteredMsg

@typing.final
class AdapterImportError(google.protobuf.message.Message):
    """E035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___AdapterImportError: typing_extensions.TypeAlias = AdapterImportError

@typing.final
class AdapterImportErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___AdapterImportError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___AdapterImportError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___AdapterImportErrorMsg: typing_extensions.TypeAlias = AdapterImportErrorMsg

@typing.final
class PluginLoadError(google.protobuf.message.Message):
    """E036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_INFO_FIELD_NUMBER: builtins.int
    exc_info: builtins.str
    def __init__(
        self,
        *,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

Global___PluginLoadError: typing_extensions.TypeAlias = PluginLoadError

@typing.final
class PluginLoadErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___PluginLoadError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___PluginLoadError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PluginLoadErrorMsg: typing_extensions.TypeAlias = PluginLoadErrorMsg

@typing.final
class NewConnectionOpening(google.protobuf.message.Message):
    """E037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    CONNECTION_STATE_FIELD_NUMBER: builtins.int
    connection_state: builtins.str
    @property
    def node_info(self) -> Global___AdapterNodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___AdapterNodeInfo | None = ...,
        connection_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_state", b"connection_state", "node_info", b"node_info"]) -> None: ...

Global___NewConnectionOpening: typing_extensions.TypeAlias = NewConnectionOpening

@typing.final
class NewConnectionOpeningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___NewConnectionOpening: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___NewConnectionOpening | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NewConnectionOpeningMsg: typing_extensions.TypeAlias = NewConnectionOpeningMsg

@typing.final
class CodeExecution(google.protobuf.message.Message):
    """E038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    CODE_CONTENT_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    code_content: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
        code_content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code_content", b"code_content", "conn_name", b"conn_name"]) -> None: ...

Global___CodeExecution: typing_extensions.TypeAlias = CodeExecution

@typing.final
class CodeExecutionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CodeExecution: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CodeExecution | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CodeExecutionMsg: typing_extensions.TypeAlias = CodeExecutionMsg

@typing.final
class CodeExecutionStatus(google.protobuf.message.Message):
    """E039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    ELAPSED_FIELD_NUMBER: builtins.int
    status: builtins.str
    elapsed: builtins.float
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        elapsed: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["elapsed", b"elapsed", "status", b"status"]) -> None: ...

Global___CodeExecutionStatus: typing_extensions.TypeAlias = CodeExecutionStatus

@typing.final
class CodeExecutionStatusMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CodeExecutionStatus: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CodeExecutionStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CodeExecutionStatusMsg: typing_extensions.TypeAlias = CodeExecutionStatusMsg

@typing.final
class CatalogGenerationError(google.protobuf.message.Message):
    """E040"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___CatalogGenerationError: typing_extensions.TypeAlias = CatalogGenerationError

@typing.final
class CatalogGenerationErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CatalogGenerationError: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CatalogGenerationError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CatalogGenerationErrorMsg: typing_extensions.TypeAlias = CatalogGenerationErrorMsg

@typing.final
class WriteCatalogFailure(google.protobuf.message.Message):
    """E041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_EXCEPTIONS_FIELD_NUMBER: builtins.int
    num_exceptions: builtins.int
    def __init__(
        self,
        *,
        num_exceptions: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_exceptions", b"num_exceptions"]) -> None: ...

Global___WriteCatalogFailure: typing_extensions.TypeAlias = WriteCatalogFailure

@typing.final
class WriteCatalogFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___WriteCatalogFailure: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___WriteCatalogFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___WriteCatalogFailureMsg: typing_extensions.TypeAlias = WriteCatalogFailureMsg

@typing.final
class CatalogWritten(google.protobuf.message.Message):
    """E042"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___CatalogWritten: typing_extensions.TypeAlias = CatalogWritten

@typing.final
class CatalogWrittenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CatalogWritten: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CatalogWritten | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CatalogWrittenMsg: typing_extensions.TypeAlias = CatalogWrittenMsg

@typing.final
class CannotGenerateDocs(google.protobuf.message.Message):
    """E043"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CannotGenerateDocs: typing_extensions.TypeAlias = CannotGenerateDocs

@typing.final
class CannotGenerateDocsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___CannotGenerateDocs: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___CannotGenerateDocs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CannotGenerateDocsMsg: typing_extensions.TypeAlias = CannotGenerateDocsMsg

@typing.final
class BuildingCatalog(google.protobuf.message.Message):
    """E044"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___BuildingCatalog: typing_extensions.TypeAlias = BuildingCatalog

@typing.final
class BuildingCatalogMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___BuildingCatalog: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___BuildingCatalog | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___BuildingCatalogMsg: typing_extensions.TypeAlias = BuildingCatalogMsg

@typing.final
class DatabaseErrorRunningHook(google.protobuf.message.Message):
    """E045"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOOK_TYPE_FIELD_NUMBER: builtins.int
    hook_type: builtins.str
    def __init__(
        self,
        *,
        hook_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hook_type", b"hook_type"]) -> None: ...

Global___DatabaseErrorRunningHook: typing_extensions.TypeAlias = DatabaseErrorRunningHook

@typing.final
class DatabaseErrorRunningHookMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___DatabaseErrorRunningHook: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___DatabaseErrorRunningHook | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DatabaseErrorRunningHookMsg: typing_extensions.TypeAlias = DatabaseErrorRunningHookMsg

@typing.final
class HooksRunning(google.protobuf.message.Message):
    """E046"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_HOOKS_FIELD_NUMBER: builtins.int
    HOOK_TYPE_FIELD_NUMBER: builtins.int
    num_hooks: builtins.int
    hook_type: builtins.str
    def __init__(
        self,
        *,
        num_hooks: builtins.int = ...,
        hook_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hook_type", b"hook_type", "num_hooks", b"num_hooks"]) -> None: ...

Global___HooksRunning: typing_extensions.TypeAlias = HooksRunning

@typing.final
class HooksRunningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___HooksRunning: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___HooksRunning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___HooksRunningMsg: typing_extensions.TypeAlias = HooksRunningMsg

@typing.final
class FinishedRunningStats(google.protobuf.message.Message):
    """E047"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAT_LINE_FIELD_NUMBER: builtins.int
    EXECUTION_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    stat_line: builtins.str
    execution: builtins.str
    execution_time: builtins.float
    def __init__(
        self,
        *,
        stat_line: builtins.str = ...,
        execution: builtins.str = ...,
        execution_time: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution", b"execution", "execution_time", b"execution_time", "stat_line", b"stat_line"]) -> None: ...

Global___FinishedRunningStats: typing_extensions.TypeAlias = FinishedRunningStats

@typing.final
class FinishedRunningStatsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___FinishedRunningStats: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___FinishedRunningStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FinishedRunningStatsMsg: typing_extensions.TypeAlias = FinishedRunningStatsMsg

@typing.final
class ConstraintNotEnforced(google.protobuf.message.Message):
    """E048"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_FIELD_NUMBER: builtins.int
    ADAPTER_FIELD_NUMBER: builtins.int
    constraint: builtins.str
    adapter: builtins.str
    def __init__(
        self,
        *,
        constraint: builtins.str = ...,
        adapter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter", b"adapter", "constraint", b"constraint"]) -> None: ...

Global___ConstraintNotEnforced: typing_extensions.TypeAlias = ConstraintNotEnforced

@typing.final
class ConstraintNotEnforcedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConstraintNotEnforced: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConstraintNotEnforced | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConstraintNotEnforcedMsg: typing_extensions.TypeAlias = ConstraintNotEnforcedMsg

@typing.final
class ConstraintNotSupported(google.protobuf.message.Message):
    """E049"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_FIELD_NUMBER: builtins.int
    ADAPTER_FIELD_NUMBER: builtins.int
    constraint: builtins.str
    adapter: builtins.str
    def __init__(
        self,
        *,
        constraint: builtins.str = ...,
        adapter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter", b"adapter", "constraint", b"constraint"]) -> None: ...

Global___ConstraintNotSupported: typing_extensions.TypeAlias = ConstraintNotSupported

@typing.final
class ConstraintNotSupportedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___ConstraintNotSupported: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___ConstraintNotSupported | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConstraintNotSupportedMsg: typing_extensions.TypeAlias = ConstraintNotSupportedMsg

@typing.final
class TypeCodeNotFound(google.protobuf.message.Message):
    """E050"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_CODE_FIELD_NUMBER: builtins.int
    type_code: builtins.int
    def __init__(
        self,
        *,
        type_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type_code", b"type_code"]) -> None: ...

Global___TypeCodeNotFound: typing_extensions.TypeAlias = TypeCodeNotFound

@typing.final
class TypeCodeNotFoundMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___AdapterCommonEventInfo: ...
    @property
    def data(self) -> Global___TypeCodeNotFound: ...
    def __init__(
        self,
        *,
        info: Global___AdapterCommonEventInfo | None = ...,
        data: Global___TypeCodeNotFound | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___TypeCodeNotFoundMsg: typing_extensions.TypeAlias = TypeCodeNotFoundMsg
