# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/insights.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_telemetry_contexts_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__telemetry__contexts__pb2
from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-dbtlabs/proto/public/v1/events/insights.proto\x12\x19v1.public.events.insights\x1a>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xac\x01\n\x08PageLoad\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb3\x01\n\x0f\x43\x61talogLiteOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb4\x01\n\x10QueryHistoryOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb1\x01\n\rBookmarksOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb8\x01\n\x14\x42ookmarksOpenDetails\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb8\x01\n\x14\x42ookmarksEditDetails\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb6\x01\n\x12VersionHistoryOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xaf\x01\n\x0b\x43opilotOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb5\x01\n\x11\x43opilotCreateChat\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xce\x01\n\x0e\x43opilotAddCode\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x1a\n\x12\x63opilot_request_id\x18\x03 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xd3\x01\n\x13\x43opilotFeedbackGood\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x1a\n\x12\x63opilot_request_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xd2\x01\n\x12\x43opilotFeedbackBad\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x1a\n\x12\x63opilot_request_id\x18\x03 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xae\x01\n\nChartsOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb4\x01\n\x10\x43hartsConfigOpen\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb3\x01\n\x0fShareCreateLink\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb1\x01\n\rShareOpenLink\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb7\x01\n\x13ShareCopyToNewQuery\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xc8\x01\n\x0b\x43svDownload\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x17\n\x0f\x66ile_size_bytes\x18\x03 \x01(\x05:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xcc\x01\n\x08RunQuery\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12[\n\x07\x63ontext\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x0b\n\x03sql\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xba\x01\n\x16HandoffOpenSqlInStudio\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xba\x01\n\x16HandoffOpenSqlInCanvas\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xbd\x01\n\x19HandoffOpenModelInCatalog\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xc4\x01\n Acknowledge2025LaunchTrialBanner\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12W\n\x03\x63tx\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42<Z:github.com/dbt-labs/proto-golang/v1/public/events/insightsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.insights_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dbt-labs/proto-golang/v1/public/events/insights'
  _globals['_PAGELOAD']._loaded_options = None
  _globals['_PAGELOAD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CATALOGLITEOPEN']._loaded_options = None
  _globals['_CATALOGLITEOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_QUERYHISTORYOPEN']._loaded_options = None
  _globals['_QUERYHISTORYOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_BOOKMARKSOPEN']._loaded_options = None
  _globals['_BOOKMARKSOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_BOOKMARKSOPENDETAILS']._loaded_options = None
  _globals['_BOOKMARKSOPENDETAILS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_BOOKMARKSEDITDETAILS']._loaded_options = None
  _globals['_BOOKMARKSEDITDETAILS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_VERSIONHISTORYOPEN']._loaded_options = None
  _globals['_VERSIONHISTORYOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTOPEN']._loaded_options = None
  _globals['_COPILOTOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTCREATECHAT']._loaded_options = None
  _globals['_COPILOTCREATECHAT']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTADDCODE']._loaded_options = None
  _globals['_COPILOTADDCODE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTFEEDBACKGOOD']._loaded_options = None
  _globals['_COPILOTFEEDBACKGOOD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_COPILOTFEEDBACKBAD']._loaded_options = None
  _globals['_COPILOTFEEDBACKBAD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CHARTSOPEN']._loaded_options = None
  _globals['_CHARTSOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CHARTSCONFIGOPEN']._loaded_options = None
  _globals['_CHARTSCONFIGOPEN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_SHARECREATELINK']._loaded_options = None
  _globals['_SHARECREATELINK']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_SHAREOPENLINK']._loaded_options = None
  _globals['_SHAREOPENLINK']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_SHARECOPYTONEWQUERY']._loaded_options = None
  _globals['_SHARECOPYTONEWQUERY']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_CSVDOWNLOAD']._loaded_options = None
  _globals['_CSVDOWNLOAD']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_RUNQUERY']._loaded_options = None
  _globals['_RUNQUERY']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFOPENSQLINSTUDIO']._loaded_options = None
  _globals['_HANDOFFOPENSQLINSTUDIO']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFOPENSQLINCANVAS']._loaded_options = None
  _globals['_HANDOFFOPENSQLINCANVAS']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFOPENMODELINCATALOG']._loaded_options = None
  _globals['_HANDOFFOPENMODELINCATALOG']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._loaded_options = None
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_PAGELOAD']._serialized_start=239
  _globals['_PAGELOAD']._serialized_end=411
  _globals['_CATALOGLITEOPEN']._serialized_start=414
  _globals['_CATALOGLITEOPEN']._serialized_end=593
  _globals['_QUERYHISTORYOPEN']._serialized_start=596
  _globals['_QUERYHISTORYOPEN']._serialized_end=776
  _globals['_BOOKMARKSOPEN']._serialized_start=779
  _globals['_BOOKMARKSOPEN']._serialized_end=956
  _globals['_BOOKMARKSOPENDETAILS']._serialized_start=959
  _globals['_BOOKMARKSOPENDETAILS']._serialized_end=1143
  _globals['_BOOKMARKSEDITDETAILS']._serialized_start=1146
  _globals['_BOOKMARKSEDITDETAILS']._serialized_end=1330
  _globals['_VERSIONHISTORYOPEN']._serialized_start=1333
  _globals['_VERSIONHISTORYOPEN']._serialized_end=1515
  _globals['_COPILOTOPEN']._serialized_start=1518
  _globals['_COPILOTOPEN']._serialized_end=1693
  _globals['_COPILOTCREATECHAT']._serialized_start=1696
  _globals['_COPILOTCREATECHAT']._serialized_end=1877
  _globals['_COPILOTADDCODE']._serialized_start=1880
  _globals['_COPILOTADDCODE']._serialized_end=2086
  _globals['_COPILOTFEEDBACKGOOD']._serialized_start=2089
  _globals['_COPILOTFEEDBACKGOOD']._serialized_end=2300
  _globals['_COPILOTFEEDBACKBAD']._serialized_start=2303
  _globals['_COPILOTFEEDBACKBAD']._serialized_end=2513
  _globals['_CHARTSOPEN']._serialized_start=2516
  _globals['_CHARTSOPEN']._serialized_end=2690
  _globals['_CHARTSCONFIGOPEN']._serialized_start=2693
  _globals['_CHARTSCONFIGOPEN']._serialized_end=2873
  _globals['_SHARECREATELINK']._serialized_start=2876
  _globals['_SHARECREATELINK']._serialized_end=3055
  _globals['_SHAREOPENLINK']._serialized_start=3058
  _globals['_SHAREOPENLINK']._serialized_end=3235
  _globals['_SHARECOPYTONEWQUERY']._serialized_start=3238
  _globals['_SHARECOPYTONEWQUERY']._serialized_end=3421
  _globals['_CSVDOWNLOAD']._serialized_start=3424
  _globals['_CSVDOWNLOAD']._serialized_end=3624
  _globals['_RUNQUERY']._serialized_start=3627
  _globals['_RUNQUERY']._serialized_end=3831
  _globals['_HANDOFFOPENSQLINSTUDIO']._serialized_start=3834
  _globals['_HANDOFFOPENSQLINSTUDIO']._serialized_end=4020
  _globals['_HANDOFFOPENSQLINCANVAS']._serialized_start=4023
  _globals['_HANDOFFOPENSQLINCANVAS']._serialized_end=4209
  _globals['_HANDOFFOPENMODELINCATALOG']._serialized_start=4212
  _globals['_HANDOFFOPENMODELINCATALOG']._serialized_end=4401
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._serialized_start=4404
  _globals['_ACKNOWLEDGE2025LAUNCHTRIALBANNER']._serialized_end=4600
# @@protoc_insertion_point(module_scope)
