# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/common_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dbtlabs/proto/public/v1/fields/common_types.proto\x12\x1dv1.public.fields.common_types\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x02\n\tEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x05\x65xtra\x18\t \x03(\x0b\x32\x33.v1.public.fields.common_types.EventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eGenericMessage\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\"d\n\x13\x42\x65haviorChangeEvent\x12\x11\n\tflag_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66lag_source\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x04 \x01(\t\"\x92\x01\n\x16\x42\x65haviorChangeEventMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.common_types.BehaviorChangeEvent\"1\n\x11RetryExternalCall\x12\x0f\n\x07\x61ttempt\x18\x01 \x01(\x05\x12\x0b\n\x03max\x18\x02 \x01(\x05\"\x8e\x01\n\x14RetryExternalCallMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.common_types.RetryExternalCall\"#\n\x14RecordRetryException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x94\x01\n\x17RecordRetryExceptionMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.common_types.RecordRetryException\"@\n\x13SystemCouldNotWrite\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\"\x92\x01\n\x16SystemCouldNotWriteMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.common_types.SystemCouldNotWrite\"!\n\x12SystemExecutingCmd\x12\x0b\n\x03\x63md\x18\x01 \x03(\t\"\x90\x01\n\x15SystemExecutingCmdMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.common_types.SystemExecutingCmd\"\x1c\n\x0cSystemStdOut\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"\x84\x01\n\x0fSystemStdOutMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.common_types.SystemStdOut\"\x1c\n\x0cSystemStdErr\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"\x84\x01\n\x0fSystemStdErrMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.common_types.SystemStdErr\",\n\x16SystemReportReturnCode\x12\x12\n\nreturncode\x18\x01 \x01(\x05\"\x98\x01\n\x19SystemReportReturnCodeMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.common_types.SystemReportReturnCode\"\x19\n\nFormatting\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x80\x01\n\rFormattingMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.common_types.Formatting\"\x13\n\x04Note\x12\x0b\n\x03msg\x18\x01 \x01(\t\"t\n\x07NoteMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.v1.public.fields.common_types.Note\"\x19\n\nPrintEvent\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x80\x01\n\rPrintEventMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.common_types.PrintEvent\" \n\x11RecordReplayIssue\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x8e\x01\n\x14RecordReplayIssueMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.common_types.RecordReplayIssueB@Z>github.com/dbt-labs/proto-golang/v1/public/fields/common_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.common_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/fields/common_types'
  _globals['_EVENTINFO_EXTRAENTRY']._loaded_options = None
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTINFO']._serialized_start=118
  _globals['_EVENTINFO']._serialized_end=409
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_start=365
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_end=409
  _globals['_GENERICMESSAGE']._serialized_start=411
  _globals['_GENERICMESSAGE']._serialized_end=483
  _globals['_BEHAVIORCHANGEEVENT']._serialized_start=485
  _globals['_BEHAVIORCHANGEEVENT']._serialized_end=585
  _globals['_BEHAVIORCHANGEEVENTMSG']._serialized_start=588
  _globals['_BEHAVIORCHANGEEVENTMSG']._serialized_end=734
  _globals['_RETRYEXTERNALCALL']._serialized_start=736
  _globals['_RETRYEXTERNALCALL']._serialized_end=785
  _globals['_RETRYEXTERNALCALLMSG']._serialized_start=788
  _globals['_RETRYEXTERNALCALLMSG']._serialized_end=930
  _globals['_RECORDRETRYEXCEPTION']._serialized_start=932
  _globals['_RECORDRETRYEXCEPTION']._serialized_end=967
  _globals['_RECORDRETRYEXCEPTIONMSG']._serialized_start=970
  _globals['_RECORDRETRYEXCEPTIONMSG']._serialized_end=1118
  _globals['_SYSTEMCOULDNOTWRITE']._serialized_start=1120
  _globals['_SYSTEMCOULDNOTWRITE']._serialized_end=1184
  _globals['_SYSTEMCOULDNOTWRITEMSG']._serialized_start=1187
  _globals['_SYSTEMCOULDNOTWRITEMSG']._serialized_end=1333
  _globals['_SYSTEMEXECUTINGCMD']._serialized_start=1335
  _globals['_SYSTEMEXECUTINGCMD']._serialized_end=1368
  _globals['_SYSTEMEXECUTINGCMDMSG']._serialized_start=1371
  _globals['_SYSTEMEXECUTINGCMDMSG']._serialized_end=1515
  _globals['_SYSTEMSTDOUT']._serialized_start=1517
  _globals['_SYSTEMSTDOUT']._serialized_end=1545
  _globals['_SYSTEMSTDOUTMSG']._serialized_start=1548
  _globals['_SYSTEMSTDOUTMSG']._serialized_end=1680
  _globals['_SYSTEMSTDERR']._serialized_start=1682
  _globals['_SYSTEMSTDERR']._serialized_end=1710
  _globals['_SYSTEMSTDERRMSG']._serialized_start=1713
  _globals['_SYSTEMSTDERRMSG']._serialized_end=1845
  _globals['_SYSTEMREPORTRETURNCODE']._serialized_start=1847
  _globals['_SYSTEMREPORTRETURNCODE']._serialized_end=1891
  _globals['_SYSTEMREPORTRETURNCODEMSG']._serialized_start=1894
  _globals['_SYSTEMREPORTRETURNCODEMSG']._serialized_end=2046
  _globals['_FORMATTING']._serialized_start=2048
  _globals['_FORMATTING']._serialized_end=2073
  _globals['_FORMATTINGMSG']._serialized_start=2076
  _globals['_FORMATTINGMSG']._serialized_end=2204
  _globals['_NOTE']._serialized_start=2206
  _globals['_NOTE']._serialized_end=2225
  _globals['_NOTEMSG']._serialized_start=2227
  _globals['_NOTEMSG']._serialized_end=2343
  _globals['_PRINTEVENT']._serialized_start=2345
  _globals['_PRINTEVENT']._serialized_end=2370
  _globals['_PRINTEVENTMSG']._serialized_start=2373
  _globals['_PRINTEVENTMSG']._serialized_end=2501
  _globals['_RECORDREPLAYISSUE']._serialized_start=2503
  _globals['_RECORDREPLAYISSUE']._serialized_end=2535
  _globals['_RECORDREPLAYISSUEMSG']._serialized_start=2538
  _globals['_RECORDREPLAYISSUEMSG']._serialized_end=2680
# @@protoc_insertion_point(module_scope)
