"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CoreEventInfo(google.protobuf.message.Message):
    """Common event info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    code: builtins.str
    msg: builtins.str
    level: builtins.str
    invocation_id: builtins.str
    pid: builtins.int
    thread: builtins.str
    category: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
        level: builtins.str = ...,
        invocation_id: builtins.str = ...,
        pid: builtins.int = ...,
        thread: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        category: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "code", b"code", "extra", b"extra", "invocation_id", b"invocation_id", "level", b"level", "msg", b"msg", "name", b"name", "pid", b"pid", "thread", b"thread", "ts", b"ts"]) -> None: ...

Global___CoreEventInfo: typing_extensions.TypeAlias = CoreEventInfo

@typing.final
class NodeRelation(google.protobuf.message.Message):
    """NodeRelation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    ALIAS_FIELD_NUMBER: builtins.int
    RELATION_NAME_FIELD_NUMBER: builtins.int
    database: builtins.str
    schema: builtins.str
    alias: builtins.str
    relation_name: builtins.str
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        schema: builtins.str = ...,
        alias: builtins.str = ...,
        relation_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alias", b"alias", "database", b"database", "relation_name", b"relation_name", "schema", b"schema"]) -> None: ...

Global___NodeRelation: typing_extensions.TypeAlias = NodeRelation

@typing.final
class NodeInfo(google.protobuf.message.Message):
    """NodeInfo"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_PATH_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    MATERIALIZED_FIELD_NUMBER: builtins.int
    NODE_STATUS_FIELD_NUMBER: builtins.int
    NODE_STARTED_AT_FIELD_NUMBER: builtins.int
    NODE_FINISHED_AT_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    NODE_RELATION_FIELD_NUMBER: builtins.int
    NODE_CHECKSUM_FIELD_NUMBER: builtins.int
    node_path: builtins.str
    node_name: builtins.str
    unique_id: builtins.str
    resource_type: builtins.str
    materialized: builtins.str
    node_status: builtins.str
    node_started_at: builtins.str
    node_finished_at: builtins.str
    node_checksum: builtins.str
    @property
    def meta(self) -> google.protobuf.struct_pb2.Struct: ...
    @property
    def node_relation(self) -> Global___NodeRelation: ...
    def __init__(
        self,
        *,
        node_path: builtins.str = ...,
        node_name: builtins.str = ...,
        unique_id: builtins.str = ...,
        resource_type: builtins.str = ...,
        materialized: builtins.str = ...,
        node_status: builtins.str = ...,
        node_started_at: builtins.str = ...,
        node_finished_at: builtins.str = ...,
        meta: google.protobuf.struct_pb2.Struct | None = ...,
        node_relation: Global___NodeRelation | None = ...,
        node_checksum: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["meta", b"meta", "node_relation", b"node_relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["materialized", b"materialized", "meta", b"meta", "node_checksum", b"node_checksum", "node_finished_at", b"node_finished_at", "node_name", b"node_name", "node_path", b"node_path", "node_relation", b"node_relation", "node_started_at", b"node_started_at", "node_status", b"node_status", "resource_type", b"resource_type", "unique_id", b"unique_id"]) -> None: ...

Global___NodeInfo: typing_extensions.TypeAlias = NodeInfo

@typing.final
class TimingInfoMsg(google.protobuf.message.Message):
    """TimingInfoMsg"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_at", b"completed_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completed_at", b"completed_at", "name", b"name", "started_at", b"started_at"]) -> None: ...

Global___TimingInfoMsg: typing_extensions.TypeAlias = TimingInfoMsg

@typing.final
class RunResultMsg(google.protobuf.message.Message):
    """RunResult"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TIMING_INFO_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    ADAPTER_RESPONSE_FIELD_NUMBER: builtins.int
    NUM_FAILURES_FIELD_NUMBER: builtins.int
    status: builtins.str
    message: builtins.str
    thread: builtins.str
    execution_time: builtins.float
    num_failures: builtins.int
    @property
    def timing_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___TimingInfoMsg]: ...
    @property
    def adapter_response(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        message: builtins.str = ...,
        timing_info: collections.abc.Iterable[Global___TimingInfoMsg] | None = ...,
        thread: builtins.str = ...,
        execution_time: builtins.float = ...,
        adapter_response: google.protobuf.struct_pb2.Struct | None = ...,
        num_failures: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["adapter_response", b"adapter_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_response", b"adapter_response", "execution_time", b"execution_time", "message", b"message", "num_failures", b"num_failures", "status", b"status", "thread", b"thread", "timing_info", b"timing_info"]) -> None: ...

Global___RunResultMsg: typing_extensions.TypeAlias = RunResultMsg

@typing.final
class ColumnType(google.protobuf.message.Message):
    """ColumnType"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    PREVIOUS_COLUMN_TYPE_FIELD_NUMBER: builtins.int
    CURRENT_COLUMN_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    previous_column_type: builtins.str
    current_column_type: builtins.str
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        previous_column_type: builtins.str = ...,
        current_column_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["column_name", b"column_name", "current_column_type", b"current_column_type", "previous_column_type", b"previous_column_type"]) -> None: ...

Global___ColumnType: typing_extensions.TypeAlias = ColumnType

@typing.final
class ColumnConstraint(google.protobuf.message.Message):
    """ColumnConstraint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    CONSTRAINT_NAME_FIELD_NUMBER: builtins.int
    CONSTRAINT_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    constraint_name: builtins.str
    constraint_type: builtins.str
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        constraint_name: builtins.str = ...,
        constraint_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["column_name", b"column_name", "constraint_name", b"constraint_name", "constraint_type", b"constraint_type"]) -> None: ...

Global___ColumnConstraint: typing_extensions.TypeAlias = ColumnConstraint

@typing.final
class ModelConstraint(google.protobuf.message.Message):
    """ModelConstraint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSTRAINT_NAME_FIELD_NUMBER: builtins.int
    CONSTRAINT_TYPE_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    constraint_name: builtins.str
    constraint_type: builtins.str
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        constraint_name: builtins.str = ...,
        constraint_type: builtins.str = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "constraint_name", b"constraint_name", "constraint_type", b"constraint_type"]) -> None: ...

Global___ModelConstraint: typing_extensions.TypeAlias = ModelConstraint

@typing.final
class MainReportVersion(google.protobuf.message.Message):
    """A - Pre-project loading

    A001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    LOG_VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    log_version: builtins.int
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        log_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["log_version", b"log_version", "version", b"version"]) -> None: ...

Global___MainReportVersion: typing_extensions.TypeAlias = MainReportVersion

@typing.final
class MainReportVersionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MainReportVersion: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MainReportVersion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MainReportVersionMsg: typing_extensions.TypeAlias = MainReportVersionMsg

@typing.final
class MainReportArgs(google.protobuf.message.Message):
    """A002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ArgsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARGS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["args", b"args"]) -> None: ...

Global___MainReportArgs: typing_extensions.TypeAlias = MainReportArgs

@typing.final
class MainReportArgsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MainReportArgs: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MainReportArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MainReportArgsMsg: typing_extensions.TypeAlias = MainReportArgsMsg

@typing.final
class MainTrackingUserState(google.protobuf.message.Message):
    """A003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_STATE_FIELD_NUMBER: builtins.int
    user_state: builtins.str
    def __init__(
        self,
        *,
        user_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_state", b"user_state"]) -> None: ...

Global___MainTrackingUserState: typing_extensions.TypeAlias = MainTrackingUserState

@typing.final
class MainTrackingUserStateMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MainTrackingUserState: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MainTrackingUserState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MainTrackingUserStateMsg: typing_extensions.TypeAlias = MainTrackingUserStateMsg

@typing.final
class MergedFromState(google.protobuf.message.Message):
    """A004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_MERGED_FIELD_NUMBER: builtins.int
    SAMPLE_FIELD_NUMBER: builtins.int
    num_merged: builtins.int
    @property
    def sample(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        num_merged: builtins.int = ...,
        sample: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["num_merged", b"num_merged", "sample", b"sample"]) -> None: ...

Global___MergedFromState: typing_extensions.TypeAlias = MergedFromState

@typing.final
class MergedFromStateMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MergedFromState: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MergedFromState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MergedFromStateMsg: typing_extensions.TypeAlias = MergedFromStateMsg

@typing.final
class MissingProfileTarget(google.protobuf.message.Message):
    """A005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROFILE_NAME_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    profile_name: builtins.str
    target_name: builtins.str
    def __init__(
        self,
        *,
        profile_name: builtins.str = ...,
        target_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["profile_name", b"profile_name", "target_name", b"target_name"]) -> None: ...

Global___MissingProfileTarget: typing_extensions.TypeAlias = MissingProfileTarget

@typing.final
class MissingProfileTargetMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MissingProfileTarget: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MissingProfileTarget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MissingProfileTargetMsg: typing_extensions.TypeAlias = MissingProfileTargetMsg

@typing.final
class InvalidOptionYAML(google.protobuf.message.Message):
    """Skipped A006, A007

    A008
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTION_NAME_FIELD_NUMBER: builtins.int
    option_name: builtins.str
    def __init__(
        self,
        *,
        option_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["option_name", b"option_name"]) -> None: ...

Global___InvalidOptionYAML: typing_extensions.TypeAlias = InvalidOptionYAML

@typing.final
class InvalidOptionYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InvalidOptionYAML: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InvalidOptionYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InvalidOptionYAMLMsg: typing_extensions.TypeAlias = InvalidOptionYAMLMsg

@typing.final
class LogDbtProjectError(google.protobuf.message.Message):
    """A009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___LogDbtProjectError: typing_extensions.TypeAlias = LogDbtProjectError

@typing.final
class LogDbtProjectErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogDbtProjectError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogDbtProjectError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogDbtProjectErrorMsg: typing_extensions.TypeAlias = LogDbtProjectErrorMsg

@typing.final
class LogDbtProfileError(google.protobuf.message.Message):
    """Skipped A010

    A011
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    PROFILES_FIELD_NUMBER: builtins.int
    exc: builtins.str
    @property
    def profiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
        profiles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "profiles", b"profiles"]) -> None: ...

Global___LogDbtProfileError: typing_extensions.TypeAlias = LogDbtProfileError

@typing.final
class LogDbtProfileErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogDbtProfileError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogDbtProfileError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogDbtProfileErrorMsg: typing_extensions.TypeAlias = LogDbtProfileErrorMsg

@typing.final
class StarterProjectPath(google.protobuf.message.Message):
    """Skipped A012, A013, A014, A015, A016

    A017
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

Global___StarterProjectPath: typing_extensions.TypeAlias = StarterProjectPath

@typing.final
class StarterProjectPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___StarterProjectPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___StarterProjectPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___StarterProjectPathMsg: typing_extensions.TypeAlias = StarterProjectPathMsg

@typing.final
class ConfigFolderDirectory(google.protobuf.message.Message):
    """A018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

Global___ConfigFolderDirectory: typing_extensions.TypeAlias = ConfigFolderDirectory

@typing.final
class ConfigFolderDirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConfigFolderDirectory: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConfigFolderDirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConfigFolderDirectoryMsg: typing_extensions.TypeAlias = ConfigFolderDirectoryMsg

@typing.final
class NoSampleProfileFound(google.protobuf.message.Message):
    """A019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTER_FIELD_NUMBER: builtins.int
    adapter: builtins.str
    def __init__(
        self,
        *,
        adapter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter", b"adapter"]) -> None: ...

Global___NoSampleProfileFound: typing_extensions.TypeAlias = NoSampleProfileFound

@typing.final
class NoSampleProfileFoundMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NoSampleProfileFound: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NoSampleProfileFound | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NoSampleProfileFoundMsg: typing_extensions.TypeAlias = NoSampleProfileFoundMsg

@typing.final
class ProfileWrittenWithSample(google.protobuf.message.Message):
    """A020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "path", b"path"]) -> None: ...

Global___ProfileWrittenWithSample: typing_extensions.TypeAlias = ProfileWrittenWithSample

@typing.final
class ProfileWrittenWithSampleMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProfileWrittenWithSample: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProfileWrittenWithSample | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProfileWrittenWithSampleMsg: typing_extensions.TypeAlias = ProfileWrittenWithSampleMsg

@typing.final
class ProfileWrittenWithTargetTemplateYAML(google.protobuf.message.Message):
    """A021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "path", b"path"]) -> None: ...

Global___ProfileWrittenWithTargetTemplateYAML: typing_extensions.TypeAlias = ProfileWrittenWithTargetTemplateYAML

@typing.final
class ProfileWrittenWithTargetTemplateYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProfileWrittenWithTargetTemplateYAML: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProfileWrittenWithTargetTemplateYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProfileWrittenWithTargetTemplateYAMLMsg: typing_extensions.TypeAlias = ProfileWrittenWithTargetTemplateYAMLMsg

@typing.final
class ProfileWrittenWithProjectTemplateYAML(google.protobuf.message.Message):
    """A022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "path", b"path"]) -> None: ...

Global___ProfileWrittenWithProjectTemplateYAML: typing_extensions.TypeAlias = ProfileWrittenWithProjectTemplateYAML

@typing.final
class ProfileWrittenWithProjectTemplateYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProfileWrittenWithProjectTemplateYAML: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProfileWrittenWithProjectTemplateYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProfileWrittenWithProjectTemplateYAMLMsg: typing_extensions.TypeAlias = ProfileWrittenWithProjectTemplateYAMLMsg

@typing.final
class SettingUpProfile(google.protobuf.message.Message):
    """A023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___SettingUpProfile: typing_extensions.TypeAlias = SettingUpProfile

@typing.final
class SettingUpProfileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SettingUpProfile: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SettingUpProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SettingUpProfileMsg: typing_extensions.TypeAlias = SettingUpProfileMsg

@typing.final
class InvalidProfileTemplateYAML(google.protobuf.message.Message):
    """A024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___InvalidProfileTemplateYAML: typing_extensions.TypeAlias = InvalidProfileTemplateYAML

@typing.final
class InvalidProfileTemplateYAMLMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InvalidProfileTemplateYAML: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InvalidProfileTemplateYAML | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InvalidProfileTemplateYAMLMsg: typing_extensions.TypeAlias = InvalidProfileTemplateYAMLMsg

@typing.final
class ProjectNameAlreadyExists(google.protobuf.message.Message):
    """A025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

Global___ProjectNameAlreadyExists: typing_extensions.TypeAlias = ProjectNameAlreadyExists

@typing.final
class ProjectNameAlreadyExistsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProjectNameAlreadyExists: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProjectNameAlreadyExists | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProjectNameAlreadyExistsMsg: typing_extensions.TypeAlias = ProjectNameAlreadyExistsMsg

@typing.final
class ProjectCreated(google.protobuf.message.Message):
    """A026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_NAME_FIELD_NUMBER: builtins.int
    DOCS_URL_FIELD_NUMBER: builtins.int
    SLACK_URL_FIELD_NUMBER: builtins.int
    project_name: builtins.str
    docs_url: builtins.str
    slack_url: builtins.str
    def __init__(
        self,
        *,
        project_name: builtins.str = ...,
        docs_url: builtins.str = ...,
        slack_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["docs_url", b"docs_url", "project_name", b"project_name", "slack_url", b"slack_url"]) -> None: ...

Global___ProjectCreated: typing_extensions.TypeAlias = ProjectCreated

@typing.final
class ProjectCreatedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProjectCreated: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProjectCreated | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProjectCreatedMsg: typing_extensions.TypeAlias = ProjectCreatedMsg

@typing.final
class PackageRedirectDeprecation(google.protobuf.message.Message):
    """D - Deprecation

    D001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    old_name: builtins.str
    new_name: builtins.str
    def __init__(
        self,
        *,
        old_name: builtins.str = ...,
        new_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "old_name", b"old_name"]) -> None: ...

Global___PackageRedirectDeprecation: typing_extensions.TypeAlias = PackageRedirectDeprecation

@typing.final
class PackageRedirectDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PackageRedirectDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PackageRedirectDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PackageRedirectDeprecationMsg: typing_extensions.TypeAlias = PackageRedirectDeprecationMsg

@typing.final
class PackageInstallPathDeprecation(google.protobuf.message.Message):
    """D002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___PackageInstallPathDeprecation: typing_extensions.TypeAlias = PackageInstallPathDeprecation

@typing.final
class PackageInstallPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PackageInstallPathDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PackageInstallPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PackageInstallPathDeprecationMsg: typing_extensions.TypeAlias = PackageInstallPathDeprecationMsg

@typing.final
class ConfigSourcePathDeprecation(google.protobuf.message.Message):
    """D003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    EXP_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    exp_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
        exp_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path", "exp_path", b"exp_path"]) -> None: ...

Global___ConfigSourcePathDeprecation: typing_extensions.TypeAlias = ConfigSourcePathDeprecation

@typing.final
class ConfigSourcePathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConfigSourcePathDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConfigSourcePathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConfigSourcePathDeprecationMsg: typing_extensions.TypeAlias = ConfigSourcePathDeprecationMsg

@typing.final
class ConfigDataPathDeprecation(google.protobuf.message.Message):
    """D004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    EXP_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    exp_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
        exp_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path", "exp_path", b"exp_path"]) -> None: ...

Global___ConfigDataPathDeprecation: typing_extensions.TypeAlias = ConfigDataPathDeprecation

@typing.final
class ConfigDataPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConfigDataPathDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConfigDataPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConfigDataPathDeprecationMsg: typing_extensions.TypeAlias = ConfigDataPathDeprecationMsg

@typing.final
class MetricAttributesRenamed(google.protobuf.message.Message):
    """D006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_NAME_FIELD_NUMBER: builtins.int
    metric_name: builtins.str
    def __init__(
        self,
        *,
        metric_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["metric_name", b"metric_name"]) -> None: ...

Global___MetricAttributesRenamed: typing_extensions.TypeAlias = MetricAttributesRenamed

@typing.final
class MetricAttributesRenamedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MetricAttributesRenamed: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MetricAttributesRenamed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MetricAttributesRenamedMsg: typing_extensions.TypeAlias = MetricAttributesRenamedMsg

@typing.final
class ExposureNameDeprecation(google.protobuf.message.Message):
    """D007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPOSURE_FIELD_NUMBER: builtins.int
    exposure: builtins.str
    def __init__(
        self,
        *,
        exposure: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exposure", b"exposure"]) -> None: ...

Global___ExposureNameDeprecation: typing_extensions.TypeAlias = ExposureNameDeprecation

@typing.final
class ExposureNameDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ExposureNameDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ExposureNameDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ExposureNameDeprecationMsg: typing_extensions.TypeAlias = ExposureNameDeprecationMsg

@typing.final
class InternalDeprecation(google.protobuf.message.Message):
    """D008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    SUGGESTED_ACTION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    reason: builtins.str
    suggested_action: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        reason: builtins.str = ...,
        suggested_action: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "reason", b"reason", "suggested_action", b"suggested_action", "version", b"version"]) -> None: ...

Global___InternalDeprecation: typing_extensions.TypeAlias = InternalDeprecation

@typing.final
class InternalDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InternalDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InternalDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InternalDeprecationMsg: typing_extensions.TypeAlias = InternalDeprecationMsg

@typing.final
class EnvironmentVariableRenamed(google.protobuf.message.Message):
    """D009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    old_name: builtins.str
    new_name: builtins.str
    def __init__(
        self,
        *,
        old_name: builtins.str = ...,
        new_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "old_name", b"old_name"]) -> None: ...

Global___EnvironmentVariableRenamed: typing_extensions.TypeAlias = EnvironmentVariableRenamed

@typing.final
class EnvironmentVariableRenamedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___EnvironmentVariableRenamed: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___EnvironmentVariableRenamed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___EnvironmentVariableRenamedMsg: typing_extensions.TypeAlias = EnvironmentVariableRenamedMsg

@typing.final
class ConfigLogPathDeprecation(google.protobuf.message.Message):
    """D010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path"]) -> None: ...

Global___ConfigLogPathDeprecation: typing_extensions.TypeAlias = ConfigLogPathDeprecation

@typing.final
class ConfigLogPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConfigLogPathDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConfigLogPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConfigLogPathDeprecationMsg: typing_extensions.TypeAlias = ConfigLogPathDeprecationMsg

@typing.final
class ConfigTargetPathDeprecation(google.protobuf.message.Message):
    """D011"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path"]) -> None: ...

Global___ConfigTargetPathDeprecation: typing_extensions.TypeAlias = ConfigTargetPathDeprecation

@typing.final
class ConfigTargetPathDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConfigTargetPathDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConfigTargetPathDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConfigTargetPathDeprecationMsg: typing_extensions.TypeAlias = ConfigTargetPathDeprecationMsg

@typing.final
class TestsConfigDeprecation(google.protobuf.message.Message):
    """D012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPRECATED_PATH_FIELD_NUMBER: builtins.int
    EXP_PATH_FIELD_NUMBER: builtins.int
    deprecated_path: builtins.str
    exp_path: builtins.str
    def __init__(
        self,
        *,
        deprecated_path: builtins.str = ...,
        exp_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated_path", b"deprecated_path", "exp_path", b"exp_path"]) -> None: ...

Global___TestsConfigDeprecation: typing_extensions.TypeAlias = TestsConfigDeprecation

@typing.final
class TestsConfigDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___TestsConfigDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___TestsConfigDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___TestsConfigDeprecationMsg: typing_extensions.TypeAlias = TestsConfigDeprecationMsg

@typing.final
class ProjectFlagsMovedDeprecation(google.protobuf.message.Message):
    """D013"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ProjectFlagsMovedDeprecation: typing_extensions.TypeAlias = ProjectFlagsMovedDeprecation

@typing.final
class ProjectFlagsMovedDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProjectFlagsMovedDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProjectFlagsMovedDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProjectFlagsMovedDeprecationMsg: typing_extensions.TypeAlias = ProjectFlagsMovedDeprecationMsg

@typing.final
class SpacesInResourceNameDeprecation(google.protobuf.message.Message):
    """D014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIQUE_ID_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    unique_id: builtins.str
    level: builtins.str
    def __init__(
        self,
        *,
        unique_id: builtins.str = ...,
        level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["level", b"level", "unique_id", b"unique_id"]) -> None: ...

Global___SpacesInResourceNameDeprecation: typing_extensions.TypeAlias = SpacesInResourceNameDeprecation

@typing.final
class SpacesInResourceNameDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SpacesInResourceNameDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SpacesInResourceNameDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SpacesInResourceNameDeprecationMsg: typing_extensions.TypeAlias = SpacesInResourceNameDeprecationMsg

@typing.final
class ResourceNamesWithSpacesDeprecation(google.protobuf.message.Message):
    """D015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_INVALID_NAMES_FIELD_NUMBER: builtins.int
    SHOW_DEBUG_HINT_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    count_invalid_names: builtins.int
    show_debug_hint: builtins.bool
    level: builtins.str
    def __init__(
        self,
        *,
        count_invalid_names: builtins.int = ...,
        show_debug_hint: builtins.bool = ...,
        level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["count_invalid_names", b"count_invalid_names", "level", b"level", "show_debug_hint", b"show_debug_hint"]) -> None: ...

Global___ResourceNamesWithSpacesDeprecation: typing_extensions.TypeAlias = ResourceNamesWithSpacesDeprecation

@typing.final
class ResourceNamesWithSpacesDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ResourceNamesWithSpacesDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ResourceNamesWithSpacesDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ResourceNamesWithSpacesDeprecationMsg: typing_extensions.TypeAlias = ResourceNamesWithSpacesDeprecationMsg

@typing.final
class PackageMaterializationOverrideDeprecation(google.protobuf.message.Message):
    """D016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    MATERIALIZATION_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    materialization_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        materialization_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["materialization_name", b"materialization_name", "package_name", b"package_name"]) -> None: ...

Global___PackageMaterializationOverrideDeprecation: typing_extensions.TypeAlias = PackageMaterializationOverrideDeprecation

@typing.final
class PackageMaterializationOverrideDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PackageMaterializationOverrideDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PackageMaterializationOverrideDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PackageMaterializationOverrideDeprecationMsg: typing_extensions.TypeAlias = PackageMaterializationOverrideDeprecationMsg

@typing.final
class SourceFreshnessProjectHooksNotRun(google.protobuf.message.Message):
    """D017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___SourceFreshnessProjectHooksNotRun: typing_extensions.TypeAlias = SourceFreshnessProjectHooksNotRun

@typing.final
class SourceFreshnessProjectHooksNotRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SourceFreshnessProjectHooksNotRun: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SourceFreshnessProjectHooksNotRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SourceFreshnessProjectHooksNotRunMsg: typing_extensions.TypeAlias = SourceFreshnessProjectHooksNotRunMsg

@typing.final
class MFTimespineWithoutYamlConfigurationDeprecation(google.protobuf.message.Message):
    """D018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MFTimespineWithoutYamlConfigurationDeprecation: typing_extensions.TypeAlias = MFTimespineWithoutYamlConfigurationDeprecation

@typing.final
class MFTimespineWithoutYamlConfigurationDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MFTimespineWithoutYamlConfigurationDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MFTimespineWithoutYamlConfigurationDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MFTimespineWithoutYamlConfigurationDeprecationMsg: typing_extensions.TypeAlias = MFTimespineWithoutYamlConfigurationDeprecationMsg

@typing.final
class MFCumulativeTypeParamsDeprecation(google.protobuf.message.Message):
    """D019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MFCumulativeTypeParamsDeprecation: typing_extensions.TypeAlias = MFCumulativeTypeParamsDeprecation

@typing.final
class MFCumulativeTypeParamsDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MFCumulativeTypeParamsDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MFCumulativeTypeParamsDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MFCumulativeTypeParamsDeprecationMsg: typing_extensions.TypeAlias = MFCumulativeTypeParamsDeprecationMsg

@typing.final
class MicrobatchMacroOutsideOfBatchesDeprecation(google.protobuf.message.Message):
    """D020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MicrobatchMacroOutsideOfBatchesDeprecation: typing_extensions.TypeAlias = MicrobatchMacroOutsideOfBatchesDeprecation

@typing.final
class MicrobatchMacroOutsideOfBatchesDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MicrobatchMacroOutsideOfBatchesDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MicrobatchMacroOutsideOfBatchesDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MicrobatchMacroOutsideOfBatchesDeprecationMsg: typing_extensions.TypeAlias = MicrobatchMacroOutsideOfBatchesDeprecationMsg

@typing.final
class GenericJSONSchemaValidationDeprecation(google.protobuf.message.Message):
    """Skipping D021. It belonged to the now deleted PackageRedirectDeprecationSummaryMsg.

    D022
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIOLATION_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    violation: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        violation: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key_path", b"key_path", "violation", b"violation"]) -> None: ...

Global___GenericJSONSchemaValidationDeprecation: typing_extensions.TypeAlias = GenericJSONSchemaValidationDeprecation

@typing.final
class GenericJSONSchemaValidationDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GenericJSONSchemaValidationDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GenericJSONSchemaValidationDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GenericJSONSchemaValidationDeprecationMsg: typing_extensions.TypeAlias = GenericJSONSchemaValidationDeprecationMsg

@typing.final
class UnexpectedJinjaBlockDeprecation(google.protobuf.message.Message):
    """D023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    msg: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "msg", b"msg"]) -> None: ...

Global___UnexpectedJinjaBlockDeprecation: typing_extensions.TypeAlias = UnexpectedJinjaBlockDeprecation

@typing.final
class UnexpectedJinjaBlockDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnexpectedJinjaBlockDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnexpectedJinjaBlockDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnexpectedJinjaBlockDeprecationMsg: typing_extensions.TypeAlias = UnexpectedJinjaBlockDeprecationMsg

@typing.final
class DuplicateYAMLKeysDeprecation(google.protobuf.message.Message):
    """D024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DUPLICATE_DESCRIPTION_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    duplicate_description: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        duplicate_description: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duplicate_description", b"duplicate_description", "file", b"file"]) -> None: ...

Global___DuplicateYAMLKeysDeprecation: typing_extensions.TypeAlias = DuplicateYAMLKeysDeprecation

@typing.final
class DuplicateYAMLKeysDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DuplicateYAMLKeysDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DuplicateYAMLKeysDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DuplicateYAMLKeysDeprecationMsg: typing_extensions.TypeAlias = DuplicateYAMLKeysDeprecationMsg

@typing.final
class CustomTopLevelKeyDeprecation(google.protobuf.message.Message):
    """D025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    msg: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "msg", b"msg"]) -> None: ...

Global___CustomTopLevelKeyDeprecation: typing_extensions.TypeAlias = CustomTopLevelKeyDeprecation

@typing.final
class CustomTopLevelKeyDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CustomTopLevelKeyDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CustomTopLevelKeyDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CustomTopLevelKeyDeprecationMsg: typing_extensions.TypeAlias = CustomTopLevelKeyDeprecationMsg

@typing.final
class CustomKeyInConfigDeprecation(google.protobuf.message.Message):
    """D026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

Global___CustomKeyInConfigDeprecation: typing_extensions.TypeAlias = CustomKeyInConfigDeprecation

@typing.final
class CustomKeyInConfigDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CustomKeyInConfigDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CustomKeyInConfigDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CustomKeyInConfigDeprecationMsg: typing_extensions.TypeAlias = CustomKeyInConfigDeprecationMsg

@typing.final
class CustomKeyInObjectDeprecation(google.protobuf.message.Message):
    """D027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

Global___CustomKeyInObjectDeprecation: typing_extensions.TypeAlias = CustomKeyInObjectDeprecation

@typing.final
class CustomKeyInObjectDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CustomKeyInObjectDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CustomKeyInObjectDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CustomKeyInObjectDeprecationMsg: typing_extensions.TypeAlias = CustomKeyInObjectDeprecationMsg

@typing.final
class DeprecationSummary(google.protobuf.message.Message):
    """D028"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_NAME_FIELD_NUMBER: builtins.int
    EVENT_CODE_FIELD_NUMBER: builtins.int
    OCCURRENCES_FIELD_NUMBER: builtins.int
    event_name: builtins.str
    event_code: builtins.str
    occurrences: builtins.int
    def __init__(
        self,
        *,
        event_name: builtins.str = ...,
        event_code: builtins.str = ...,
        occurrences: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["event_code", b"event_code", "event_name", b"event_name", "occurrences", b"occurrences"]) -> None: ...

Global___DeprecationSummary: typing_extensions.TypeAlias = DeprecationSummary

@typing.final
class DeprecationsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARIES_FIELD_NUMBER: builtins.int
    SHOW_ALL_HINT_FIELD_NUMBER: builtins.int
    show_all_hint: builtins.bool
    @property
    def summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___DeprecationSummary]: ...
    def __init__(
        self,
        *,
        summaries: collections.abc.Iterable[Global___DeprecationSummary] | None = ...,
        show_all_hint: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["show_all_hint", b"show_all_hint", "summaries", b"summaries"]) -> None: ...

Global___DeprecationsSummary: typing_extensions.TypeAlias = DeprecationsSummary

@typing.final
class DeprecationsSummaryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DeprecationsSummary: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DeprecationsSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DeprecationsSummaryMsg: typing_extensions.TypeAlias = DeprecationsSummaryMsg

@typing.final
class CustomOutputPathInSourceFreshnessDeprecation(google.protobuf.message.Message):
    """D029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___CustomOutputPathInSourceFreshnessDeprecation: typing_extensions.TypeAlias = CustomOutputPathInSourceFreshnessDeprecation

@typing.final
class CustomOutputPathInSourceFreshnessDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CustomOutputPathInSourceFreshnessDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CustomOutputPathInSourceFreshnessDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CustomOutputPathInSourceFreshnessDeprecationMsg: typing_extensions.TypeAlias = CustomOutputPathInSourceFreshnessDeprecationMsg

@typing.final
class PropertyMovedToConfigDeprecation(google.protobuf.message.Message):
    """D030"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

Global___PropertyMovedToConfigDeprecation: typing_extensions.TypeAlias = PropertyMovedToConfigDeprecation

@typing.final
class PropertyMovedToConfigDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PropertyMovedToConfigDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PropertyMovedToConfigDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PropertyMovedToConfigDeprecationMsg: typing_extensions.TypeAlias = PropertyMovedToConfigDeprecationMsg

@typing.final
class WEOIncludeExcludeDeprecation(google.protobuf.message.Message):
    """D031"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOUND_INCLUDE_FIELD_NUMBER: builtins.int
    FOUND_EXCLUDE_FIELD_NUMBER: builtins.int
    found_include: builtins.bool
    found_exclude: builtins.bool
    def __init__(
        self,
        *,
        found_include: builtins.bool = ...,
        found_exclude: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["found_exclude", b"found_exclude", "found_include", b"found_include"]) -> None: ...

Global___WEOIncludeExcludeDeprecation: typing_extensions.TypeAlias = WEOIncludeExcludeDeprecation

@typing.final
class WEOIncludeExcludeDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___WEOIncludeExcludeDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___WEOIncludeExcludeDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___WEOIncludeExcludeDeprecationMsg: typing_extensions.TypeAlias = WEOIncludeExcludeDeprecationMsg

@typing.final
class ModelParamUsageDeprecation(google.protobuf.message.Message):
    """D032"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ModelParamUsageDeprecation: typing_extensions.TypeAlias = ModelParamUsageDeprecation

@typing.final
class ModelParamUsageDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ModelParamUsageDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ModelParamUsageDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ModelParamUsageDeprecationMsg: typing_extensions.TypeAlias = ModelParamUsageDeprecationMsg

@typing.final
class ResourceTypesParamUsageDeprecation(google.protobuf.message.Message):
    """D033"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ResourceTypesParamUsageDeprecation: typing_extensions.TypeAlias = ResourceTypesParamUsageDeprecation

@typing.final
class ResourceTypesParamUsageDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ResourceTypesParamUsageDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ResourceTypesParamUsageDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ResourceTypesParamUsageDeprecationMsg: typing_extensions.TypeAlias = ResourceTypesParamUsageDeprecationMsg

@typing.final
class ModulesItertoolsUsageDeprecation(google.protobuf.message.Message):
    """D034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ModulesItertoolsUsageDeprecation: typing_extensions.TypeAlias = ModulesItertoolsUsageDeprecation

@typing.final
class ModulesItertoolsUsageDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ModulesItertoolsUsageDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ModulesItertoolsUsageDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ModulesItertoolsUsageDeprecationMsg: typing_extensions.TypeAlias = ModulesItertoolsUsageDeprecationMsg

@typing.final
class SourceOverrideDeprecation(google.protobuf.message.Message):
    """D035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_NAME_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    source_name: builtins.str
    file: builtins.str
    def __init__(
        self,
        *,
        source_name: builtins.str = ...,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "source_name", b"source_name"]) -> None: ...

Global___SourceOverrideDeprecation: typing_extensions.TypeAlias = SourceOverrideDeprecation

@typing.final
class SourceOverrideDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SourceOverrideDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SourceOverrideDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SourceOverrideDeprecationMsg: typing_extensions.TypeAlias = SourceOverrideDeprecationMsg

@typing.final
class EnvironmentVariableNamespaceDeprecation(google.protobuf.message.Message):
    """D036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_VAR_FIELD_NUMBER: builtins.int
    RESERVED_PREFIX_FIELD_NUMBER: builtins.int
    env_var: builtins.str
    reserved_prefix: builtins.str
    def __init__(
        self,
        *,
        env_var: builtins.str = ...,
        reserved_prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["env_var", b"env_var", "reserved_prefix", b"reserved_prefix"]) -> None: ...

Global___EnvironmentVariableNamespaceDeprecation: typing_extensions.TypeAlias = EnvironmentVariableNamespaceDeprecation

@typing.final
class EnvironmentVariableNamespaceDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___EnvironmentVariableNamespaceDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___EnvironmentVariableNamespaceDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___EnvironmentVariableNamespaceDeprecationMsg: typing_extensions.TypeAlias = EnvironmentVariableNamespaceDeprecationMsg

@typing.final
class MissingPlusPrefixDeprecation(google.protobuf.message.Message):
    """D037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    KEY_PATH_FIELD_NUMBER: builtins.int
    key: builtins.str
    file: builtins.str
    key_path: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        file: builtins.str = ...,
        key_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "key", b"key", "key_path", b"key_path"]) -> None: ...

Global___MissingPlusPrefixDeprecation: typing_extensions.TypeAlias = MissingPlusPrefixDeprecation

@typing.final
class MissingPlusPrefixDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MissingPlusPrefixDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MissingPlusPrefixDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MissingPlusPrefixDeprecationMsg: typing_extensions.TypeAlias = MissingPlusPrefixDeprecationMsg

@typing.final
class ArgsPropertyInGenericTestDeprecation(google.protobuf.message.Message):
    """unused"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file"]) -> None: ...

Global___ArgsPropertyInGenericTestDeprecation: typing_extensions.TypeAlias = ArgsPropertyInGenericTestDeprecation

@typing.final
class ArgsPropertyInGenericTestDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ArgsPropertyInGenericTestDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ArgsPropertyInGenericTestDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ArgsPropertyInGenericTestDeprecationMsg: typing_extensions.TypeAlias = ArgsPropertyInGenericTestDeprecationMsg

@typing.final
class ArgumentsPropertyInGenericTestDeprecation(google.protobuf.message.Message):
    """D038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_NAME_FIELD_NUMBER: builtins.int
    test_name: builtins.str
    def __init__(
        self,
        *,
        test_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_name", b"test_name"]) -> None: ...

Global___ArgumentsPropertyInGenericTestDeprecation: typing_extensions.TypeAlias = ArgumentsPropertyInGenericTestDeprecation

@typing.final
class ArgumentsPropertyInGenericTestDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ArgumentsPropertyInGenericTestDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ArgumentsPropertyInGenericTestDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ArgumentsPropertyInGenericTestDeprecationMsg: typing_extensions.TypeAlias = ArgumentsPropertyInGenericTestDeprecationMsg

@typing.final
class MissingArgumentsPropertyInGenericTestDeprecation(google.protobuf.message.Message):
    """D039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_NAME_FIELD_NUMBER: builtins.int
    test_name: builtins.str
    def __init__(
        self,
        *,
        test_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_name", b"test_name"]) -> None: ...

Global___MissingArgumentsPropertyInGenericTestDeprecation: typing_extensions.TypeAlias = MissingArgumentsPropertyInGenericTestDeprecation

@typing.final
class MissingArgumentsPropertyInGenericTestDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MissingArgumentsPropertyInGenericTestDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MissingArgumentsPropertyInGenericTestDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MissingArgumentsPropertyInGenericTestDeprecationMsg: typing_extensions.TypeAlias = MissingArgumentsPropertyInGenericTestDeprecationMsg

@typing.final
class DuplicateNameDistinctNodeTypesDeprecation(google.protobuf.message.Message):
    """D040"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    UNIQUE_ID1_FIELD_NUMBER: builtins.int
    UNIQUE_ID2_FIELD_NUMBER: builtins.int
    resource_name: builtins.str
    package_name: builtins.str
    unique_id1: builtins.str
    unique_id2: builtins.str
    def __init__(
        self,
        *,
        resource_name: builtins.str = ...,
        package_name: builtins.str = ...,
        unique_id1: builtins.str = ...,
        unique_id2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name", "resource_name", b"resource_name", "unique_id1", b"unique_id1", "unique_id2", b"unique_id2"]) -> None: ...

Global___DuplicateNameDistinctNodeTypesDeprecation: typing_extensions.TypeAlias = DuplicateNameDistinctNodeTypesDeprecation

@typing.final
class DuplicateNameDistinctNodeTypesDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DuplicateNameDistinctNodeTypesDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DuplicateNameDistinctNodeTypesDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DuplicateNameDistinctNodeTypesDeprecationMsg: typing_extensions.TypeAlias = DuplicateNameDistinctNodeTypesDeprecationMsg

@typing.final
class DeprecatedModel(google.protobuf.message.Message):
    """I065"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    DEPRECATION_DATE_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    model_version: builtins.str
    deprecation_date: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        model_version: builtins.str = ...,
        deprecation_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecation_date", b"deprecation_date", "model_name", b"model_name", "model_version", b"model_version"]) -> None: ...

Global___DeprecatedModel: typing_extensions.TypeAlias = DeprecatedModel

@typing.final
class DeprecatedModelMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DeprecatedModel: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DeprecatedModel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DeprecatedModelMsg: typing_extensions.TypeAlias = DeprecatedModelMsg

@typing.final
class InputFileDiffError(google.protobuf.message.Message):
    """I - Project parsing

    I001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    FILE_ID_FIELD_NUMBER: builtins.int
    category: builtins.str
    file_id: builtins.str
    def __init__(
        self,
        *,
        category: builtins.str = ...,
        file_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "file_id", b"file_id"]) -> None: ...

Global___InputFileDiffError: typing_extensions.TypeAlias = InputFileDiffError

@typing.final
class InputFileDiffErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InputFileDiffError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InputFileDiffError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InputFileDiffErrorMsg: typing_extensions.TypeAlias = InputFileDiffErrorMsg

@typing.final
class InvalidValueForField(google.protobuf.message.Message):
    """Skipping I002, I003, I004, I005, I006, I007

    I008
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_NAME_FIELD_NUMBER: builtins.int
    FIELD_VALUE_FIELD_NUMBER: builtins.int
    field_name: builtins.str
    field_value: builtins.str
    def __init__(
        self,
        *,
        field_name: builtins.str = ...,
        field_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field_name", b"field_name", "field_value", b"field_value"]) -> None: ...

Global___InvalidValueForField: typing_extensions.TypeAlias = InvalidValueForField

@typing.final
class InvalidValueForFieldMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InvalidValueForField: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InvalidValueForField | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InvalidValueForFieldMsg: typing_extensions.TypeAlias = InvalidValueForFieldMsg

@typing.final
class ValidationWarning(google.protobuf.message.Message):
    """I009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    FIELD_NAME_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    field_name: builtins.str
    node_name: builtins.str
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        field_name: builtins.str = ...,
        node_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["field_name", b"field_name", "node_name", b"node_name", "resource_type", b"resource_type"]) -> None: ...

Global___ValidationWarning: typing_extensions.TypeAlias = ValidationWarning

@typing.final
class ValidationWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ValidationWarning: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ValidationWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ValidationWarningMsg: typing_extensions.TypeAlias = ValidationWarningMsg

@typing.final
class ParsePerfInfoPath(google.protobuf.message.Message):
    """I010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___ParsePerfInfoPath: typing_extensions.TypeAlias = ParsePerfInfoPath

@typing.final
class ParsePerfInfoPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ParsePerfInfoPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ParsePerfInfoPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ParsePerfInfoPathMsg: typing_extensions.TypeAlias = ParsePerfInfoPathMsg

@typing.final
class PartialParsingErrorProcessingFile(google.protobuf.message.Message):
    """Skipping I013

    I014
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file"]) -> None: ...

Global___PartialParsingErrorProcessingFile: typing_extensions.TypeAlias = PartialParsingErrorProcessingFile

@typing.final
class PartialParsingErrorProcessingFileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PartialParsingErrorProcessingFile: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PartialParsingErrorProcessingFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PartialParsingErrorProcessingFileMsg: typing_extensions.TypeAlias = PartialParsingErrorProcessingFileMsg

@typing.final
class PartialParsingError(google.protobuf.message.Message):
    """I016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExcInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    EXC_INFO_FIELD_NUMBER: builtins.int
    @property
    def exc_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        exc_info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

Global___PartialParsingError: typing_extensions.TypeAlias = PartialParsingError

@typing.final
class PartialParsingErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PartialParsingError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PartialParsingError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PartialParsingErrorMsg: typing_extensions.TypeAlias = PartialParsingErrorMsg

@typing.final
class PartialParsingSkipParsing(google.protobuf.message.Message):
    """I017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___PartialParsingSkipParsing: typing_extensions.TypeAlias = PartialParsingSkipParsing

@typing.final
class PartialParsingSkipParsingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PartialParsingSkipParsing: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PartialParsingSkipParsing | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PartialParsingSkipParsingMsg: typing_extensions.TypeAlias = PartialParsingSkipParsingMsg

@typing.final
class UnableToPartialParse(google.protobuf.message.Message):
    """Skipped I018, I019, I020, I021, I022, I023

    I024
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    reason: builtins.str
    def __init__(
        self,
        *,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason"]) -> None: ...

Global___UnableToPartialParse: typing_extensions.TypeAlias = UnableToPartialParse

@typing.final
class UnableToPartialParseMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnableToPartialParse: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnableToPartialParse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnableToPartialParseMsg: typing_extensions.TypeAlias = UnableToPartialParseMsg

@typing.final
class StateCheckVarsHash(google.protobuf.message.Message):
    """I025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECKSUM_FIELD_NUMBER: builtins.int
    VARS_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    checksum: builtins.str
    vars: builtins.str
    profile: builtins.str
    target: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        checksum: builtins.str = ...,
        vars: builtins.str = ...,
        profile: builtins.str = ...,
        target: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["checksum", b"checksum", "profile", b"profile", "target", b"target", "vars", b"vars", "version", b"version"]) -> None: ...

Global___StateCheckVarsHash: typing_extensions.TypeAlias = StateCheckVarsHash

@typing.final
class StateCheckVarsHashMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___StateCheckVarsHash: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___StateCheckVarsHash | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___StateCheckVarsHashMsg: typing_extensions.TypeAlias = StateCheckVarsHashMsg

@typing.final
class PartialParsingNotEnabled(google.protobuf.message.Message):
    """Skipped I026, I027

    I028
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___PartialParsingNotEnabled: typing_extensions.TypeAlias = PartialParsingNotEnabled

@typing.final
class PartialParsingNotEnabledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PartialParsingNotEnabled: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PartialParsingNotEnabled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PartialParsingNotEnabledMsg: typing_extensions.TypeAlias = PartialParsingNotEnabledMsg

@typing.final
class ParsedFileLoadFailed(google.protobuf.message.Message):
    """I029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    exc: builtins.str
    exc_info: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "path", b"path"]) -> None: ...

Global___ParsedFileLoadFailed: typing_extensions.TypeAlias = ParsedFileLoadFailed

@typing.final
class ParsedFileLoadFailedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ParsedFileLoadFailed: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ParsedFileLoadFailed | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ParsedFileLoadFailedMsg: typing_extensions.TypeAlias = ParsedFileLoadFailedMsg

@typing.final
class PartialParsingEnabled(google.protobuf.message.Message):
    """Skipping I030 - I039

    I040
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_FIELD_NUMBER: builtins.int
    ADDED_FIELD_NUMBER: builtins.int
    CHANGED_FIELD_NUMBER: builtins.int
    deleted: builtins.int
    added: builtins.int
    changed: builtins.int
    def __init__(
        self,
        *,
        deleted: builtins.int = ...,
        added: builtins.int = ...,
        changed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added", b"added", "changed", b"changed", "deleted", b"deleted"]) -> None: ...

Global___PartialParsingEnabled: typing_extensions.TypeAlias = PartialParsingEnabled

@typing.final
class PartialParsingEnabledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PartialParsingEnabled: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PartialParsingEnabled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PartialParsingEnabledMsg: typing_extensions.TypeAlias = PartialParsingEnabledMsg

@typing.final
class PartialParsingFile(google.protobuf.message.Message):
    """I041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    operation: builtins.str
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
        operation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id", "operation", b"operation"]) -> None: ...

Global___PartialParsingFile: typing_extensions.TypeAlias = PartialParsingFile

@typing.final
class PartialParsingFileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___PartialParsingFile: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___PartialParsingFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PartialParsingFileMsg: typing_extensions.TypeAlias = PartialParsingFileMsg

@typing.final
class InvalidDisabledTargetInTestNode(google.protobuf.message.Message):
    """Skipped I042, I043, I044, I045, I046, I047, I048, I049

    I050
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_TITLE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    ORIGINAL_FILE_PATH_FIELD_NUMBER: builtins.int
    TARGET_KIND_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    TARGET_PACKAGE_FIELD_NUMBER: builtins.int
    resource_type_title: builtins.str
    unique_id: builtins.str
    original_file_path: builtins.str
    target_kind: builtins.str
    target_name: builtins.str
    target_package: builtins.str
    def __init__(
        self,
        *,
        resource_type_title: builtins.str = ...,
        unique_id: builtins.str = ...,
        original_file_path: builtins.str = ...,
        target_kind: builtins.str = ...,
        target_name: builtins.str = ...,
        target_package: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["original_file_path", b"original_file_path", "resource_type_title", b"resource_type_title", "target_kind", b"target_kind", "target_name", b"target_name", "target_package", b"target_package", "unique_id", b"unique_id"]) -> None: ...

Global___InvalidDisabledTargetInTestNode: typing_extensions.TypeAlias = InvalidDisabledTargetInTestNode

@typing.final
class InvalidDisabledTargetInTestNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InvalidDisabledTargetInTestNode: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InvalidDisabledTargetInTestNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InvalidDisabledTargetInTestNodeMsg: typing_extensions.TypeAlias = InvalidDisabledTargetInTestNodeMsg

@typing.final
class UnusedResourceConfigPath(google.protobuf.message.Message):
    """I051"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNUSED_CONFIG_PATHS_FIELD_NUMBER: builtins.int
    @property
    def unused_config_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        unused_config_paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["unused_config_paths", b"unused_config_paths"]) -> None: ...

Global___UnusedResourceConfigPath: typing_extensions.TypeAlias = UnusedResourceConfigPath

@typing.final
class UnusedResourceConfigPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnusedResourceConfigPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnusedResourceConfigPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnusedResourceConfigPathMsg: typing_extensions.TypeAlias = UnusedResourceConfigPathMsg

@typing.final
class SeedIncreased(google.protobuf.message.Message):
    """I052"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "package_name", b"package_name"]) -> None: ...

Global___SeedIncreased: typing_extensions.TypeAlias = SeedIncreased

@typing.final
class SeedIncreasedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SeedIncreased: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SeedIncreased | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SeedIncreasedMsg: typing_extensions.TypeAlias = SeedIncreasedMsg

@typing.final
class SeedExceedsLimitSamePath(google.protobuf.message.Message):
    """I053"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "package_name", b"package_name"]) -> None: ...

Global___SeedExceedsLimitSamePath: typing_extensions.TypeAlias = SeedExceedsLimitSamePath

@typing.final
class SeedExceedsLimitSamePathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SeedExceedsLimitSamePath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SeedExceedsLimitSamePath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SeedExceedsLimitSamePathMsg: typing_extensions.TypeAlias = SeedExceedsLimitSamePathMsg

@typing.final
class SeedExceedsLimitAndPathChanged(google.protobuf.message.Message):
    """I054"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "package_name", b"package_name"]) -> None: ...

Global___SeedExceedsLimitAndPathChanged: typing_extensions.TypeAlias = SeedExceedsLimitAndPathChanged

@typing.final
class SeedExceedsLimitAndPathChangedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SeedExceedsLimitAndPathChanged: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SeedExceedsLimitAndPathChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SeedExceedsLimitAndPathChangedMsg: typing_extensions.TypeAlias = SeedExceedsLimitAndPathChangedMsg

@typing.final
class SeedExceedsLimitChecksumChanged(google.protobuf.message.Message):
    """I055"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CHECKSUM_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    name: builtins.str
    checksum_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
        checksum_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["checksum_name", b"checksum_name", "name", b"name", "package_name", b"package_name"]) -> None: ...

Global___SeedExceedsLimitChecksumChanged: typing_extensions.TypeAlias = SeedExceedsLimitChecksumChanged

@typing.final
class SeedExceedsLimitChecksumChangedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SeedExceedsLimitChecksumChanged: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SeedExceedsLimitChecksumChanged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SeedExceedsLimitChecksumChangedMsg: typing_extensions.TypeAlias = SeedExceedsLimitChecksumChangedMsg

@typing.final
class UnusedTables(google.protobuf.message.Message):
    """I056"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNUSED_TABLES_FIELD_NUMBER: builtins.int
    @property
    def unused_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        unused_tables: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["unused_tables", b"unused_tables"]) -> None: ...

Global___UnusedTables: typing_extensions.TypeAlias = UnusedTables

@typing.final
class UnusedTablesMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnusedTables: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnusedTables | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnusedTablesMsg: typing_extensions.TypeAlias = UnusedTablesMsg

@typing.final
class WrongResourceSchemaFile(google.protobuf.message.Message):
    """I057"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATCH_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    PLURAL_RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    YAML_KEY_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    patch_name: builtins.str
    resource_type: builtins.str
    plural_resource_type: builtins.str
    yaml_key: builtins.str
    file_path: builtins.str
    def __init__(
        self,
        *,
        patch_name: builtins.str = ...,
        resource_type: builtins.str = ...,
        plural_resource_type: builtins.str = ...,
        yaml_key: builtins.str = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "patch_name", b"patch_name", "plural_resource_type", b"plural_resource_type", "resource_type", b"resource_type", "yaml_key", b"yaml_key"]) -> None: ...

Global___WrongResourceSchemaFile: typing_extensions.TypeAlias = WrongResourceSchemaFile

@typing.final
class WrongResourceSchemaFileMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___WrongResourceSchemaFile: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___WrongResourceSchemaFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___WrongResourceSchemaFileMsg: typing_extensions.TypeAlias = WrongResourceSchemaFileMsg

@typing.final
class NoNodeForYamlKey(google.protobuf.message.Message):
    """I058"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATCH_NAME_FIELD_NUMBER: builtins.int
    YAML_KEY_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    patch_name: builtins.str
    yaml_key: builtins.str
    file_path: builtins.str
    def __init__(
        self,
        *,
        patch_name: builtins.str = ...,
        yaml_key: builtins.str = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_path", b"file_path", "patch_name", b"patch_name", "yaml_key", b"yaml_key"]) -> None: ...

Global___NoNodeForYamlKey: typing_extensions.TypeAlias = NoNodeForYamlKey

@typing.final
class NoNodeForYamlKeyMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NoNodeForYamlKey: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NoNodeForYamlKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NoNodeForYamlKeyMsg: typing_extensions.TypeAlias = NoNodeForYamlKeyMsg

@typing.final
class MacroNotFoundForPatch(google.protobuf.message.Message):
    """I059"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATCH_NAME_FIELD_NUMBER: builtins.int
    patch_name: builtins.str
    def __init__(
        self,
        *,
        patch_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["patch_name", b"patch_name"]) -> None: ...

Global___MacroNotFoundForPatch: typing_extensions.TypeAlias = MacroNotFoundForPatch

@typing.final
class MacroNotFoundForPatchMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MacroNotFoundForPatch: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MacroNotFoundForPatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MacroNotFoundForPatchMsg: typing_extensions.TypeAlias = MacroNotFoundForPatchMsg

@typing.final
class NodeNotFoundOrDisabled(google.protobuf.message.Message):
    """I060"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_FILE_PATH_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_TITLE_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    TARGET_KIND_FIELD_NUMBER: builtins.int
    TARGET_PACKAGE_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    original_file_path: builtins.str
    unique_id: builtins.str
    resource_type_title: builtins.str
    target_name: builtins.str
    target_kind: builtins.str
    target_package: builtins.str
    disabled: builtins.str
    def __init__(
        self,
        *,
        original_file_path: builtins.str = ...,
        unique_id: builtins.str = ...,
        resource_type_title: builtins.str = ...,
        target_name: builtins.str = ...,
        target_kind: builtins.str = ...,
        target_package: builtins.str = ...,
        disabled: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "original_file_path", b"original_file_path", "resource_type_title", b"resource_type_title", "target_kind", b"target_kind", "target_name", b"target_name", "target_package", b"target_package", "unique_id", b"unique_id"]) -> None: ...

Global___NodeNotFoundOrDisabled: typing_extensions.TypeAlias = NodeNotFoundOrDisabled

@typing.final
class NodeNotFoundOrDisabledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NodeNotFoundOrDisabled: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NodeNotFoundOrDisabled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NodeNotFoundOrDisabledMsg: typing_extensions.TypeAlias = NodeNotFoundOrDisabledMsg

@typing.final
class JinjaLogWarning(google.protobuf.message.Message):
    """I061"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

Global___JinjaLogWarning: typing_extensions.TypeAlias = JinjaLogWarning

@typing.final
class JinjaLogWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___JinjaLogWarning: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___JinjaLogWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___JinjaLogWarningMsg: typing_extensions.TypeAlias = JinjaLogWarningMsg

@typing.final
class JinjaLogInfo(google.protobuf.message.Message):
    """I062"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

Global___JinjaLogInfo: typing_extensions.TypeAlias = JinjaLogInfo

@typing.final
class JinjaLogInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___JinjaLogInfo: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___JinjaLogInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___JinjaLogInfoMsg: typing_extensions.TypeAlias = JinjaLogInfoMsg

@typing.final
class JinjaLogDebug(google.protobuf.message.Message):
    """I063"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

Global___JinjaLogDebug: typing_extensions.TypeAlias = JinjaLogDebug

@typing.final
class JinjaLogDebugMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___JinjaLogDebug: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___JinjaLogDebug | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___JinjaLogDebugMsg: typing_extensions.TypeAlias = JinjaLogDebugMsg

@typing.final
class UnpinnedRefNewVersionAvailable(google.protobuf.message.Message):
    """I064"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    REF_NODE_NAME_FIELD_NUMBER: builtins.int
    REF_NODE_PACKAGE_FIELD_NUMBER: builtins.int
    REF_NODE_VERSION_FIELD_NUMBER: builtins.int
    REF_MAX_VERSION_FIELD_NUMBER: builtins.int
    ref_node_name: builtins.str
    ref_node_package: builtins.str
    ref_node_version: builtins.str
    ref_max_version: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        ref_node_name: builtins.str = ...,
        ref_node_package: builtins.str = ...,
        ref_node_version: builtins.str = ...,
        ref_max_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "ref_max_version", b"ref_max_version", "ref_node_name", b"ref_node_name", "ref_node_package", b"ref_node_package", "ref_node_version", b"ref_node_version"]) -> None: ...

Global___UnpinnedRefNewVersionAvailable: typing_extensions.TypeAlias = UnpinnedRefNewVersionAvailable

@typing.final
class UnpinnedRefNewVersionAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnpinnedRefNewVersionAvailable: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnpinnedRefNewVersionAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnpinnedRefNewVersionAvailableMsg: typing_extensions.TypeAlias = UnpinnedRefNewVersionAvailableMsg

@typing.final
class UpcomingReferenceDeprecation(google.protobuf.message.Message):
    """I066"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_PACKAGE_FIELD_NUMBER: builtins.int
    REF_MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_LATEST_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_DEPRECATION_DATE_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    ref_model_package: builtins.str
    ref_model_name: builtins.str
    ref_model_version: builtins.str
    ref_model_latest_version: builtins.str
    ref_model_deprecation_date: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        ref_model_package: builtins.str = ...,
        ref_model_name: builtins.str = ...,
        ref_model_version: builtins.str = ...,
        ref_model_latest_version: builtins.str = ...,
        ref_model_deprecation_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_name", b"model_name", "ref_model_deprecation_date", b"ref_model_deprecation_date", "ref_model_latest_version", b"ref_model_latest_version", "ref_model_name", b"ref_model_name", "ref_model_package", b"ref_model_package", "ref_model_version", b"ref_model_version"]) -> None: ...

Global___UpcomingReferenceDeprecation: typing_extensions.TypeAlias = UpcomingReferenceDeprecation

@typing.final
class UpcomingReferenceDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UpcomingReferenceDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UpcomingReferenceDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UpcomingReferenceDeprecationMsg: typing_extensions.TypeAlias = UpcomingReferenceDeprecationMsg

@typing.final
class DeprecatedReference(google.protobuf.message.Message):
    """I067"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_PACKAGE_FIELD_NUMBER: builtins.int
    REF_MODEL_NAME_FIELD_NUMBER: builtins.int
    REF_MODEL_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_LATEST_VERSION_FIELD_NUMBER: builtins.int
    REF_MODEL_DEPRECATION_DATE_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    ref_model_package: builtins.str
    ref_model_name: builtins.str
    ref_model_version: builtins.str
    ref_model_latest_version: builtins.str
    ref_model_deprecation_date: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        ref_model_package: builtins.str = ...,
        ref_model_name: builtins.str = ...,
        ref_model_version: builtins.str = ...,
        ref_model_latest_version: builtins.str = ...,
        ref_model_deprecation_date: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_name", b"model_name", "ref_model_deprecation_date", b"ref_model_deprecation_date", "ref_model_latest_version", b"ref_model_latest_version", "ref_model_name", b"ref_model_name", "ref_model_package", b"ref_model_package", "ref_model_version", b"ref_model_version"]) -> None: ...

Global___DeprecatedReference: typing_extensions.TypeAlias = DeprecatedReference

@typing.final
class DeprecatedReferenceMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DeprecatedReference: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DeprecatedReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DeprecatedReferenceMsg: typing_extensions.TypeAlias = DeprecatedReferenceMsg

@typing.final
class UnsupportedConstraintMaterialization(google.protobuf.message.Message):
    """I068"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIALIZED_FIELD_NUMBER: builtins.int
    materialized: builtins.str
    def __init__(
        self,
        *,
        materialized: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["materialized", b"materialized"]) -> None: ...

Global___UnsupportedConstraintMaterialization: typing_extensions.TypeAlias = UnsupportedConstraintMaterialization

@typing.final
class UnsupportedConstraintMaterializationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnsupportedConstraintMaterialization: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnsupportedConstraintMaterialization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnsupportedConstraintMaterializationMsg: typing_extensions.TypeAlias = UnsupportedConstraintMaterializationMsg

@typing.final
class ParseInlineNodeError(google.protobuf.message.Message):
    """I069"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        exc: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "node_info", b"node_info"]) -> None: ...

Global___ParseInlineNodeError: typing_extensions.TypeAlias = ParseInlineNodeError

@typing.final
class ParseInlineNodeErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ParseInlineNodeError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ParseInlineNodeError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ParseInlineNodeErrorMsg: typing_extensions.TypeAlias = ParseInlineNodeErrorMsg

@typing.final
class SemanticValidationFailure(google.protobuf.message.Message):
    """I070"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___SemanticValidationFailure: typing_extensions.TypeAlias = SemanticValidationFailure

@typing.final
class SemanticValidationFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SemanticValidationFailure: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SemanticValidationFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SemanticValidationFailureMsg: typing_extensions.TypeAlias = SemanticValidationFailureMsg

@typing.final
class UnversionedBreakingChange(google.protobuf.message.Message):
    """I071"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BREAKING_CHANGES_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    MODEL_FILE_PATH_FIELD_NUMBER: builtins.int
    CONTRACT_ENFORCED_DISABLED_FIELD_NUMBER: builtins.int
    COLUMNS_REMOVED_FIELD_NUMBER: builtins.int
    COLUMN_TYPE_CHANGES_FIELD_NUMBER: builtins.int
    ENFORCED_COLUMN_CONSTRAINT_REMOVED_FIELD_NUMBER: builtins.int
    ENFORCED_MODEL_CONSTRAINT_REMOVED_FIELD_NUMBER: builtins.int
    MATERIALIZATION_CHANGED_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    model_file_path: builtins.str
    contract_enforced_disabled: builtins.bool
    @property
    def breaking_changes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def columns_removed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def column_type_changes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ColumnType]: ...
    @property
    def enforced_column_constraint_removed(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ColumnConstraint]: ...
    @property
    def enforced_model_constraint_removed(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ModelConstraint]: ...
    @property
    def materialization_changed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        breaking_changes: collections.abc.Iterable[builtins.str] | None = ...,
        model_name: builtins.str = ...,
        model_file_path: builtins.str = ...,
        contract_enforced_disabled: builtins.bool = ...,
        columns_removed: collections.abc.Iterable[builtins.str] | None = ...,
        column_type_changes: collections.abc.Iterable[Global___ColumnType] | None = ...,
        enforced_column_constraint_removed: collections.abc.Iterable[Global___ColumnConstraint] | None = ...,
        enforced_model_constraint_removed: collections.abc.Iterable[Global___ModelConstraint] | None = ...,
        materialization_changed: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["breaking_changes", b"breaking_changes", "column_type_changes", b"column_type_changes", "columns_removed", b"columns_removed", "contract_enforced_disabled", b"contract_enforced_disabled", "enforced_column_constraint_removed", b"enforced_column_constraint_removed", "enforced_model_constraint_removed", b"enforced_model_constraint_removed", "materialization_changed", b"materialization_changed", "model_file_path", b"model_file_path", "model_name", b"model_name"]) -> None: ...

Global___UnversionedBreakingChange: typing_extensions.TypeAlias = UnversionedBreakingChange

@typing.final
class UnversionedBreakingChangeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___UnversionedBreakingChange: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___UnversionedBreakingChange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___UnversionedBreakingChangeMsg: typing_extensions.TypeAlias = UnversionedBreakingChangeMsg

@typing.final
class WarnStateTargetEqual(google.protobuf.message.Message):
    """I072"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_PATH_FIELD_NUMBER: builtins.int
    state_path: builtins.str
    def __init__(
        self,
        *,
        state_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["state_path", b"state_path"]) -> None: ...

Global___WarnStateTargetEqual: typing_extensions.TypeAlias = WarnStateTargetEqual

@typing.final
class WarnStateTargetEqualMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___WarnStateTargetEqual: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___WarnStateTargetEqual | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___WarnStateTargetEqualMsg: typing_extensions.TypeAlias = WarnStateTargetEqualMsg

@typing.final
class FreshnessConfigProblem(google.protobuf.message.Message):
    """I073"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___FreshnessConfigProblem: typing_extensions.TypeAlias = FreshnessConfigProblem

@typing.final
class FreshnessConfigProblemMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___FreshnessConfigProblem: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___FreshnessConfigProblem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FreshnessConfigProblemMsg: typing_extensions.TypeAlias = FreshnessConfigProblemMsg

@typing.final
class MicrobatchModelNoEventTimeInputs(google.protobuf.message.Message):
    """I074"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_name", b"model_name"]) -> None: ...

Global___MicrobatchModelNoEventTimeInputs: typing_extensions.TypeAlias = MicrobatchModelNoEventTimeInputs

@typing.final
class MicrobatchModelNoEventTimeInputsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MicrobatchModelNoEventTimeInputs: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MicrobatchModelNoEventTimeInputs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MicrobatchModelNoEventTimeInputsMsg: typing_extensions.TypeAlias = MicrobatchModelNoEventTimeInputsMsg

@typing.final
class InvalidConcurrentBatchesConfig(google.protobuf.message.Message):
    """I075"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_MODELS_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    num_models: builtins.int
    adapter_type: builtins.str
    def __init__(
        self,
        *,
        num_models: builtins.int = ...,
        adapter_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "num_models", b"num_models"]) -> None: ...

Global___InvalidConcurrentBatchesConfig: typing_extensions.TypeAlias = InvalidConcurrentBatchesConfig

@typing.final
class InvalidConcurrentBatchesConfigMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InvalidConcurrentBatchesConfig: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InvalidConcurrentBatchesConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InvalidConcurrentBatchesConfigMsg: typing_extensions.TypeAlias = InvalidConcurrentBatchesConfigMsg

@typing.final
class InvalidMacroAnnotation(google.protobuf.message.Message):
    """I076"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    MACRO_UNIQUE_ID_FIELD_NUMBER: builtins.int
    MACRO_FILE_PATH_FIELD_NUMBER: builtins.int
    msg: builtins.str
    macro_unique_id: builtins.str
    macro_file_path: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        macro_unique_id: builtins.str = ...,
        macro_file_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["macro_file_path", b"macro_file_path", "macro_unique_id", b"macro_unique_id", "msg", b"msg"]) -> None: ...

Global___InvalidMacroAnnotation: typing_extensions.TypeAlias = InvalidMacroAnnotation

@typing.final
class InvalidMacroAnnotationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InvalidMacroAnnotation: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InvalidMacroAnnotation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InvalidMacroAnnotationMsg: typing_extensions.TypeAlias = InvalidMacroAnnotationMsg

@typing.final
class GitSparseCheckoutSubdirectory(google.protobuf.message.Message):
    """M - Deps generation

    M001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBDIR_FIELD_NUMBER: builtins.int
    subdir: builtins.str
    def __init__(
        self,
        *,
        subdir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subdir", b"subdir"]) -> None: ...

Global___GitSparseCheckoutSubdirectory: typing_extensions.TypeAlias = GitSparseCheckoutSubdirectory

@typing.final
class GitSparseCheckoutSubdirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitSparseCheckoutSubdirectory: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitSparseCheckoutSubdirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitSparseCheckoutSubdirectoryMsg: typing_extensions.TypeAlias = GitSparseCheckoutSubdirectoryMsg

@typing.final
class GitProgressCheckoutRevision(google.protobuf.message.Message):
    """M002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REVISION_FIELD_NUMBER: builtins.int
    revision: builtins.str
    def __init__(
        self,
        *,
        revision: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["revision", b"revision"]) -> None: ...

Global___GitProgressCheckoutRevision: typing_extensions.TypeAlias = GitProgressCheckoutRevision

@typing.final
class GitProgressCheckoutRevisionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitProgressCheckoutRevision: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitProgressCheckoutRevision | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitProgressCheckoutRevisionMsg: typing_extensions.TypeAlias = GitProgressCheckoutRevisionMsg

@typing.final
class GitProgressUpdatingExistingDependency(google.protobuf.message.Message):
    """M003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

Global___GitProgressUpdatingExistingDependency: typing_extensions.TypeAlias = GitProgressUpdatingExistingDependency

@typing.final
class GitProgressUpdatingExistingDependencyMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitProgressUpdatingExistingDependency: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitProgressUpdatingExistingDependency | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitProgressUpdatingExistingDependencyMsg: typing_extensions.TypeAlias = GitProgressUpdatingExistingDependencyMsg

@typing.final
class GitProgressPullingNewDependency(google.protobuf.message.Message):
    """M004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIR_FIELD_NUMBER: builtins.int
    dir: builtins.str
    def __init__(
        self,
        *,
        dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dir", b"dir"]) -> None: ...

Global___GitProgressPullingNewDependency: typing_extensions.TypeAlias = GitProgressPullingNewDependency

@typing.final
class GitProgressPullingNewDependencyMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitProgressPullingNewDependency: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitProgressPullingNewDependency | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitProgressPullingNewDependencyMsg: typing_extensions.TypeAlias = GitProgressPullingNewDependencyMsg

@typing.final
class GitNothingToDo(google.protobuf.message.Message):
    """M005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHA_FIELD_NUMBER: builtins.int
    sha: builtins.str
    def __init__(
        self,
        *,
        sha: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sha", b"sha"]) -> None: ...

Global___GitNothingToDo: typing_extensions.TypeAlias = GitNothingToDo

@typing.final
class GitNothingToDoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitNothingToDo: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitNothingToDo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitNothingToDoMsg: typing_extensions.TypeAlias = GitNothingToDoMsg

@typing.final
class GitProgressUpdatedCheckoutRange(google.protobuf.message.Message):
    """M006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_SHA_FIELD_NUMBER: builtins.int
    END_SHA_FIELD_NUMBER: builtins.int
    start_sha: builtins.str
    end_sha: builtins.str
    def __init__(
        self,
        *,
        start_sha: builtins.str = ...,
        end_sha: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_sha", b"end_sha", "start_sha", b"start_sha"]) -> None: ...

Global___GitProgressUpdatedCheckoutRange: typing_extensions.TypeAlias = GitProgressUpdatedCheckoutRange

@typing.final
class GitProgressUpdatedCheckoutRangeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitProgressUpdatedCheckoutRange: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitProgressUpdatedCheckoutRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitProgressUpdatedCheckoutRangeMsg: typing_extensions.TypeAlias = GitProgressUpdatedCheckoutRangeMsg

@typing.final
class GitProgressCheckedOutAt(google.protobuf.message.Message):
    """M007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_SHA_FIELD_NUMBER: builtins.int
    end_sha: builtins.str
    def __init__(
        self,
        *,
        end_sha: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_sha", b"end_sha"]) -> None: ...

Global___GitProgressCheckedOutAt: typing_extensions.TypeAlias = GitProgressCheckedOutAt

@typing.final
class GitProgressCheckedOutAtMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GitProgressCheckedOutAt: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GitProgressCheckedOutAt | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GitProgressCheckedOutAtMsg: typing_extensions.TypeAlias = GitProgressCheckedOutAtMsg

@typing.final
class RegistryProgressGETRequest(google.protobuf.message.Message):
    """M008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

Global___RegistryProgressGETRequest: typing_extensions.TypeAlias = RegistryProgressGETRequest

@typing.final
class RegistryProgressGETRequestMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryProgressGETRequest: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryProgressGETRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryProgressGETRequestMsg: typing_extensions.TypeAlias = RegistryProgressGETRequestMsg

@typing.final
class RegistryProgressGETResponse(google.protobuf.message.Message):
    """M009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    RESP_CODE_FIELD_NUMBER: builtins.int
    url: builtins.str
    resp_code: builtins.int
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        resp_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resp_code", b"resp_code", "url", b"url"]) -> None: ...

Global___RegistryProgressGETResponse: typing_extensions.TypeAlias = RegistryProgressGETResponse

@typing.final
class RegistryProgressGETResponseMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryProgressGETResponse: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryProgressGETResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryProgressGETResponseMsg: typing_extensions.TypeAlias = RegistryProgressGETResponseMsg

@typing.final
class SelectorReportInvalidSelector(google.protobuf.message.Message):
    """M010"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALID_SELECTORS_FIELD_NUMBER: builtins.int
    SPEC_METHOD_FIELD_NUMBER: builtins.int
    RAW_SPEC_FIELD_NUMBER: builtins.int
    valid_selectors: builtins.str
    spec_method: builtins.str
    raw_spec: builtins.str
    def __init__(
        self,
        *,
        valid_selectors: builtins.str = ...,
        spec_method: builtins.str = ...,
        raw_spec: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["raw_spec", b"raw_spec", "spec_method", b"spec_method", "valid_selectors", b"valid_selectors"]) -> None: ...

Global___SelectorReportInvalidSelector: typing_extensions.TypeAlias = SelectorReportInvalidSelector

@typing.final
class SelectorReportInvalidSelectorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SelectorReportInvalidSelector: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SelectorReportInvalidSelector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SelectorReportInvalidSelectorMsg: typing_extensions.TypeAlias = SelectorReportInvalidSelectorMsg

@typing.final
class DepsNoPackagesFound(google.protobuf.message.Message):
    """Skipped M011 and M012

    M013
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DepsNoPackagesFound: typing_extensions.TypeAlias = DepsNoPackagesFound

@typing.final
class DepsNoPackagesFoundMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsNoPackagesFound: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsNoPackagesFound | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsNoPackagesFoundMsg: typing_extensions.TypeAlias = DepsNoPackagesFoundMsg

@typing.final
class DepsStartPackageInstall(google.protobuf.message.Message):
    """M014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name"]) -> None: ...

Global___DepsStartPackageInstall: typing_extensions.TypeAlias = DepsStartPackageInstall

@typing.final
class DepsStartPackageInstallMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsStartPackageInstall: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsStartPackageInstall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsStartPackageInstallMsg: typing_extensions.TypeAlias = DepsStartPackageInstallMsg

@typing.final
class DepsInstallInfo(google.protobuf.message.Message):
    """M015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_NAME_FIELD_NUMBER: builtins.int
    version_name: builtins.str
    def __init__(
        self,
        *,
        version_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version_name", b"version_name"]) -> None: ...

Global___DepsInstallInfo: typing_extensions.TypeAlias = DepsInstallInfo

@typing.final
class DepsInstallInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsInstallInfo: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsInstallInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsInstallInfoMsg: typing_extensions.TypeAlias = DepsInstallInfoMsg

@typing.final
class DepsUpdateAvailable(google.protobuf.message.Message):
    """M016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_LATEST_FIELD_NUMBER: builtins.int
    version_latest: builtins.str
    def __init__(
        self,
        *,
        version_latest: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version_latest", b"version_latest"]) -> None: ...

Global___DepsUpdateAvailable: typing_extensions.TypeAlias = DepsUpdateAvailable

@typing.final
class DepsUpdateAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsUpdateAvailable: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsUpdateAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsUpdateAvailableMsg: typing_extensions.TypeAlias = DepsUpdateAvailableMsg

@typing.final
class DepsUpToDate(google.protobuf.message.Message):
    """M017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DepsUpToDate: typing_extensions.TypeAlias = DepsUpToDate

@typing.final
class DepsUpToDateMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsUpToDate: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsUpToDate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsUpToDateMsg: typing_extensions.TypeAlias = DepsUpToDateMsg

@typing.final
class DepsListSubdirectory(google.protobuf.message.Message):
    """M018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBDIRECTORY_FIELD_NUMBER: builtins.int
    subdirectory: builtins.str
    def __init__(
        self,
        *,
        subdirectory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subdirectory", b"subdirectory"]) -> None: ...

Global___DepsListSubdirectory: typing_extensions.TypeAlias = DepsListSubdirectory

@typing.final
class DepsListSubdirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsListSubdirectory: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsListSubdirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsListSubdirectoryMsg: typing_extensions.TypeAlias = DepsListSubdirectoryMsg

@typing.final
class DepsNotifyUpdatesAvailable(google.protobuf.message.Message):
    """M019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGES_FIELD_NUMBER: builtins.int
    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["packages", b"packages"]) -> None: ...

Global___DepsNotifyUpdatesAvailable: typing_extensions.TypeAlias = DepsNotifyUpdatesAvailable

@typing.final
class DepsNotifyUpdatesAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsNotifyUpdatesAvailable: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsNotifyUpdatesAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsNotifyUpdatesAvailableMsg: typing_extensions.TypeAlias = DepsNotifyUpdatesAvailableMsg

@typing.final
class RegistryIndexProgressGETRequest(google.protobuf.message.Message):
    """M022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

Global___RegistryIndexProgressGETRequest: typing_extensions.TypeAlias = RegistryIndexProgressGETRequest

@typing.final
class RegistryIndexProgressGETRequestMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryIndexProgressGETRequest: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryIndexProgressGETRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryIndexProgressGETRequestMsg: typing_extensions.TypeAlias = RegistryIndexProgressGETRequestMsg

@typing.final
class RegistryIndexProgressGETResponse(google.protobuf.message.Message):
    """M023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    RESP_CODE_FIELD_NUMBER: builtins.int
    url: builtins.str
    resp_code: builtins.int
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        resp_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resp_code", b"resp_code", "url", b"url"]) -> None: ...

Global___RegistryIndexProgressGETResponse: typing_extensions.TypeAlias = RegistryIndexProgressGETResponse

@typing.final
class RegistryIndexProgressGETResponseMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryIndexProgressGETResponse: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryIndexProgressGETResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryIndexProgressGETResponseMsg: typing_extensions.TypeAlias = RegistryIndexProgressGETResponseMsg

@typing.final
class RegistryResponseUnexpectedType(google.protobuf.message.Message):
    """M024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

Global___RegistryResponseUnexpectedType: typing_extensions.TypeAlias = RegistryResponseUnexpectedType

@typing.final
class RegistryResponseUnexpectedTypeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryResponseUnexpectedType: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryResponseUnexpectedType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryResponseUnexpectedTypeMsg: typing_extensions.TypeAlias = RegistryResponseUnexpectedTypeMsg

@typing.final
class RegistryResponseMissingTopKeys(google.protobuf.message.Message):
    """M025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

Global___RegistryResponseMissingTopKeys: typing_extensions.TypeAlias = RegistryResponseMissingTopKeys

@typing.final
class RegistryResponseMissingTopKeysMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryResponseMissingTopKeys: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryResponseMissingTopKeys | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryResponseMissingTopKeysMsg: typing_extensions.TypeAlias = RegistryResponseMissingTopKeysMsg

@typing.final
class RegistryResponseMissingNestedKeys(google.protobuf.message.Message):
    """M026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

Global___RegistryResponseMissingNestedKeys: typing_extensions.TypeAlias = RegistryResponseMissingNestedKeys

@typing.final
class RegistryResponseMissingNestedKeysMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryResponseMissingNestedKeys: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryResponseMissingNestedKeys | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryResponseMissingNestedKeysMsg: typing_extensions.TypeAlias = RegistryResponseMissingNestedKeysMsg

@typing.final
class RegistryResponseExtraNestedKeys(google.protobuf.message.Message):
    """M027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: builtins.str
    def __init__(
        self,
        *,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

Global___RegistryResponseExtraNestedKeys: typing_extensions.TypeAlias = RegistryResponseExtraNestedKeys

@typing.final
class RegistryResponseExtraNestedKeysMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RegistryResponseExtraNestedKeys: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RegistryResponseExtraNestedKeys | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RegistryResponseExtraNestedKeysMsg: typing_extensions.TypeAlias = RegistryResponseExtraNestedKeysMsg

@typing.final
class DepsSetDownloadDirectory(google.protobuf.message.Message):
    """M028"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___DepsSetDownloadDirectory: typing_extensions.TypeAlias = DepsSetDownloadDirectory

@typing.final
class DepsSetDownloadDirectoryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsSetDownloadDirectory: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsSetDownloadDirectory | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsSetDownloadDirectoryMsg: typing_extensions.TypeAlias = DepsSetDownloadDirectoryMsg

@typing.final
class DepsUnpinned(google.protobuf.message.Message):
    """M029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REVISION_FIELD_NUMBER: builtins.int
    GIT_FIELD_NUMBER: builtins.int
    revision: builtins.str
    git: builtins.str
    def __init__(
        self,
        *,
        revision: builtins.str = ...,
        git: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["git", b"git", "revision", b"revision"]) -> None: ...

Global___DepsUnpinned: typing_extensions.TypeAlias = DepsUnpinned

@typing.final
class DepsUnpinnedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsUnpinned: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsUnpinned | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsUnpinnedMsg: typing_extensions.TypeAlias = DepsUnpinnedMsg

@typing.final
class NoNodesForSelectionCriteria(google.protobuf.message.Message):
    """M030"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_RAW_FIELD_NUMBER: builtins.int
    spec_raw: builtins.str
    def __init__(
        self,
        *,
        spec_raw: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["spec_raw", b"spec_raw"]) -> None: ...

Global___NoNodesForSelectionCriteria: typing_extensions.TypeAlias = NoNodesForSelectionCriteria

@typing.final
class NoNodesForSelectionCriteriaMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NoNodesForSelectionCriteria: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NoNodesForSelectionCriteria | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NoNodesForSelectionCriteriaMsg: typing_extensions.TypeAlias = NoNodesForSelectionCriteriaMsg

@typing.final
class DepsLockUpdating(google.protobuf.message.Message):
    """M031"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCK_FILEPATH_FIELD_NUMBER: builtins.int
    lock_filepath: builtins.str
    def __init__(
        self,
        *,
        lock_filepath: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["lock_filepath", b"lock_filepath"]) -> None: ...

Global___DepsLockUpdating: typing_extensions.TypeAlias = DepsLockUpdating

@typing.final
class DepsLockUpdatingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsLockUpdating: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsLockUpdating | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsLockUpdatingMsg: typing_extensions.TypeAlias = DepsLockUpdatingMsg

@typing.final
class DepsAddPackage(google.protobuf.message.Message):
    """M032"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    PACKAGES_FILEPATH_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    version: builtins.str
    packages_filepath: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        version: builtins.str = ...,
        packages_filepath: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name", "packages_filepath", b"packages_filepath", "version", b"version"]) -> None: ...

Global___DepsAddPackage: typing_extensions.TypeAlias = DepsAddPackage

@typing.final
class DepsAddPackageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsAddPackage: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsAddPackage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsAddPackageMsg: typing_extensions.TypeAlias = DepsAddPackageMsg

@typing.final
class DepsFoundDuplicatePackage(google.protobuf.message.Message):
    """M033"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class RemovedPackageEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    REMOVED_PACKAGE_FIELD_NUMBER: builtins.int
    @property
    def removed_package(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        removed_package: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["removed_package", b"removed_package"]) -> None: ...

Global___DepsFoundDuplicatePackage: typing_extensions.TypeAlias = DepsFoundDuplicatePackage

@typing.final
class DepsFoundDuplicatePackageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsFoundDuplicatePackage: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsFoundDuplicatePackage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsFoundDuplicatePackageMsg: typing_extensions.TypeAlias = DepsFoundDuplicatePackageMsg

@typing.final
class DepsVersionMissing(google.protobuf.message.Message):
    """M034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    source: builtins.str
    def __init__(
        self,
        *,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source", b"source"]) -> None: ...

Global___DepsVersionMissing: typing_extensions.TypeAlias = DepsVersionMissing

@typing.final
class DepsVersionMissingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsVersionMissing: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsVersionMissing | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsVersionMissingMsg: typing_extensions.TypeAlias = DepsVersionMissingMsg

@typing.final
class DepsScrubbedPackageName(google.protobuf.message.Message):
    """M035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_name", b"package_name"]) -> None: ...

Global___DepsScrubbedPackageName: typing_extensions.TypeAlias = DepsScrubbedPackageName

@typing.final
class DepsScrubbedPackageNameMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsScrubbedPackageName: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsScrubbedPackageName | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsScrubbedPackageNameMsg: typing_extensions.TypeAlias = DepsScrubbedPackageNameMsg

@typing.final
class ArtifactWritten(google.protobuf.message.Message):
    """P - Artifacts

    P001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACT_TYPE_FIELD_NUMBER: builtins.int
    ARTIFACT_PATH_FIELD_NUMBER: builtins.int
    artifact_type: builtins.str
    artifact_path: builtins.str
    def __init__(
        self,
        *,
        artifact_type: builtins.str = ...,
        artifact_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifact_path", b"artifact_path", "artifact_type", b"artifact_type"]) -> None: ...

Global___ArtifactWritten: typing_extensions.TypeAlias = ArtifactWritten

@typing.final
class ArtifactWrittenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ArtifactWritten: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ArtifactWritten | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ArtifactWrittenMsg: typing_extensions.TypeAlias = ArtifactWrittenMsg

@typing.final
class RunningOperationCaughtError(google.protobuf.message.Message):
    """Q - Node execution

    Q001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___RunningOperationCaughtError: typing_extensions.TypeAlias = RunningOperationCaughtError

@typing.final
class RunningOperationCaughtErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunningOperationCaughtError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunningOperationCaughtError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunningOperationCaughtErrorMsg: typing_extensions.TypeAlias = RunningOperationCaughtErrorMsg

@typing.final
class CompileComplete(google.protobuf.message.Message):
    """Q002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CompileComplete: typing_extensions.TypeAlias = CompileComplete

@typing.final
class CompileCompleteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CompileComplete: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CompileComplete | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CompileCompleteMsg: typing_extensions.TypeAlias = CompileCompleteMsg

@typing.final
class FreshnessCheckComplete(google.protobuf.message.Message):
    """Q003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___FreshnessCheckComplete: typing_extensions.TypeAlias = FreshnessCheckComplete

@typing.final
class FreshnessCheckCompleteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___FreshnessCheckComplete: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___FreshnessCheckComplete | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FreshnessCheckCompleteMsg: typing_extensions.TypeAlias = FreshnessCheckCompleteMsg

@typing.final
class SeedHeader(google.protobuf.message.Message):
    """Q004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    header: builtins.str
    def __init__(
        self,
        *,
        header: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["header", b"header"]) -> None: ...

Global___SeedHeader: typing_extensions.TypeAlias = SeedHeader

@typing.final
class SeedHeaderMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SeedHeader: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SeedHeader | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SeedHeaderMsg: typing_extensions.TypeAlias = SeedHeaderMsg

@typing.final
class SQLRunnerException(google.protobuf.message.Message):
    """Skipped Q005

    Q006
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    exc: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "node_info", b"node_info"]) -> None: ...

Global___SQLRunnerException: typing_extensions.TypeAlias = SQLRunnerException

@typing.final
class SQLRunnerExceptionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SQLRunnerException: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SQLRunnerException | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLRunnerExceptionMsg: typing_extensions.TypeAlias = SQLRunnerExceptionMsg

@typing.final
class Group(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class OwnerEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    name: builtins.str
    package_name: builtins.str
    @property
    def owner(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        package_name: builtins.str = ...,
        owner: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "owner", b"owner", "package_name", b"package_name"]) -> None: ...

Global___Group: typing_extensions.TypeAlias = Group

@typing.final
class LogTestResult(google.protobuf.message.Message):
    """Q007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    NUM_MODELS_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    NUM_FAILURES_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    ATTACHED_NODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    status: builtins.str
    index: builtins.int
    num_models: builtins.int
    execution_time: builtins.float
    num_failures: builtins.int
    attached_node: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        name: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        num_models: builtins.int = ...,
        execution_time: builtins.float = ...,
        num_failures: builtins.int = ...,
        group: Global___Group | None = ...,
        attached_node: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attached_node", b"attached_node", "execution_time", b"execution_time", "group", b"group", "index", b"index", "name", b"name", "node_info", b"node_info", "num_failures", b"num_failures", "num_models", b"num_models", "status", b"status"]) -> None: ...

Global___LogTestResult: typing_extensions.TypeAlias = LogTestResult

@typing.final
class LogTestResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogTestResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogTestResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogTestResultMsg: typing_extensions.TypeAlias = LogTestResultMsg

@typing.final
class LogNodeResult(google.protobuf.message.Message):
    """Q008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    msg: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "index", b"index", "msg", b"msg", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

Global___LogNodeResult: typing_extensions.TypeAlias = LogNodeResult

@typing.final
class LogNodeResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogNodeResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogNodeResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogNodeResultMsg: typing_extensions.TypeAlias = LogNodeResultMsg

@typing.final
class LogStartLine(google.protobuf.message.Message):
    """Skipped Q009, Q010

    Q011
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    description: builtins.str
    index: builtins.int
    total: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "index", b"index", "node_info", b"node_info", "total", b"total"]) -> None: ...

Global___LogStartLine: typing_extensions.TypeAlias = LogStartLine

@typing.final
class LogStartLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogStartLine: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogStartLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogStartLineMsg: typing_extensions.TypeAlias = LogStartLineMsg

@typing.final
class LogModelResult(google.protobuf.message.Message):
    """Q012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

Global___LogModelResult: typing_extensions.TypeAlias = LogModelResult

@typing.final
class LogModelResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogModelResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogModelResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogModelResultMsg: typing_extensions.TypeAlias = LogModelResultMsg

@typing.final
class LogSnapshotResult(google.protobuf.message.Message):
    """skipped Q013, Q014

    Q015
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CfgEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    CFG_FIELD_NUMBER: builtins.int
    RESULT_MESSAGE_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    result_message: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def cfg(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        cfg: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        result_message: builtins.str = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cfg", b"cfg", "description", b"description", "execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "result_message", b"result_message", "status", b"status", "total", b"total"]) -> None: ...

Global___LogSnapshotResult: typing_extensions.TypeAlias = LogSnapshotResult

@typing.final
class LogSnapshotResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogSnapshotResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogSnapshotResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogSnapshotResultMsg: typing_extensions.TypeAlias = LogSnapshotResultMsg

@typing.final
class LogSeedResult(google.protobuf.message.Message):
    """Q016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESULT_MESSAGE_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    status: builtins.str
    result_message: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    schema: builtins.str
    relation: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        status: builtins.str = ...,
        result_message: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        schema: builtins.str = ...,
        relation: builtins.str = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "relation", b"relation", "result_message", b"result_message", "schema", b"schema", "status", b"status", "total", b"total"]) -> None: ...

Global___LogSeedResult: typing_extensions.TypeAlias = LogSeedResult

@typing.final
class LogSeedResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogSeedResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogSeedResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogSeedResultMsg: typing_extensions.TypeAlias = LogSeedResultMsg

@typing.final
class LogFreshnessResult(google.protobuf.message.Message):
    """Skipped Q017

    Q018
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    SOURCE_NAME_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    source_name: builtins.str
    table_name: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        source_name: builtins.str = ...,
        table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution_time", b"execution_time", "index", b"index", "node_info", b"node_info", "source_name", b"source_name", "status", b"status", "table_name", b"table_name", "total", b"total"]) -> None: ...

Global___LogFreshnessResult: typing_extensions.TypeAlias = LogFreshnessResult

@typing.final
class LogFreshnessResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogFreshnessResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogFreshnessResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogFreshnessResultMsg: typing_extensions.TypeAlias = LogFreshnessResultMsg

@typing.final
class LogNodeNoOpResult(google.protobuf.message.Message):
    """Q019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "index", b"index", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

Global___LogNodeNoOpResult: typing_extensions.TypeAlias = LogNodeNoOpResult

@typing.final
class LogNodeNoOpResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogNodeNoOpResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogNodeNoOpResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogNodeNoOpResultMsg: typing_extensions.TypeAlias = LogNodeNoOpResultMsg

@typing.final
class LogCancelLine(google.protobuf.message.Message):
    """Skipped Q020, Q021

    Q022
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONN_NAME_FIELD_NUMBER: builtins.int
    conn_name: builtins.str
    def __init__(
        self,
        *,
        conn_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["conn_name", b"conn_name"]) -> None: ...

Global___LogCancelLine: typing_extensions.TypeAlias = LogCancelLine

@typing.final
class LogCancelLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogCancelLine: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogCancelLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogCancelLineMsg: typing_extensions.TypeAlias = LogCancelLineMsg

@typing.final
class DefaultSelector(google.protobuf.message.Message):
    """Q023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

Global___DefaultSelector: typing_extensions.TypeAlias = DefaultSelector

@typing.final
class DefaultSelectorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DefaultSelector: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DefaultSelector | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DefaultSelectorMsg: typing_extensions.TypeAlias = DefaultSelectorMsg

@typing.final
class NodeStart(google.protobuf.message.Message):
    """Q024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

Global___NodeStart: typing_extensions.TypeAlias = NodeStart

@typing.final
class NodeStartMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NodeStart: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NodeStart | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NodeStartMsg: typing_extensions.TypeAlias = NodeStartMsg

@typing.final
class NodeFinished(google.protobuf.message.Message):
    """Q025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    RUN_RESULT_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def run_result(self) -> Global___RunResultMsg: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        run_result: Global___RunResultMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info", "run_result", b"run_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "run_result", b"run_result"]) -> None: ...

Global___NodeFinished: typing_extensions.TypeAlias = NodeFinished

@typing.final
class NodeFinishedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NodeFinished: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NodeFinished | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NodeFinishedMsg: typing_extensions.TypeAlias = NodeFinishedMsg

@typing.final
class QueryCancelationUnsupported(google.protobuf.message.Message):
    """Q026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

Global___QueryCancelationUnsupported: typing_extensions.TypeAlias = QueryCancelationUnsupported

@typing.final
class QueryCancelationUnsupportedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___QueryCancelationUnsupported: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___QueryCancelationUnsupported | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___QueryCancelationUnsupportedMsg: typing_extensions.TypeAlias = QueryCancelationUnsupportedMsg

@typing.final
class ConcurrencyLine(google.protobuf.message.Message):
    """Q027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_THREADS_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    num_threads: builtins.int
    target_name: builtins.str
    node_count: builtins.int
    def __init__(
        self,
        *,
        num_threads: builtins.int = ...,
        target_name: builtins.str = ...,
        node_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_count", b"node_count", "num_threads", b"num_threads", "target_name", b"target_name"]) -> None: ...

Global___ConcurrencyLine: typing_extensions.TypeAlias = ConcurrencyLine

@typing.final
class ConcurrencyLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConcurrencyLine: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConcurrencyLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConcurrencyLineMsg: typing_extensions.TypeAlias = ConcurrencyLineMsg

@typing.final
class WritingInjectedSQLForNode(google.protobuf.message.Message):
    """Q029"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

Global___WritingInjectedSQLForNode: typing_extensions.TypeAlias = WritingInjectedSQLForNode

@typing.final
class WritingInjectedSQLForNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___WritingInjectedSQLForNode: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___WritingInjectedSQLForNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___WritingInjectedSQLForNodeMsg: typing_extensions.TypeAlias = WritingInjectedSQLForNodeMsg

@typing.final
class NodeCompiling(google.protobuf.message.Message):
    """Q030"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

Global___NodeCompiling: typing_extensions.TypeAlias = NodeCompiling

@typing.final
class NodeCompilingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NodeCompiling: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NodeCompiling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NodeCompilingMsg: typing_extensions.TypeAlias = NodeCompilingMsg

@typing.final
class NodeExecuting(google.protobuf.message.Message):
    """Q031"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info"]) -> None: ...

Global___NodeExecuting: typing_extensions.TypeAlias = NodeExecuting

@typing.final
class NodeExecutingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NodeExecuting: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NodeExecuting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NodeExecutingMsg: typing_extensions.TypeAlias = NodeExecutingMsg

@typing.final
class LogHookStartLine(google.protobuf.message.Message):
    """Q032"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATEMENT_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    statement: builtins.str
    index: builtins.int
    total: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        statement: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "node_info", b"node_info", "statement", b"statement", "total", b"total"]) -> None: ...

Global___LogHookStartLine: typing_extensions.TypeAlias = LogHookStartLine

@typing.final
class LogHookStartLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogHookStartLine: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogHookStartLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogHookStartLineMsg: typing_extensions.TypeAlias = LogHookStartLineMsg

@typing.final
class LogHookEndLine(google.protobuf.message.Message):
    """Q033"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    STATEMENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    statement: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        statement: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution_time", b"execution_time", "index", b"index", "node_info", b"node_info", "statement", b"statement", "status", b"status", "total", b"total"]) -> None: ...

Global___LogHookEndLine: typing_extensions.TypeAlias = LogHookEndLine

@typing.final
class LogHookEndLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogHookEndLine: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogHookEndLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogHookEndLineMsg: typing_extensions.TypeAlias = LogHookEndLineMsg

@typing.final
class SkippingDetails(google.protobuf.message.Message):
    """Q034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    schema: builtins.str
    node_name: builtins.str
    index: builtins.int
    total: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        resource_type: builtins.str = ...,
        schema: builtins.str = ...,
        node_name: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "index", b"index", "node_info", b"node_info", "node_name", b"node_name", "resource_type", b"resource_type", "schema", b"schema", "total", b"total"]) -> None: ...

Global___SkippingDetails: typing_extensions.TypeAlias = SkippingDetails

@typing.final
class SkippingDetailsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SkippingDetails: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SkippingDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SkippingDetailsMsg: typing_extensions.TypeAlias = SkippingDetailsMsg

@typing.final
class NothingToDo(google.protobuf.message.Message):
    """Q035"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___NothingToDo: typing_extensions.TypeAlias = NothingToDo

@typing.final
class NothingToDoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NothingToDo: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NothingToDo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NothingToDoMsg: typing_extensions.TypeAlias = NothingToDoMsg

@typing.final
class RunningOperationUncaughtError(google.protobuf.message.Message):
    """Q036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___RunningOperationUncaughtError: typing_extensions.TypeAlias = RunningOperationUncaughtError

@typing.final
class RunningOperationUncaughtErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunningOperationUncaughtError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunningOperationUncaughtError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunningOperationUncaughtErrorMsg: typing_extensions.TypeAlias = RunningOperationUncaughtErrorMsg

@typing.final
class EndRunResult(google.protobuf.message.Message):
    """Q037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    ELAPSED_TIME_FIELD_NUMBER: builtins.int
    GENERATED_AT_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    elapsed_time: builtins.float
    success: builtins.bool
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___RunResultMsg]: ...
    @property
    def generated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___RunResultMsg] | None = ...,
        elapsed_time: builtins.float = ...,
        generated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        success: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["generated_at", b"generated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["elapsed_time", b"elapsed_time", "generated_at", b"generated_at", "results", b"results", "success", b"success"]) -> None: ...

Global___EndRunResult: typing_extensions.TypeAlias = EndRunResult

@typing.final
class EndRunResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___EndRunResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___EndRunResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___EndRunResultMsg: typing_extensions.TypeAlias = EndRunResultMsg

@typing.final
class NoNodesSelected(google.protobuf.message.Message):
    """Q038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___NoNodesSelected: typing_extensions.TypeAlias = NoNodesSelected

@typing.final
class NoNodesSelectedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NoNodesSelected: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NoNodesSelected | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NoNodesSelectedMsg: typing_extensions.TypeAlias = NoNodesSelectedMsg

@typing.final
class CommandCompleted(google.protobuf.message.Message):
    """Q039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    ELAPSED_FIELD_NUMBER: builtins.int
    command: builtins.str
    success: builtins.bool
    elapsed: builtins.float
    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        command: builtins.str = ...,
        success: builtins.bool = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        elapsed: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_at", b"completed_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["command", b"command", "completed_at", b"completed_at", "elapsed", b"elapsed", "success", b"success"]) -> None: ...

Global___CommandCompleted: typing_extensions.TypeAlias = CommandCompleted

@typing.final
class CommandCompletedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CommandCompleted: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CommandCompleted | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CommandCompletedMsg: typing_extensions.TypeAlias = CommandCompletedMsg

@typing.final
class ShowNode(google.protobuf.message.Message):
    """Q041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_NAME_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    IS_INLINE_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    QUIET_FIELD_NUMBER: builtins.int
    node_name: builtins.str
    preview: builtins.str
    is_inline: builtins.bool
    output_format: builtins.str
    unique_id: builtins.str
    quiet: builtins.bool
    def __init__(
        self,
        *,
        node_name: builtins.str = ...,
        preview: builtins.str = ...,
        is_inline: builtins.bool = ...,
        output_format: builtins.str = ...,
        unique_id: builtins.str = ...,
        quiet: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["is_inline", b"is_inline", "node_name", b"node_name", "output_format", b"output_format", "preview", b"preview", "quiet", b"quiet", "unique_id", b"unique_id"]) -> None: ...

Global___ShowNode: typing_extensions.TypeAlias = ShowNode

@typing.final
class ShowNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ShowNode: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ShowNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ShowNodeMsg: typing_extensions.TypeAlias = ShowNodeMsg

@typing.final
class CompiledNode(google.protobuf.message.Message):
    """Q042"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_NAME_FIELD_NUMBER: builtins.int
    COMPILED_FIELD_NUMBER: builtins.int
    IS_INLINE_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    QUIET_FIELD_NUMBER: builtins.int
    node_name: builtins.str
    compiled: builtins.str
    is_inline: builtins.bool
    output_format: builtins.str
    unique_id: builtins.str
    quiet: builtins.bool
    def __init__(
        self,
        *,
        node_name: builtins.str = ...,
        compiled: builtins.str = ...,
        is_inline: builtins.bool = ...,
        output_format: builtins.str = ...,
        unique_id: builtins.str = ...,
        quiet: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compiled", b"compiled", "is_inline", b"is_inline", "node_name", b"node_name", "output_format", b"output_format", "quiet", b"quiet", "unique_id", b"unique_id"]) -> None: ...

Global___CompiledNode: typing_extensions.TypeAlias = CompiledNode

@typing.final
class CompiledNodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CompiledNode: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CompiledNode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CompiledNodeMsg: typing_extensions.TypeAlias = CompiledNodeMsg

@typing.final
class SnapshotTimestampWarning(google.protobuf.message.Message):
    """Q043"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_TIME_DATA_TYPE_FIELD_NUMBER: builtins.int
    UPDATED_AT_DATA_TYPE_FIELD_NUMBER: builtins.int
    snapshot_time_data_type: builtins.str
    updated_at_data_type: builtins.str
    def __init__(
        self,
        *,
        snapshot_time_data_type: builtins.str = ...,
        updated_at_data_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_time_data_type", b"snapshot_time_data_type", "updated_at_data_type", b"updated_at_data_type"]) -> None: ...

Global___SnapshotTimestampWarning: typing_extensions.TypeAlias = SnapshotTimestampWarning

@typing.final
class SnapshotTimestampWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SnapshotTimestampWarning: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SnapshotTimestampWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SnapshotTimestampWarningMsg: typing_extensions.TypeAlias = SnapshotTimestampWarningMsg

@typing.final
class MicrobatchExecutionDebug(google.protobuf.message.Message):
    """Q044"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___MicrobatchExecutionDebug: typing_extensions.TypeAlias = MicrobatchExecutionDebug

@typing.final
class MicrobatchExecutionDebugMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MicrobatchExecutionDebug: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MicrobatchExecutionDebug | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MicrobatchExecutionDebugMsg: typing_extensions.TypeAlias = MicrobatchExecutionDebugMsg

@typing.final
class LogStartBatch(google.protobuf.message.Message):
    """Q045"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BATCH_INDEX_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    description: builtins.str
    batch_index: builtins.int
    total_batches: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        batch_index: builtins.int = ...,
        total_batches: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_index", b"batch_index", "description", b"description", "node_info", b"node_info", "total_batches", b"total_batches"]) -> None: ...

Global___LogStartBatch: typing_extensions.TypeAlias = LogStartBatch

@typing.final
class LogStartBatchMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogStartBatch: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogStartBatch | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogStartBatchMsg: typing_extensions.TypeAlias = LogStartBatchMsg

@typing.final
class LogBatchResult(google.protobuf.message.Message):
    """Q046"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BATCH_INDEX_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    batch_index: builtins.int
    total_batches: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        batch_index: builtins.int = ...,
        total_batches: builtins.int = ...,
        execution_time: builtins.float = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_index", b"batch_index", "description", b"description", "execution_time", b"execution_time", "group", b"group", "node_info", b"node_info", "status", b"status", "total_batches", b"total_batches"]) -> None: ...

Global___LogBatchResult: typing_extensions.TypeAlias = LogBatchResult

@typing.final
class LogBatchResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogBatchResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogBatchResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogBatchResultMsg: typing_extensions.TypeAlias = LogBatchResultMsg

@typing.final
class LogFunctionResult(google.protobuf.message.Message):
    """Q047"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    index: builtins.int
    total: builtins.int
    execution_time: builtins.float
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "execution_time", b"execution_time", "group", b"group", "index", b"index", "node_info", b"node_info", "status", b"status", "total", b"total"]) -> None: ...

Global___LogFunctionResult: typing_extensions.TypeAlias = LogFunctionResult

@typing.final
class LogFunctionResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogFunctionResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogFunctionResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogFunctionResultMsg: typing_extensions.TypeAlias = LogFunctionResultMsg

@typing.final
class CatchableExceptionOnRun(google.protobuf.message.Message):
    """Skipped W001

    W002
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    exc: builtins.str
    exc_info: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "node_info", b"node_info"]) -> None: ...

Global___CatchableExceptionOnRun: typing_extensions.TypeAlias = CatchableExceptionOnRun

@typing.final
class CatchableExceptionOnRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CatchableExceptionOnRun: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CatchableExceptionOnRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CatchableExceptionOnRunMsg: typing_extensions.TypeAlias = CatchableExceptionOnRunMsg

@typing.final
class InternalErrorOnRun(google.protobuf.message.Message):
    """W003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_PATH_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    build_path: builtins.str
    exc: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        build_path: builtins.str = ...,
        exc: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["build_path", b"build_path", "exc", b"exc", "node_info", b"node_info"]) -> None: ...

Global___InternalErrorOnRun: typing_extensions.TypeAlias = InternalErrorOnRun

@typing.final
class InternalErrorOnRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___InternalErrorOnRun: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___InternalErrorOnRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___InternalErrorOnRunMsg: typing_extensions.TypeAlias = InternalErrorOnRunMsg

@typing.final
class GenericExceptionOnRun(google.protobuf.message.Message):
    """W004"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_PATH_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    build_path: builtins.str
    unique_id: builtins.str
    exc: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        build_path: builtins.str = ...,
        unique_id: builtins.str = ...,
        exc: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["build_path", b"build_path", "exc", b"exc", "node_info", b"node_info", "unique_id", b"unique_id"]) -> None: ...

Global___GenericExceptionOnRun: typing_extensions.TypeAlias = GenericExceptionOnRun

@typing.final
class GenericExceptionOnRunMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___GenericExceptionOnRun: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___GenericExceptionOnRun | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GenericExceptionOnRunMsg: typing_extensions.TypeAlias = GenericExceptionOnRunMsg

@typing.final
class NodeConnectionReleaseError(google.protobuf.message.Message):
    """W005"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_NAME_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    EXC_INFO_FIELD_NUMBER: builtins.int
    node_name: builtins.str
    exc: builtins.str
    exc_info: builtins.str
    def __init__(
        self,
        *,
        node_name: builtins.str = ...,
        exc: builtins.str = ...,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "exc_info", b"exc_info", "node_name", b"node_name"]) -> None: ...

Global___NodeConnectionReleaseError: typing_extensions.TypeAlias = NodeConnectionReleaseError

@typing.final
class NodeConnectionReleaseErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___NodeConnectionReleaseError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___NodeConnectionReleaseError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NodeConnectionReleaseErrorMsg: typing_extensions.TypeAlias = NodeConnectionReleaseErrorMsg

@typing.final
class FoundStats(google.protobuf.message.Message):
    """W006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAT_LINE_FIELD_NUMBER: builtins.int
    stat_line: builtins.str
    def __init__(
        self,
        *,
        stat_line: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stat_line", b"stat_line"]) -> None: ...

Global___FoundStats: typing_extensions.TypeAlias = FoundStats

@typing.final
class FoundStatsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___FoundStats: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___FoundStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FoundStatsMsg: typing_extensions.TypeAlias = FoundStatsMsg

@typing.final
class MainKeyboardInterrupt(google.protobuf.message.Message):
    """Z - Misc

    Z001
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MainKeyboardInterrupt: typing_extensions.TypeAlias = MainKeyboardInterrupt

@typing.final
class MainKeyboardInterruptMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MainKeyboardInterrupt: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MainKeyboardInterrupt | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MainKeyboardInterruptMsg: typing_extensions.TypeAlias = MainKeyboardInterruptMsg

@typing.final
class MainEncounteredError(google.protobuf.message.Message):
    """Z002"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___MainEncounteredError: typing_extensions.TypeAlias = MainEncounteredError

@typing.final
class MainEncounteredErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MainEncounteredError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MainEncounteredError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MainEncounteredErrorMsg: typing_extensions.TypeAlias = MainEncounteredErrorMsg

@typing.final
class MainStackTrace(google.protobuf.message.Message):
    """Z003"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STACK_TRACE_FIELD_NUMBER: builtins.int
    stack_trace: builtins.str
    def __init__(
        self,
        *,
        stack_trace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stack_trace", b"stack_trace"]) -> None: ...

Global___MainStackTrace: typing_extensions.TypeAlias = MainStackTrace

@typing.final
class MainStackTraceMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MainStackTrace: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MainStackTrace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MainStackTraceMsg: typing_extensions.TypeAlias = MainStackTraceMsg

@typing.final
class TimingInfoCollected(google.protobuf.message.Message):
    """skipping Z004

    Z010
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_INFO_FIELD_NUMBER: builtins.int
    TIMING_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def timing_info(self) -> Global___TimingInfoMsg: ...
    def __init__(
        self,
        *,
        node_info: Global___NodeInfo | None = ...,
        timing_info: Global___TimingInfoMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info", "timing_info", b"timing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "timing_info", b"timing_info"]) -> None: ...

Global___TimingInfoCollected: typing_extensions.TypeAlias = TimingInfoCollected

@typing.final
class TimingInfoCollectedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___TimingInfoCollected: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___TimingInfoCollected | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___TimingInfoCollectedMsg: typing_extensions.TypeAlias = TimingInfoCollectedMsg

@typing.final
class LogDebugStackTrace(google.protobuf.message.Message):
    """Z011"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_INFO_FIELD_NUMBER: builtins.int
    exc_info: builtins.str
    def __init__(
        self,
        *,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

Global___LogDebugStackTrace: typing_extensions.TypeAlias = LogDebugStackTrace

@typing.final
class LogDebugStackTraceMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogDebugStackTrace: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogDebugStackTrace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogDebugStackTraceMsg: typing_extensions.TypeAlias = LogDebugStackTraceMsg

@typing.final
class CheckCleanPath(google.protobuf.message.Message):
    """Z012"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___CheckCleanPath: typing_extensions.TypeAlias = CheckCleanPath

@typing.final
class CheckCleanPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CheckCleanPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CheckCleanPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CheckCleanPathMsg: typing_extensions.TypeAlias = CheckCleanPathMsg

@typing.final
class ConfirmCleanPath(google.protobuf.message.Message):
    """Z013"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___ConfirmCleanPath: typing_extensions.TypeAlias = ConfirmCleanPath

@typing.final
class ConfirmCleanPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ConfirmCleanPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ConfirmCleanPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ConfirmCleanPathMsg: typing_extensions.TypeAlias = ConfirmCleanPathMsg

@typing.final
class ProtectedCleanPath(google.protobuf.message.Message):
    """Z014"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

Global___ProtectedCleanPath: typing_extensions.TypeAlias = ProtectedCleanPath

@typing.final
class ProtectedCleanPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ProtectedCleanPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ProtectedCleanPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ProtectedCleanPathMsg: typing_extensions.TypeAlias = ProtectedCleanPathMsg

@typing.final
class FinishedCleanPaths(google.protobuf.message.Message):
    """Z015"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___FinishedCleanPaths: typing_extensions.TypeAlias = FinishedCleanPaths

@typing.final
class FinishedCleanPathsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___FinishedCleanPaths: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___FinishedCleanPaths | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FinishedCleanPathsMsg: typing_extensions.TypeAlias = FinishedCleanPathsMsg

@typing.final
class OpenCommand(google.protobuf.message.Message):
    """Z016"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_CMD_FIELD_NUMBER: builtins.int
    PROFILES_DIR_FIELD_NUMBER: builtins.int
    open_cmd: builtins.str
    profiles_dir: builtins.str
    def __init__(
        self,
        *,
        open_cmd: builtins.str = ...,
        profiles_dir: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["open_cmd", b"open_cmd", "profiles_dir", b"profiles_dir"]) -> None: ...

Global___OpenCommand: typing_extensions.TypeAlias = OpenCommand

@typing.final
class OpenCommandMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___OpenCommand: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___OpenCommand | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___OpenCommandMsg: typing_extensions.TypeAlias = OpenCommandMsg

@typing.final
class ServingDocsPort(google.protobuf.message.Message):
    """Z018"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    address: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "port", b"port"]) -> None: ...

Global___ServingDocsPort: typing_extensions.TypeAlias = ServingDocsPort

@typing.final
class ServingDocsPortMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ServingDocsPort: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ServingDocsPort | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ServingDocsPortMsg: typing_extensions.TypeAlias = ServingDocsPortMsg

@typing.final
class ServingDocsAccessInfo(google.protobuf.message.Message):
    """Z019"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    port: builtins.str
    def __init__(
        self,
        *,
        port: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["port", b"port"]) -> None: ...

Global___ServingDocsAccessInfo: typing_extensions.TypeAlias = ServingDocsAccessInfo

@typing.final
class ServingDocsAccessInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ServingDocsAccessInfo: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ServingDocsAccessInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ServingDocsAccessInfoMsg: typing_extensions.TypeAlias = ServingDocsAccessInfoMsg

@typing.final
class ServingDocsExitInfo(google.protobuf.message.Message):
    """Z020"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ServingDocsExitInfo: typing_extensions.TypeAlias = ServingDocsExitInfo

@typing.final
class ServingDocsExitInfoMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ServingDocsExitInfo: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ServingDocsExitInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ServingDocsExitInfoMsg: typing_extensions.TypeAlias = ServingDocsExitInfoMsg

@typing.final
class RunResultWarning(google.protobuf.message.Message):
    """Z021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    node_name: builtins.str
    path: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        node_name: builtins.str = ...,
        path: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info", "node_name", b"node_name", "path", b"path", "resource_type", b"resource_type"]) -> None: ...

Global___RunResultWarning: typing_extensions.TypeAlias = RunResultWarning

@typing.final
class RunResultWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunResultWarning: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunResultWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunResultWarningMsg: typing_extensions.TypeAlias = RunResultWarningMsg

@typing.final
class RunResultFailure(google.protobuf.message.Message):
    """Z022"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    resource_type: builtins.str
    node_name: builtins.str
    path: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        resource_type: builtins.str = ...,
        node_name: builtins.str = ...,
        path: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info", "node_name", b"node_name", "path", b"path", "resource_type", b"resource_type"]) -> None: ...

Global___RunResultFailure: typing_extensions.TypeAlias = RunResultFailure

@typing.final
class RunResultFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunResultFailure: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunResultFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunResultFailureMsg: typing_extensions.TypeAlias = RunResultFailureMsg

@typing.final
class StatsLine(google.protobuf.message.Message):
    """Z023"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class StatsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATS_FIELD_NUMBER: builtins.int
    @property
    def stats(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]: ...
    def __init__(
        self,
        *,
        stats: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stats", b"stats"]) -> None: ...

Global___StatsLine: typing_extensions.TypeAlias = StatsLine

@typing.final
class StatsLineMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___StatsLine: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___StatsLine | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___StatsLineMsg: typing_extensions.TypeAlias = StatsLineMsg

@typing.final
class RunResultError(google.protobuf.message.Message):
    """Z024"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "msg", b"msg", "node_info", b"node_info"]) -> None: ...

Global___RunResultError: typing_extensions.TypeAlias = RunResultError

@typing.final
class RunResultErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunResultError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunResultError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunResultErrorMsg: typing_extensions.TypeAlias = RunResultErrorMsg

@typing.final
class RunResultErrorNoMessage(google.protobuf.message.Message):
    """Z025"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    status: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "status", b"status"]) -> None: ...

Global___RunResultErrorNoMessage: typing_extensions.TypeAlias = RunResultErrorNoMessage

@typing.final
class RunResultErrorNoMessageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunResultErrorNoMessage: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunResultErrorNoMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunResultErrorNoMessageMsg: typing_extensions.TypeAlias = RunResultErrorNoMessageMsg

@typing.final
class SQLCompiledPath(google.protobuf.message.Message):
    """Z026"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    path: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "path", b"path"]) -> None: ...

Global___SQLCompiledPath: typing_extensions.TypeAlias = SQLCompiledPath

@typing.final
class SQLCompiledPathMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SQLCompiledPath: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SQLCompiledPath | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SQLCompiledPathMsg: typing_extensions.TypeAlias = SQLCompiledPathMsg

@typing.final
class CheckNodeTestFailure(google.protobuf.message.Message):
    """Z027"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_NAME_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    relation_name: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        relation_name: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node_info", b"node_info", "relation_name", b"relation_name"]) -> None: ...

Global___CheckNodeTestFailure: typing_extensions.TypeAlias = CheckNodeTestFailure

@typing.final
class CheckNodeTestFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___CheckNodeTestFailure: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___CheckNodeTestFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___CheckNodeTestFailureMsg: typing_extensions.TypeAlias = CheckNodeTestFailureMsg

@typing.final
class EndOfRunSummary(google.protobuf.message.Message):
    """Skipped Z028, Z029

    Z030
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUM_ERRORS_FIELD_NUMBER: builtins.int
    NUM_WARNINGS_FIELD_NUMBER: builtins.int
    KEYBOARD_INTERRUPT_FIELD_NUMBER: builtins.int
    NUM_PARTIAL_SUCCESS_FIELD_NUMBER: builtins.int
    num_errors: builtins.int
    num_warnings: builtins.int
    keyboard_interrupt: builtins.bool
    num_partial_success: builtins.int
    def __init__(
        self,
        *,
        num_errors: builtins.int = ...,
        num_warnings: builtins.int = ...,
        keyboard_interrupt: builtins.bool = ...,
        num_partial_success: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keyboard_interrupt", b"keyboard_interrupt", "num_errors", b"num_errors", "num_partial_success", b"num_partial_success", "num_warnings", b"num_warnings"]) -> None: ...

Global___EndOfRunSummary: typing_extensions.TypeAlias = EndOfRunSummary

@typing.final
class EndOfRunSummaryMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___EndOfRunSummary: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___EndOfRunSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___EndOfRunSummaryMsg: typing_extensions.TypeAlias = EndOfRunSummaryMsg

@typing.final
class MarkSkippedChildren(google.protobuf.message.Message):
    """Skipped Z031, Z032

    Z033
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIQUE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RUN_RESULT_FIELD_NUMBER: builtins.int
    unique_id: builtins.str
    status: builtins.str
    @property
    def run_result(self) -> Global___RunResultMsg: ...
    def __init__(
        self,
        *,
        unique_id: builtins.str = ...,
        status: builtins.str = ...,
        run_result: Global___RunResultMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["run_result", b"run_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["run_result", b"run_result", "status", b"status", "unique_id", b"unique_id"]) -> None: ...

Global___MarkSkippedChildren: typing_extensions.TypeAlias = MarkSkippedChildren

@typing.final
class MarkSkippedChildrenMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___MarkSkippedChildren: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___MarkSkippedChildren | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___MarkSkippedChildrenMsg: typing_extensions.TypeAlias = MarkSkippedChildrenMsg

@typing.final
class LogSkipBecauseError(google.protobuf.message.Message):
    """Z034"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    schema: builtins.str
    relation: builtins.str
    index: builtins.int
    total: builtins.int
    status: builtins.str
    @property
    def group(self) -> Global___Group: ...
    def __init__(
        self,
        *,
        schema: builtins.str = ...,
        relation: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        status: builtins.str = ...,
        group: Global___Group | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "index", b"index", "relation", b"relation", "schema", b"schema", "status", b"status", "total", b"total"]) -> None: ...

Global___LogSkipBecauseError: typing_extensions.TypeAlias = LogSkipBecauseError

@typing.final
class LogSkipBecauseErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___LogSkipBecauseError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___LogSkipBecauseError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___LogSkipBecauseErrorMsg: typing_extensions.TypeAlias = LogSkipBecauseErrorMsg

@typing.final
class EnsureGitInstalled(google.protobuf.message.Message):
    """Z036"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___EnsureGitInstalled: typing_extensions.TypeAlias = EnsureGitInstalled

@typing.final
class EnsureGitInstalledMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___EnsureGitInstalled: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___EnsureGitInstalled | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___EnsureGitInstalledMsg: typing_extensions.TypeAlias = EnsureGitInstalledMsg

@typing.final
class DepsCreatingLocalSymlink(google.protobuf.message.Message):
    """Z037"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DepsCreatingLocalSymlink: typing_extensions.TypeAlias = DepsCreatingLocalSymlink

@typing.final
class DepsCreatingLocalSymlinkMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsCreatingLocalSymlink: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsCreatingLocalSymlink | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsCreatingLocalSymlinkMsg: typing_extensions.TypeAlias = DepsCreatingLocalSymlinkMsg

@typing.final
class DepsSymlinkNotAvailable(google.protobuf.message.Message):
    """Z038"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DepsSymlinkNotAvailable: typing_extensions.TypeAlias = DepsSymlinkNotAvailable

@typing.final
class DepsSymlinkNotAvailableMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DepsSymlinkNotAvailable: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DepsSymlinkNotAvailable | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DepsSymlinkNotAvailableMsg: typing_extensions.TypeAlias = DepsSymlinkNotAvailableMsg

@typing.final
class DisableTracking(google.protobuf.message.Message):
    """Z039"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DisableTracking: typing_extensions.TypeAlias = DisableTracking

@typing.final
class DisableTrackingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DisableTracking: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DisableTracking | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DisableTrackingMsg: typing_extensions.TypeAlias = DisableTrackingMsg

@typing.final
class SendingEvent(google.protobuf.message.Message):
    """Z040"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KWARGS_FIELD_NUMBER: builtins.int
    kwargs: builtins.str
    def __init__(
        self,
        *,
        kwargs: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["kwargs", b"kwargs"]) -> None: ...

Global___SendingEvent: typing_extensions.TypeAlias = SendingEvent

@typing.final
class SendingEventMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SendingEvent: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SendingEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SendingEventMsg: typing_extensions.TypeAlias = SendingEventMsg

@typing.final
class SendEventFailure(google.protobuf.message.Message):
    """Z041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___SendEventFailure: typing_extensions.TypeAlias = SendEventFailure

@typing.final
class SendEventFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___SendEventFailure: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___SendEventFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SendEventFailureMsg: typing_extensions.TypeAlias = SendEventFailureMsg

@typing.final
class FlushEvents(google.protobuf.message.Message):
    """Z042"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___FlushEvents: typing_extensions.TypeAlias = FlushEvents

@typing.final
class FlushEventsMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___FlushEvents: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___FlushEvents | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FlushEventsMsg: typing_extensions.TypeAlias = FlushEventsMsg

@typing.final
class FlushEventsFailure(google.protobuf.message.Message):
    """Z043"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___FlushEventsFailure: typing_extensions.TypeAlias = FlushEventsFailure

@typing.final
class FlushEventsFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___FlushEventsFailure: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___FlushEventsFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FlushEventsFailureMsg: typing_extensions.TypeAlias = FlushEventsFailureMsg

@typing.final
class TrackingInitializeFailure(google.protobuf.message.Message):
    """Z044"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_INFO_FIELD_NUMBER: builtins.int
    exc_info: builtins.str
    def __init__(
        self,
        *,
        exc_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc_info", b"exc_info"]) -> None: ...

Global___TrackingInitializeFailure: typing_extensions.TypeAlias = TrackingInitializeFailure

@typing.final
class TrackingInitializeFailureMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___TrackingInitializeFailure: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___TrackingInitializeFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___TrackingInitializeFailureMsg: typing_extensions.TypeAlias = TrackingInitializeFailureMsg

@typing.final
class RunResultWarningMessage(google.protobuf.message.Message):
    """Skipped Z045

    Z046
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    NODE_INFO_FIELD_NUMBER: builtins.int
    msg: builtins.str
    @property
    def node_info(self) -> Global___NodeInfo: ...
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
        node_info: Global___NodeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_info", b"node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg", "node_info", b"node_info"]) -> None: ...

Global___RunResultWarningMessage: typing_extensions.TypeAlias = RunResultWarningMessage

@typing.final
class RunResultWarningMessageMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___RunResultWarningMessage: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___RunResultWarningMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RunResultWarningMessageMsg: typing_extensions.TypeAlias = RunResultWarningMessageMsg

@typing.final
class DebugCmdOut(google.protobuf.message.Message):
    """Z047"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___DebugCmdOut: typing_extensions.TypeAlias = DebugCmdOut

@typing.final
class DebugCmdOutMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DebugCmdOut: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DebugCmdOut | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DebugCmdOutMsg: typing_extensions.TypeAlias = DebugCmdOutMsg

@typing.final
class DebugCmdResult(google.protobuf.message.Message):
    """Z048"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___DebugCmdResult: typing_extensions.TypeAlias = DebugCmdResult

@typing.final
class DebugCmdResultMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___DebugCmdResult: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___DebugCmdResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___DebugCmdResultMsg: typing_extensions.TypeAlias = DebugCmdResultMsg

@typing.final
class ListCmdOut(google.protobuf.message.Message):
    """Z049"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___ListCmdOut: typing_extensions.TypeAlias = ListCmdOut

@typing.final
class ListCmdOutMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ListCmdOut: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ListCmdOut | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ListCmdOutMsg: typing_extensions.TypeAlias = ListCmdOutMsg

@typing.final
class ResourceReport(google.protobuf.message.Message):
    """Z051"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_NAME_FIELD_NUMBER: builtins.int
    COMMAND_SUCCESS_FIELD_NUMBER: builtins.int
    COMMAND_WALL_CLOCK_TIME_FIELD_NUMBER: builtins.int
    PROCESS_USER_TIME_FIELD_NUMBER: builtins.int
    PROCESS_KERNEL_TIME_FIELD_NUMBER: builtins.int
    PROCESS_MEM_MAX_RSS_FIELD_NUMBER: builtins.int
    PROCESS_IN_BLOCKS_FIELD_NUMBER: builtins.int
    PROCESS_OUT_BLOCKS_FIELD_NUMBER: builtins.int
    command_name: builtins.str
    command_success: builtins.bool
    command_wall_clock_time: builtins.float
    process_user_time: builtins.float
    """The process_* metrics reflect the resource consumption of the process as
    a whole when the command completes. When dbt is being used as a library,
    these will reflect the resource consumption of the host process as a whole,
    rather than the resources used exclusively by the command.
    """
    process_kernel_time: builtins.float
    process_mem_max_rss: builtins.int
    process_in_blocks: builtins.int
    process_out_blocks: builtins.int
    def __init__(
        self,
        *,
        command_name: builtins.str = ...,
        command_success: builtins.bool = ...,
        command_wall_clock_time: builtins.float = ...,
        process_user_time: builtins.float = ...,
        process_kernel_time: builtins.float = ...,
        process_mem_max_rss: builtins.int = ...,
        process_in_blocks: builtins.int = ...,
        process_out_blocks: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["command_name", b"command_name", "command_success", b"command_success", "command_wall_clock_time", b"command_wall_clock_time", "process_in_blocks", b"process_in_blocks", "process_kernel_time", b"process_kernel_time", "process_mem_max_rss", b"process_mem_max_rss", "process_out_blocks", b"process_out_blocks", "process_user_time", b"process_user_time"]) -> None: ...

Global___ResourceReport: typing_extensions.TypeAlias = ResourceReport

@typing.final
class ResourceReportMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ResourceReport: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ResourceReport | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ResourceReportMsg: typing_extensions.TypeAlias = ResourceReportMsg

@typing.final
class ObservabilityMetric(google.protobuf.message.Message):
    """Z052"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DEBUG_MESSAGE_FIELD_NUMBER: builtins.int
    label: builtins.str
    value: builtins.float
    debug_message: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        label: builtins.str = ...,
        value: builtins.float = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        debug_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["debug_message", b"debug_message", "label", b"label", "tags", b"tags", "value", b"value"]) -> None: ...

Global___ObservabilityMetric: typing_extensions.TypeAlias = ObservabilityMetric

@typing.final
class ObservabilityMetricMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ObservabilityMetric: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ObservabilityMetric | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ObservabilityMetricMsg: typing_extensions.TypeAlias = ObservabilityMetricMsg

@typing.final
class ArtifactUploadError(google.protobuf.message.Message):
    """Z061"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___ArtifactUploadError: typing_extensions.TypeAlias = ArtifactUploadError

@typing.final
class ArtifactUploadErrorMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ArtifactUploadError: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ArtifactUploadError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ArtifactUploadErrorMsg: typing_extensions.TypeAlias = ArtifactUploadErrorMsg

@typing.final
class ArtifactUploadSuccess(google.protobuf.message.Message):
    """Z062"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___ArtifactUploadSuccess: typing_extensions.TypeAlias = ArtifactUploadSuccess

@typing.final
class ArtifactUploadSuccessMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ArtifactUploadSuccess: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ArtifactUploadSuccess | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ArtifactUploadSuccessMsg: typing_extensions.TypeAlias = ArtifactUploadSuccessMsg

@typing.final
class ArtifactUploadSkipped(google.protobuf.message.Message):
    """Z063"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___ArtifactUploadSkipped: typing_extensions.TypeAlias = ArtifactUploadSkipped

@typing.final
class ArtifactUploadSkippedMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___CoreEventInfo: ...
    @property
    def data(self) -> Global___ArtifactUploadSkipped: ...
    def __init__(
        self,
        *,
        info: Global___CoreEventInfo | None = ...,
        data: Global___ArtifactUploadSkipped | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___ArtifactUploadSkippedMsg: typing_extensions.TypeAlias = ArtifactUploadSkippedMsg
